/*---------------------------------------------------------------------------*/
/*Copyright (C)	Hach-Lange (2010). All Rights Reserved.                      */
/*Product:	SIMATIC PDM  	                                             	 */
/*Device:	SC 1720e        	                                     		 */
/*Description:	Device Description	                                     	 */
/*Dictionary:	SIPADC01.dct	                                             */
/*$Revision:	1.6  $  	                                                 */
/*$Date:	Feb 2010	                                                     */
/*File:	SC_1720e.ddl   	                                                     */
/*	Author:		T.Thiel Hach-Lange                                           */
/*				R.Mellows Hach-Lange                                         */
/*				R.Stollenwerk Hach-Lange                                     */
/*---------------------------------------------------------------------------*/


/************************************************************************/
/*---------------------Variablen----------------------------------------*/
/************************************************************************/

//-----------------Messwerte------Anfang------------------------------

VARIABLE E171_Measurement1  //TURBIDITY	40001   Measured turbidity value

{
 LABEL 	"Turbidity value" 	"|de|Trbungswert";
 HELP	"Measured turbidity value";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

}


VARIABLE E171_Measurement2  //TEMP	40005 Temperature measurement in Celsius

{
 LABEL 	"Temperature" 	"|de|Temperatur";
 HELP	"Temperature measurement in Celsius" ;
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
 	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"C";
}

VARIABLE E171_Measurement3  //LAMP V	40018   Lamp voltage

{
 LABEL 	"Lamp voltage" 	"|de|Lampenspannung";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"V";
}

VARIABLE E171_Measurement4  //LAMP CURR	40020 Lamp Current (amps)

{
 LABEL 	"Lamp Current" 	"|de|Lampenstrom";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"A";
}

VARIABLE E171_Measurement5  //INPUT V	40024 Input voltage (~12V)

{
 LABEL 	"Input voltage" 	"|de|Eingangsspannung";
 HELP	"Input voltage (12V)";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"V";
}

VARIABLE E171_Measurement6  //TEMP MAX	40068 Maximum Temperature

{
 LABEL 	"Maximum Temperature" 	"|de|Maximale Temperatur";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"C";
}

VARIABLE E171_Measurement7  // TEMP MIN	40070 Minimale Temperature

{
 LABEL 	"Minimum Temperature" 	"|de|Minimale Temperatur";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"C";
}

VARIABLE E171_Measurement8

{
 LABEL 	"+5V" 	"|de|+5V";
 HELP	"Plus five volt measurement" ;
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"V";
}


UNIT Select_unit_1		// dynymic unit relation
{
	E171_Unit1:
	E171_Measurement1, E171_Setting6
}

//-----------------Messwerte------Ende------------------------------





//-----------------Settings------Anfang------------------------------

VARIABLE E171_Unit1  //Turbidity Unit	40004 Turb units (0=mg/L:7=NTU;42=FTU)
{
	LABEL 	"Turbidity Unit" "|de|Trbungseinheit";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
         MIN_VALUE 0 ;
	 MAX_VALUE 60 ;
	{0,	"mg/l"   },
	{7,	"NTU"    },
	{8,	"TE/F"    },
	{42,	"FTU"    },
	{60,	"DEG"    }


		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE E171_Setting1  //Bubble Reject	40017   Bubble reject status (0=OFF; 1=ON)
{
	LABEL 	"Bubble Reject" "|de|Luftblasenunterdrckung";
	HELP	"Bubble reject status";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
         MIN_VALUE 0 ;
	 MAX_VALUE 1 ;

	{0,	"Off"   "|de|Aus"},
	{1,	"On"    "|de|An"}

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}


VARIABLE E171_Setting2  //Datalog Interval	40026  Datalog interval (0=5sec;
                          //1=30sec;2=1min;3=2min;4=5min;6=10min;7=15min;8=30min;9=60min, 10=4hr)
{
	LABEL 	"Datalog Interval" "|de|Datenloggerintervall";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
         MIN_VALUE 0 ;
	 MAX_VALUE 10 ;

	{0,	"5sec"     "|de|6s" },
	{1,	"30sec"    "|de|30s"},
	{2,	"1min"     "|de|1min"},
	{3,	"2min"     "|de|2min"},
	{4,	"5min"     "|de|5min"},
	{5,	"10min"    "|de|10min"},
	{6,	"15min"    "|de|15min"},
	{7,	"30min"    "|de|30min"},
	{8,	"60min"    "|de|60min"},
	{9,	"4hr"      "|de|4h"}

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE E171_Setting3  //Sensor Name	40027 Sensor name or location (8)
{
	LABEL 	"Probe Location" "|de|Einbauort";
	CLASS	CONTAINED;
	TYPE	ASCII (16)
		{

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE E171_Setting4  //SIGNAL AVG	40035 Signal Average (0=1sec; 1=6sec;
                        //2=30sec;3=60sec;4=90sec)
{
	LABEL 	"Signal avg" "|de|Mittelwertbildung";
	HELP	"Signal Average";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
         MIN_VALUE 0 ;
	 MAX_VALUE 4 ;

	{0,	"No Averaging"  "|de|Kein Mittelwert" },
	{1,	"6sec"          "|de|6s" },
	{2,	"30sec"         "|de|30s"},
	{3,	"60sec"         "|de|60s"},
	{4,	"90sec"         "|de|90s"}

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE E171_Setting5

{
	LABEL 	"Resolution" "|de|Auflsung";
	HELP	"Maximum number of decimal places";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
         MIN_VALUE 0 ;
	 MAX_VALUE 2 ;

	{0,	"x.xxxx"   },
	{1,	"xx.xxx"    },
	{2,	"xxx.xx"    }

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE E171_Setting6

{
	LABEL 	"Offset" "|de|Offset";
	HELP	"Clean Water Offset - offsets the measurement by up to 0.05NTU";
	CLASS	CONTAINED;
	TYPE	FLOAT
		{
                   MIN_VALUE -0.001 ;
          	   MAX_VALUE 0.050 ;
                   DISPLAY_FORMAT 	".3f";
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

}


VARIABLE E171_Setting8
{
	LABEL 	"Service Mode" "|de|Service Betrieb";
	HELP	"Used to detemine if the instrument is in the service mode (0 = disabled; 1= enabled)";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
                { 0, "Off" "|de|Aus"},
	 	{ 1, "On"  "|de|An"}

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//-----------------Settings------Ende------------------------------

//---EDD2DTM Dummy Byte-----
 VARIABLE dummy_byte
{
	LABEL "dummy";
	TYPE ASCII(1);
	CLASS LOCAL;

}
/************************************************************************/
/*-----------------------COMMANDS---------------------------------------*/
/************************************************************************/
COMMAND read_E171_Float01
{
	SLOT 21;
	INDEX 0;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          E171_Measurement1,             // Measured turbidity value:40001(000)Float L(02)
          dummy_byte, dummy_byte,        // Integer turbidity value (mNTU):40003(002)Unsigned Integer L(01)
          dummy_byte, dummy_byte,        // Turb units (0=mg/L:7=NTU;42=FTU):40004(003)Unsigned Integer L(01)
          E171_Measurement2,             // Temperature measurement in Celsius:40005(004)Float L(02)
          E171_Setting6,                 // Clean Water Offset - offsets the measurement by up to 0.05NTU:40007(006)Float L(02)
          dummy_byte, dummy_byte,        // Dark turbidity A/D counts.:40009(008)Unsigned Integer L(02)
          dummy_byte, dummy_byte,        // Dark turbidity A/D counts.:400010(008)Unsigned Integer L(02)
          dummy_byte, dummy_byte,        // Turbidity value with dark offset applied, but not gain.:40011(010)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,        // Used to display gain values in menus:40013(012)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,        // Software Version:40015(014)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,        // Bubble reject status (0=OFF; 1=ON):40017(016)Unsigned Integer L(01)
          dummy_byte, dummy_byte,        // Lamp voltage:40018(017)Float L(02)
          dummy_byte, dummy_byte,        // Lamp voltage:40019(017)Float L(02)
          dummy_byte, dummy_byte,        // Lamp Current (amps):40020(019)Float L(02)
          dummy_byte, dummy_byte,        // Lamp Current (amps):40021(019)Float L(02)
          dummy_byte, dummy_byte,        // Plus five volt measurement:40022(021)Float L(02)
          dummy_byte, dummy_byte,        // Plus five volt measurement:40023(021)Float L(02)
          dummy_byte, dummy_byte,        // Input voltage (~12V):40024(023)Float L(02)
          dummy_byte, dummy_byte,        // Input voltage (~12V):40025(023)Float L(02)
          dummy_byte, dummy_byte,        // Datalog interval (0=5sec;1=30sec;2=1min;3=2min;4=5min;6=10min;7=15min;8=30min;9=60min, 10=4hr):40026(025)Unsigned Integer L(01)
          dummy_byte, dummy_byte,        // Sensor name or location:40027(026)String L(08)
          dummy_byte, dummy_byte,        // Sensor name or location:40028(026)String L(08)
          dummy_byte, dummy_byte,        // Sensor name or location:40029(026)String L(08)
          dummy_byte, dummy_byte,        // Sensor name or location:40030(026)String L(08)
          dummy_byte, dummy_byte,         // Sensor name or location:40031(026)String L(08)
          dummy_byte, dummy_byte,        // Sensor name or location:40032(026)String L(08)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
         dummy_byte, dummy_byte
        }
    }
}
COMMAND read_E171_Float02
{
	SLOT 21;
	INDEX 17;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          E171_Measurement3,            // Lamp voltage:40018(017)Float L(02)
          E171_Measurement4,            // Lamp Current (amps):40020(019)Float L(02)
          E171_Measurement8,            // Plus five volt measurement:40022(021)Float L(02)
          E171_Measurement5,            // Input voltage (~12V):40024(023)Float L(02)
          dummy_byte, dummy_byte,       // Datalog interval (0=5sec;1=30sec;2=1min;3=2min;4=5min;6=10min;7=15min;8=30min;9=60min, 10=4hr):40026(025)Unsigned Integer L(01)
          dummy_byte, dummy_byte,       // Sensor name or location:40027(026)String L(08)
          dummy_byte, dummy_byte,       // Sensor name or location:40028(026)String L(08)
          dummy_byte, dummy_byte,       // Sensor name or location:40029(026)String L(08)
          dummy_byte, dummy_byte,       // Sensor name or location:40030(026)String L(08)
          dummy_byte, dummy_byte,       // Sensor name or location:40031(026)String L(08)
          dummy_byte, dummy_byte,       // Sensor name or location:40032(026)String L(08)
          dummy_byte, dummy_byte,       // Sensor name or location:40033(026)String L(08)
          dummy_byte, dummy_byte,       // Sensor name or location:40034(026)String L(08)
          dummy_byte, dummy_byte,       // Signal Average (0=1sec; 1=6sec; 2=30sec;3=60sec;4=90sec):40035(034)Unsigned Integer L(01)
          dummy_byte, dummy_byte,       // Instrument serial number:40036(035)String L(06)
          dummy_byte, dummy_byte,       // Instrument serial number:40037(035)String L(06)
          dummy_byte, dummy_byte,       // Instrument serial number:40038(035)String L(06)
          dummy_byte, dummy_byte,       // Instrument serial number:40039(035)String L(06)
          dummy_byte, dummy_byte,       // Instrument serial number:40040(035)String L(06)
          dummy_byte, dummy_byte,       // Instrument serial number:40041(035)String L(06)
          dummy_byte, dummy_byte,       // This tag holds the output mode when the mode is changed:40042(041)Unsigned Integer L(01)
          dummy_byte, dummy_byte,       // Expected value during a calibration or verification:40043(042)Float L(02)
          dummy_byte, dummy_byte,       // Expected value during a calibration or verification:40044(042)Float L(02)
          dummy_byte, dummy_byte,       // The verification type (wet vs. dry) used during verification:40045(044)Unsigned Integer L(01)
          dummy_byte, dummy_byte,       // Menu tag to select dry verification std (1NTU vs. 20NTU):40046(045)Unsigned Integer L(01)
          dummy_byte, dummy_byte,       // Used to display a dry standard serial numbers in a menu:40047(046)String L(02)
          dummy_byte, dummy_byte,       // Used to display a dry standard serial numbers in a menu:40048(046)String L(02)
          dummy_byte, dummy_byte,       // Used to display operator initials in menus:40049(048)String L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte

        }
    }
}



COMMAND read_E171_Float04
{
	SLOT 21;
	INDEX 45;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        { dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          E171_Measurement6,      // Maximum Temperature:40068(067)Float L(02)
          E171_Measurement7,      // Minimum Temperature:40070(069)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte
        }
    }
}




COMMAND read_E171_Var01
{
	SLOT 21;
	INDEX 3;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          E171_Unit1 ,// Turb units (0=mg/L:7=NTU;42=FTU):40004(003)Unsigned Integer L(01)
          dummy_byte, dummy_byte,// Temperature measurement in Celsius:40005(004)Float L(02)
          dummy_byte, dummy_byte,// Temperature measurement in Celsius:40005(004)Float L(02)
          dummy_byte, dummy_byte ,// Clean Water Offset - offsets the measurement by up to 0.05NTU:40007(006)Float L(02)
          dummy_byte, dummy_byte ,// Clean Water Offset - offsets the measurement by up to 0.05NTU:40007(006)Float L(02)
          dummy_byte, dummy_byte ,// Dark turbidity A/D counts.:40009(008)Unsigned Integer L(02)
          dummy_byte, dummy_byte ,
          dummy_byte, dummy_byte ,// Turbidity value with dark offset applied, but not gain.:40011(010)Float L(02)
          dummy_byte, dummy_byte ,// Turbidity value with dark offset applied, but not gain.:40011(010)Float L(02)
          dummy_byte, dummy_byte ,// Used to display gain values in menus:40013(012)Float L(02)
          dummy_byte, dummy_byte ,// Used to display gain values in menus:40013(012)Float L(02)
          dummy_byte, dummy_byte ,// Software Version:40015(014)Float L(02)
          dummy_byte, dummy_byte ,// Software Version:40015(014)Float L(02)
          E171_Setting1 ,// Bubble reject status (0=OFF; 1=ON):40017(016)Unsigned Integer L(01)
          dummy_byte, dummy_byte ,// Lamp voltage:40018(017)Float L(02)
          dummy_byte, dummy_byte ,// Lamp voltage:40018(017)Float L(02)
          dummy_byte, dummy_byte ,// Lamp Current (amps):40020(019)Float L(02)
          dummy_byte, dummy_byte ,// Lamp Current (amps):40020(019)Float L(02)
          dummy_byte, dummy_byte ,// Plus five volt measurement:40022(021)Float L(02)
          dummy_byte, dummy_byte ,// Plus five volt measurement:40022(021)Float L(02)
          dummy_byte, dummy_byte ,// Input voltage (~12V):40024(023)Float L(02)
          dummy_byte, dummy_byte ,// Input voltage (~12V):40024(023)Float L(02)
          E171_Setting2 ,// Datalog interval (0=5sec;1=30sec;2=1min;3=2min;4=5min;6=10min;7=15min;8=30min;9=60min, 10=4hr):40026(025)Unsigned Integer L(01)
          E171_Setting3 // Sensor name or location:40027(026)String L(08)

        }
    }
}

COMMAND read_E171_Var02
{
	SLOT 21;
	INDEX 34;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          E171_Setting4 ,// Signal Average (0=1sec; 1=6sec; 2=30sec;3=60sec;4=90sec):40035(034)Unsigned Integer L(01)
          dummy_byte, dummy_byte ,// Instrument serial number:40036(035)String L(06)
          dummy_byte, dummy_byte ,
          dummy_byte, dummy_byte ,
          dummy_byte, dummy_byte ,
          dummy_byte, dummy_byte ,
          dummy_byte, dummy_byte ,
          dummy_byte, dummy_byte ,// This tag holds the output mode when the mode is changed:40042(041)Unsigned Integer L(01)
          dummy_byte, dummy_byte ,// Expected value during a calibration or verification:40043(042)Float L(02)
          dummy_byte, dummy_byte ,// Expected value during a calibration or verification:40044(043)Float L(02)
          dummy_byte, dummy_byte ,// The verification type (wet vs. dry) used during verification:40045(044)Unsigned Integer L(01)
          dummy_byte, dummy_byte ,// Menu tag to select dry verification std (1NTU vs. 20NTU):40046(045)Unsigned Integer L(01)
          dummy_byte, dummy_byte ,// Used to display a dry standard serial numbers in a menu:40047(046)String L(02)
          dummy_byte, dummy_byte ,
          dummy_byte, dummy_byte ,// Used to display operator initials in menus:40049(048)String L(02)
          dummy_byte, dummy_byte ,
          dummy_byte, dummy_byte ,// The value of the wet standard used in a verification:40051(050)Float L(02)
          dummy_byte, dummy_byte ,
          dummy_byte, dummy_byte ,// Measured value during a verification using a calibration plate:40053(052)Float L(02)
          dummy_byte, dummy_byte ,
          dummy_byte, dummy_byte ,// :40055(054) L(01)
          dummy_byte, dummy_byte ,// :40056(055) L(01)
          dummy_byte, dummy_byte ,// :40057(056) L(01)
          dummy_byte, dummy_byte ,// :40058(057) L(01)
          dummy_byte, dummy_byte ,// turbidity A/D counts:40059(058)Unsigned Integer L(02)
          dummy_byte, dummy_byte ,//
          E171_Setting5          ,// Maximum number of decimal places (0=x.xxxx, 1=xx.xxx, 2=xxx.xx):40061(060)Unsigned Integer L(01)
          dummy_byte, dummy_byte ,// Pass / Fail criteria for verification.  (1 to 10 percent):40062(061)Unsigned Integer L(01)
          dummy_byte, dummy_byte ,// Hold the abort query result for decision making:40063(062)Unsigned Integer L(01)
          dummy_byte, dummy_byte ,// :40064(063) L(01)
          E171_Setting8 // Used to detemine if the instrument is in the service mode (0 = disabled; 1= enabled):40065(064)Unsigned Integer L(01)

        }
    }
}
//------------------------ Write Anfang--------------------------------------

COMMAND write_E171_Unit1
{
	SLOT E171_SLOTADR;
	INDEX 3;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              E171_Unit1
        }
        REPLY
        {

        }
    }
}

COMMAND write_E171_Setting1  //Bubble Reject	40017   Bubble reject status (0=OFF; 1=ON)
{
	SLOT E171_SLOTADR;
	INDEX 16;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              E171_Setting1

        }
        REPLY
        {

        }
    }
}

COMMAND write_E171_Setting2  //Datalog Interval	40026  Datalog interval (0=5sec;
{
	SLOT E171_SLOTADR;
	INDEX 25;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              E171_Setting2
        }
        REPLY
        {

        }
    }
}



COMMAND write_E171_Setting3  //Sensor Name	40027 Sensor name or location (8)
{
	SLOT E171_SLOTADR;
	INDEX 26;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              E171_Setting3
        }
        REPLY
        {

        }
    }
}

COMMAND write_E171_Setting4  //SIGNAL AVG	40035 Signal Average (0=1sec; 1=6sec;
{
	SLOT E171_SLOTADR;
	INDEX 34;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              E171_Setting4
        }
        REPLY
        {

        }
    }
}

COMMAND write_E171_Setting5
{
	SLOT E171_SLOTADR;
	INDEX 60;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              E171_Setting5
        }                   
        REPLY
        {

        }
    }
}

COMMAND write_E171_Setting6
{
	SLOT E171_SLOTADR;
	INDEX 6;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              E171_Setting6
        }
        REPLY
        {

        }
    }
}


COMMAND write_E171_Setting8
{
	SLOT E171_SLOTADR;
	INDEX 64;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              E171_Setting8
        }
        REPLY
        {

        }
    }
}
//------------------------ Write Ende--------------------------------------


