/*------------------------------------------------------------------*/
/*	Copyright (C)	Hach-Lange (2010). All Rights Reserved.	   		*/	
/*	Product:		SIMATIC PDM  			   						*/
/*	Device:			SC1000 SC100 DP/V1     		   					*/
/*	Description:		Device Description	           				*/
/*	Dictionary:		SIPADC01.dct			   						*/
/*  $Revision:		1.0  $				   							*/
/*  $Date:			Maerz 2010			   							*/
/*	File:			CG1_pH_ORP.inc		           					*/
/*	Author:			T.Thiel Hach-Lange                 				*/
/*				R.Mellows Hach-Lange               					*/
/*				R.Stollenwerk Hach-Lange           					*/
/*------------------------------------------------------------------*/


/************************************************************************/
/*		Variables														*/
/************************************************************************/


//------------FLOAT--- ANFANG
VARIABLE CG1_Measurement1
{
	LABEL 	"pH/Orp Measurement" 	"|de|pH/Redox Messwert ";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

}


VARIABLE CG1_Measurement3
{
	LABEL 	"Temperature Value" 	"|de|Temperatur";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;


}
VARIABLE CG1_Setting6
{
	LABEL 	"Temperature Manual" 	"|de|Temp Handwert";
	HELP 	"Used when Temp Element = Manual";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;


}
VARIABLE CG1_Diag8
{
	LABEL 	"pH Slope" 	"|de|pH Steilheit";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"mV/pH";
}

 VARIABLE CG1_Setting15
{
	LABEL 	"H2O Comp.User Value" 	"|de|H2O Komp. Handwert";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;


}




//------------FLOAT--- ENDE


VARIABLE CG1_Diag1
{
	LABEL 	"Sensor in operation time" 			"|de|Sensorbetriebszeit";
	HELP 	"Sensor Livetime";
	CLASS	DYNAMIC;
	TYPE	UNSIGNED_INTEGER (2)
		{

		}
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Days" "|de|Tage";
}

VARIABLE CG1_Diag2
{
	LABEL 	"Calibration Warning" 			"|de|Kalibrierwarnung";
	HELP 	"Preset Value for Cal. Warning";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{

			MIN_VALUE		0 ;
			MAX_VALUE		32000 ;
			DEFAULT_VALUE 		30;

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Days" "|de|Tage";
}


VARIABLE CG1_Diag3
{
	LABEL 	"Sensor Warning" 			"|de|Sensorwarnung";
	HELP 	"Preset Value for Sensor Replacement Warning";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{

			MIN_VALUE		0 ;
			MAX_VALUE		32000 ;
			DEFAULT_VALUE 		365;

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Days" "|de|Tage";
}

VARIABLE CG1_Diag4
{
	LABEL 	"Electrode running time" 			"|de|Elektrodenlaufzeit";
	CLASS	DYNAMIC;
	TYPE	UNSIGNED_INTEGER (2)
		{

		}
	HANDLING	READ ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Days" "|de|Tage";
}

VARIABLE CG1_Diag5
{
	LABEL 	"Sensor Log Interv." 			"|de|Sensor Loggerintervall";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			MIN_VALUE		0 ;
			MAX_VALUE		43200 ;
			DEFAULT_VALUE 0;
			{0,			"Off"		"|de|Aus"},
			{5,			"5 Sec"		"|de|5 s"},
			{10,			"10 Sec"	"|de|10 s"},
			{15,			"15 Sec"	"|de|15 s"},
			{30,			"30 Sec"	"|de|30 s"},
			{60,			"1 Min"		"|de|1 Min"},
			{300,			"5 Min"		"|de|5 Min"},
			{600,			"10 Min"	"|de|10 Min"},
			{900,			"15 Min"	"|de|15 Min"},
			{1800,			"30 Min"	"|de|30 Min"},
			{3600,			"1 Hr"	        "|de|1 h"},
			{7200,			"2 Hr"	        "|de|2 h"},
			{21600,			"6 Hr"	        "|de|6 h"},
			{43200,			"12 Hr"	        "|de|12 h"}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE CG1_Diag6
{
	LABEL 	"Temp. Log Interv." 			"|de|Temperatur Loggerintervall";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			MIN_VALUE		0 ;
			MAX_VALUE		43200 ;
			DEFAULT_VALUE 0;
			{0,			"Off"		"|de|Aus"},
			{5,			"5 Sec"		"|de|5 s"},
			{10,			"10 Sec"	"|de|10 s"},
			{15,			"15 Sec"	"|de|15 s"},
			{30,			"30 Sec"	"|de|30 s"},
			{60,			"1 Min"		"|de|1 Min"},
			{300,			"5 Min"		"|de|5 Min"},
			{600,			"10 Min"	"|de|10 Min"},
			{900,			"15 Min"	"|de|15 Min"},
			{1800,			"30 Min"	"|de|30 Min"},
			{3600,			"1 Hr"	        "|de|1 h"},
			{7200,			"2 Hr"	        "|de|2 h"},
			{21600,			"6 Hr"	        "|de|6 h"},
			{43200,			"12 Hr"	        "|de|12 h"}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE CG1_Diag7
{
	LABEL 	"Electrode Status" 			"|de|Elektrodenstatus";
	CLASS	DYNAMIC;
	TYPE	ENUMERATED (2)
		{
			DEFAULT_VALUE 0;
			{0,			"Bad"		"|de|Schlecht"},
			{1,			"Good"		"|de|Gut"}

		}
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}



VARIABLE CG1_Unit5
{
	LABEL 	"Temperature Unit"			"|de|Temperatureinheit";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			DEFAULT_VALUE 25;
			MIN_VALUE		25 ;
			MAX_VALUE		26 ;

			{25,			"C"   	},
			{26,			"F"     }


		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}


UNIT Select_unit_T		// dynymic unit relation
{
	CG1_Unit5:
	CG1_Measurement3,
	CG1_Setting6
}


VARIABLE CG1_Setting1
{
	LABEL 	"Measurement Mode" 	"|de|Betriebsart";
	CLASS	DYNAMIC;
	TYPE	ENUMERATED (2)
		{
			MIN_VALUE		0 ;
			MAX_VALUE		1 ;
			DEFAULT_VALUE 		0 ;

			{0,			"pH" 			"|de|pH" 		},
			{1,			"Orp" 			"|de|Redox"		}

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE CG1_Setting2
{
	LABEL 	"Filter"	"|de|Daempfung";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
        {

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Sec" "|de|s";
}

VARIABLE CG1_Setting3

{
	LABEL 	"pH Resolution" "|de|pH Auflsung";
	HELP	"Maximum number of decimal places";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{

			{0,		"xx.xx"	},
			{1,		"xx.x"	}

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}



VARIABLE CG1_Setting5
{
	LABEL 	"Temp Element" 	"|de|Temperaturelement";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{

			MIN_VALUE		0 ;
			MAX_VALUE		4 ;

			{0,		"PT100" 	"|de|PT100" 	},
			{1,		"PT1000"        "|de|PT1000"	},
			{2,		"NTC300" 	"|de|NTC300" 	},
			{4,		"Manual" 	"|de|Manuell" 	}

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE CG1_Setting7
{
	LABEL 	"pH Buffer" 		"|de|pH Buffer";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			MIN_VALUE		0 ;
			MAX_VALUE		1 ;
			DEFAULT_VALUE 		0 ;
			{0,		"4,7,10" 	 	},
			{1,		"DIN 19267"         	}

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}


VARIABLE CG1_Setting9
{
	LABEL 	"AC Frequency" 	"|de|Netzfrequenz";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{

			MIN_VALUE		0 ;
			MAX_VALUE		1 ;
			DEFAULT_VALUE 		1 ;
			{0,		"60 Hz" 	 	},
			{1,		"50 Hz"         	}


		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}


VARIABLE CG1_Setting11
{
	LABEL 	"pH Buffer" 		"|de|pH Buffer";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			MIN_VALUE		0 ;
			MAX_VALUE		1 ;
			DEFAULT_VALUE 		0 ;
			{0,		"4,7,10" 	 	},
			{1,		"DIN 19267"         	}

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE CG1_Setting12
{
	LABEL 	"Pure H2O Compensation Type" 		"|de|Reinwasser Kompensationstyp";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			MIN_VALUE		0 ;
			MAX_VALUE		8 ;
			DEFAULT_VALUE 		0;
			{0,		"None" 	 		"|de|Kein"},
			{1,		"Ammonia"        	"|de|Ammoniak"},
			{2,		"Morpholine" 	 	"|de|Morpholin"},
			{3,		"Pure water"        	"|de|Reinwasser"},
			{4,		"Matrix 1"  		 },
			{5,		"Matrix 2"        	 },
			{6,		"Matrix 3"  		 },
			{7,		"Matrix 4"        	 },
			{8,		"User defined"        	"|de|Benutzerdefiniert"}

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE CG1_Setting13
{
	LABEL 	"Impedance Check" 	"|de|Impedanzmessung";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			MIN_VALUE		0 ;
			MAX_VALUE		1 ;
			DEFAULT_VALUE 		0 ;
			{0,		"disabeld" 	 	"|de|deaktiviert"},
			{1,		"enabled"         	"|de|aktiviert"}


		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}






VARIABLE CG1_SampleLocation
{
	LABEL 	"Probe Location" "|de|Einbauort";
	CLASS	CONTAINED;
	TYPE	ASCII (12)
		{
			DEFAULT_VALUE "";
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

//---EDD2DTM Dummy Byte-----
 VARIABLE dummy_byte
{
	LABEL "dummy";
	TYPE ASCII(1);
	CLASS LOCAL;

}

/************************************************************************/
/*		READ COMMANDS						*/
/************************************************************************/

COMMAND read_CG1_Float01
{
	SLOT CG1_SLOTADR;
	INDEX 1;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          CG1_Measurement1 ,// pH /Orp Measurement:40002(001)Float L(02)
          dummy_byte,dummy_byte ,// Temperature Measurement Tag:40004(003)Integer L(01)
          dummy_byte,dummy_byte ,// Temperature Measurement :40005(004)Float L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte ,// Sensor Name:40007(006)String L(06)
          dummy_byte,dummy_byte ,
          dummy_byte,dummy_byte ,
          dummy_byte,dummy_byte ,
          dummy_byte,dummy_byte ,
          dummy_byte,dummy_byte ,
          dummy_byte,dummy_byte ,// Function Code tag:40013(012)Integer L(01)
          dummy_byte,dummy_byte ,// Next State Tag:40014(013)Integer L(01)
          dummy_byte,dummy_byte ,// Measurement Type-pH or Orp:40015(014)Integer L(01)
          dummy_byte,dummy_byte ,// Temperature Units-C or F:40016(015)Integer L(01)
          dummy_byte,dummy_byte ,// pH Display Format:40017(016)Integer L(01)
          dummy_byte,dummy_byte ,// pH Display Tagged Format:40018(017)Unsigned Integer L(02)
          dummy_byte,dummy_byte ,
          dummy_byte,dummy_byte ,// Sensor Filter:40020(019)Integer L(01)
          dummy_byte,dummy_byte ,// Temeperature Element Type:40021(020)Integer L(01)
          dummy_byte,dummy_byte ,// Temperature User Value Tag:40022(021)Integer L(01)
          dummy_byte,dummy_byte ,// Temperature User Value:40023(022)Float L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte ,// pH Buffer Type:40025(024)Integer L(01)
          dummy_byte,dummy_byte ,// Pure H2O Compensation Type:40026(025)Integer L(01)
          dummy_byte,dummy_byte ,// Pure H2O Compensation User Val:40027(026)Float L(02)
          dummy_byte,dummy_byte ,
          dummy_byte,dummy_byte ,// Output Mode:40029(028)Integer L(01)
          dummy_byte,dummy_byte ,// Cal Leave Mode:40030(029)Integer L(01)
          dummy_byte,dummy_byte ,// Cal Abort Mode:40031(030)Integer L(01)
          dummy_byte,dummy_byte ,// Cal Edit Value Tag:40032(031)Integer L(01)
          dummy_byte,dummy_byte ,// Cal Edit Value:40033(032)Float L(02)
          dummy_byte,dummy_byte ,
          dummy_byte,dummy_byte ,// pH Slope:40035(034)Float L(02)
          dummy_byte,dummy_byte ,
          dummy_byte,dummy_byte // Software Version:40037(036)String L(06)
        }
    }
}

COMMAND read_CG1_Float02
{
	SLOT CG1_SLOTADR;
	INDEX 4;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
CG1_Measurement3 ,// Temperature Measurement :40005(004)Float L(02)
dummy_byte,dummy_byte ,// Sensor Name:40007(006)String L(06)
dummy_byte,dummy_byte ,
dummy_byte,dummy_byte ,
dummy_byte,dummy_byte ,
dummy_byte,dummy_byte ,
dummy_byte,dummy_byte ,
dummy_byte,dummy_byte ,// Function Code tag:40013(012)Integer L(01)
dummy_byte,dummy_byte ,// Next State Tag:40014(013)Integer L(01)
dummy_byte,dummy_byte ,// Measurement Type-pH or Orp:40015(014)Integer L(01)
dummy_byte,dummy_byte ,// Temperature Units-C or F:40016(015)Integer L(01)
dummy_byte,dummy_byte ,// pH Display Format:40017(016)Integer L(01)
dummy_byte,dummy_byte ,// pH Display Tagged Format:40018(017)Unsigned Integer L(02)
dummy_byte,dummy_byte ,
dummy_byte,dummy_byte ,// Sensor Filter:40020(019)Integer L(01)
dummy_byte,dummy_byte ,// Temeperature Element Type:40021(020)Integer L(01)
dummy_byte,dummy_byte ,// Temperature User Value Tag:40022(021)Integer L(01)
CG1_Setting6 ,// Temperature User Value:40023(022)Float L(02)
dummy_byte,dummy_byte ,// pH Buffer Type:40025(024)Integer L(01)
dummy_byte,dummy_byte ,// Pure H2O Compensation Type:40026(025)Integer L(01)
CG1_Setting15,// Pure H2O Compensation User Val:40027(026)Float L(02)
dummy_byte,dummy_byte ,// Output Mode:40029(028)Integer L(01)
dummy_byte,dummy_byte ,// Cal Leave Mode:40030(029)Integer L(01)
dummy_byte,dummy_byte ,// Cal Abort Mode:40031(030)Integer L(01)
dummy_byte,dummy_byte ,// Cal Edit Value Tag:40032(031)Integer L(01)
dummy_byte,dummy_byte ,// Cal Edit Value:40033(032)Float L(02)
dummy_byte,dummy_byte ,
CG1_Diag8, // pH Slope:40035(034)Float L(02)
dummy_byte,dummy_byte ,// Software Version:40037(036)String L(06)
dummy_byte,dummy_byte ,
dummy_byte,dummy_byte ,
dummy_byte,dummy_byte

        }
    }
}

COMMAND read_CG1_Var01
{
	SLOT CG1_SLOTADR;
	INDEX 6;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          CG1_SampleLocation ,// Sensor Name:40007(006)String L(06)
          dummy_byte,dummy_byte ,// Function Code tag:40013(012)Integer L(01)
          dummy_byte,dummy_byte ,// Next State Tag:40014(013)Integer L(01)
          dummy_byte,dummy_byte ,// Measurement Type-pH or Orp:40015(014)Integer L(01)
          dummy_byte,dummy_byte ,// Temperature Units-C or F:40016(015)Integer L(01)
          CG1_Setting3 ,// pH Display Format:40017(016)Integer L(01)
          dummy_byte,dummy_byte ,// pH Display Tagged Format:40018(017)Unsigned Integer L(02)
          dummy_byte,dummy_byte ,
          CG1_Setting2 ,// Sensor Filter:40020(019)Integer L(01)
          CG1_Setting5,// Temeperature Element Type:40021(020)Integer L(01)
          dummy_byte,dummy_byte ,// Temperature User Value Tag:40022(021)Integer L(01)
          dummy_byte,dummy_byte ,// Temperature User Value:40023(022)Float L(02)
          dummy_byte,dummy_byte ,
          CG1_Setting11,  // pH Buffer Type:40025(024)Integer L(01)
          CG1_Setting12 // Pure H2O Compensation Type:40026(025)Integer L(01)
        }
    }
}

COMMAND read_CG1_Var03
{
	SLOT CG1_SLOTADR;
	INDEX 15;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          CG1_Unit5 // Temperature Units-C or F:40016(015)Integer L(01)
        }
    }
}

COMMAND read_CG1_Var04
{
	SLOT CG1_SLOTADR;
	INDEX 14;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          CG1_Setting1 // Measurement Type-pH or Orp:40015(014)Integer L(01)
        }
    }
}

COMMAND read_CG1_Var02
{
	SLOT CG1_SLOTADR;
	INDEX 53;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          CG1_Diag5 ,// Sensor Data Log Interval:40054(053)Integer L(01)
          CG1_Diag6 ,// Temperature Data Log Interval:40055(054)Integer L(01)
          dummy_byte,dummy_byte ,// pH mV:40056(055)Float L(02)
          dummy_byte,dummy_byte ,
          dummy_byte,dummy_byte ,// Production Date:40058(057)Unsigned Integer L(02)
          dummy_byte,dummy_byte ,
          dummy_byte,dummy_byte ,// Standard Electrode Impedance:40060(059)Float L(02)
          dummy_byte,dummy_byte ,
          dummy_byte,dummy_byte ,// Reference Electrode Impedance:40062(061)Float L(02)
          dummy_byte,dummy_byte ,
          dummy_byte,dummy_byte ,// Last Calibration Date:40064(063)Unsigned Integer L(02)
          dummy_byte,dummy_byte ,
          CG1_Diag1 ,// Sensor Running Days:40066(065)Integer L(01)
          CG1_Diag4 ,// Electrode Running Days:40067(066)Integer L(01)
          CG1_Diag7 ,// Electrode Status:40068(067)Integer L(01)
          dummy_byte,dummy_byte ,// Sensor Type:40069(068)Integer L(01)
          CG1_Setting9 ,// Reject Frequency:40070(069)Integer L(01)
          dummy_byte,dummy_byte ,// Device Driver:40071(070)String L(05)
          dummy_byte,dummy_byte ,
          dummy_byte,dummy_byte ,
          dummy_byte,dummy_byte ,
          dummy_byte,dummy_byte ,
          CG1_Diag2 ,// Calibration Warning Days:40076(075)Integer L(01)
          CG1_Diag3 ,// Sensor Warning Days:40077(076)Integer L(01)
          dummy_byte,dummy_byte ,// Senor Adc Counts:40078(077)Integer L(02)
          dummy_byte,dummy_byte ,
          dummy_byte,dummy_byte ,// Temperature Adc Counts:40080(079)Integer L(02)
          dummy_byte,dummy_byte ,// Set User Temperature:40082(081)Float L(02)
          dummy_byte,dummy_byte ,
          dummy_byte,dummy_byte ,// Minimum User Temperature value:40084(083)Float L(02)
          dummy_byte,dummy_byte ,
          dummy_byte,dummy_byte ,// Maximum User Temperature Value :40086(085)Float L(02)
          dummy_byte,dummy_byte ,
          CG1_Setting13 // Imedance Measuring Ckt Enabled(1):40088(087)Integer L(01)

        }
    }
}

//---------------------------------------------------------------------------


/************************************************************************/
/*		WRITE COMMANDS						*/
/************************************************************************/


COMMAND write_CG1_SampleLocation
{
	SLOT CG1_SLOTADR;
	INDEX 6;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CG1_SampleLocation
        }
        REPLY
        {

        }
    }
}


COMMAND write_CG1_Setting1
{
	SLOT CG1_SLOTADR;
	INDEX 14;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CG1_Setting1

        }
        REPLY
        {
            
        }
    }
}



COMMAND write_CG1_Unit5
{
	SLOT CG1_SLOTADR;
	INDEX 15;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CG1_Unit5
        }
        REPLY
        {

        }
    }
}

COMMAND write_CG1_Setting2
{
	SLOT CG1_SLOTADR;
	INDEX 19;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CG1_Setting2
        }
        REPLY
        {

        }
    }
}
COMMAND write_CG1_Setting3
{
	SLOT CG1_SLOTADR;
	INDEX 16;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CG1_Setting3
        }
        REPLY
        {

        }
    }
}

COMMAND write_CG1_Setting5
{
	SLOT CG1_SLOTADR;
	INDEX 20;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CG1_Setting5
        }
        REPLY
        {

        }
    }
}

COMMAND write_CG1_Setting6
{
	SLOT CG1_SLOTADR;
	INDEX 22;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CG1_Setting6
        }
        REPLY
        {

        }
    }
}

COMMAND write_CG1_Setting11
{
	SLOT CG1_SLOTADR;
	INDEX 24;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CG1_Setting11
        }
        REPLY
        {

        }
    }
}

COMMAND write_CG1_Setting12
{
	SLOT CG1_SLOTADR;
	INDEX 25;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CG1_Setting12
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_CG1_Setting15
{
	SLOT CG1_SLOTADR;
	INDEX 26;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CG1_Setting15
        }
        REPLY
        {
            
        }
    }
}


COMMAND write_CG1_Diag5
{
	SLOT CG1_SLOTADR;
	INDEX 53;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CG1_Diag5
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_CG1_Diag6
{
	SLOT CG1_SLOTADR;
	INDEX 54;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CG1_Diag6
        }
        REPLY
        {
            
        }
    }
}


COMMAND write_CG1_Setting9
{
	SLOT CG1_SLOTADR;
	INDEX 69;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CG1_Setting9
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_CG1_Diag2
{
	SLOT CG1_SLOTADR;
	INDEX 75;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CG1_Diag2
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_CG1_Diag3
{
	SLOT CG1_SLOTADR;
	INDEX 76;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CG1_Diag3
        }
        REPLY
        {

        }
    }
}


COMMAND write_CG1_Setting13
{
	SLOT CG1_SLOTADR;
	INDEX 87;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CG1_Setting13
        }
        REPLY
        {
            
        }
    }
}





