/*--------------------------------------------------------------*/
/*Copyright (C)	Hach-Lange (2010). All Rights Reserved.    	    */
/*Product:	SIMATIC PDM  	           			                */
/*Device:	SC200 Phosphax     	           	                    */
/*Description:	Device Description	           		            */
/*Dictionary:	SIPADC01.dct	           			            */
/*$Revision:	1.0 $  	           			                    */
/*$Date:	Maerz 2010	           			                    */
/*File:		SC200_Phosphax.ddl      			                */
/*Author:	R.Stollenwerk  Hach-Lange	       	    			*/
/*                                                    	        */
/*--------------------------------------------------------------*/

MANUFACTURER	213,
DEVICE_TYPE	    1,
DEVICE_REVISION 1,
DD_REVISION     0

#define DEVICE_TITLE	"SC200 Phosphax"

#define Phosphax1_SLOTADR 21

#define READ_TIMEOUT_VAL 0
#define WRITE_TIMEOUT_VAL 0


#include	"SI_FileM.inc"	//Siemens include Menu_File
#include	"SI_OptM.inc"	//Siemens include Menu_S_Options
#include	"SI_HlpM.inc"	//Siemens include Menu_Help
#include	"SI_DevM.inc"	//Siemens include std_LoadinDevice, std_LoadinPC



//---Dummy Byte-----
 VARIABLE dummy_byte
{
	LABEL "dummy";
	TYPE ASCII(1);
	CLASS LOCAL;
}


#include	"Phosp.inc"	// first device
/************************************************************************/
/*      Methoden                                                        */
/************************************************************************/
METHOD METHOD_WOX1
{
	LABEL "Without1 0x";
	DEFINITION
	{
	DD_STRING Serial_str1,Serial_str2,Serial_str3;
	unsigned int zw;
	unsigned int s1,s2,s3,s4;

        zw=Serial1;
        s1=zw>>12;
        zw=zw-(s1<<12);
        s2=zw>>8;
        zw=zw-(s2<<8);
        s3=zw>>4;
        zw=zw-(s3<<4);
        s4=zw;
	Serial_str1=itoa(s1)+itoa(s2)+itoa(s3)+itoa(s4);

        zw=Serial2;
        s1=zw>>12;
        zw=zw-(s1<<12);
        s2=zw>>8;
        zw=zw-(s2<<8);
        s3=zw>>4;
        zw=zw-(s3<<4);
        s4=zw;
        Serial_str2=itoa(s1)+itoa(s2)+itoa(s3)+itoa(s4);

        zw=Serial3;
        s1=zw>>12;
        zw=zw-(s1<<12);
        s2=zw>>8;
        zw=zw-(s2<<8);
        s3=zw>>4;
        zw=zw-(s3<<4);
        s4=zw;
        Serial_str3=itoa(s1)+itoa(s2)+itoa(s3)+itoa(s4);

        Serial1_WOX= Serial_str1+Serial_str2+Serial_str3;

	}

}


/************************************************************************/
/*---------------------Variablen----------------------------------------*/
/************************************************************************/
//--Lokale Seriennummer ohne 0x--
VARIABLE Serial1_WOX
{
	LABEL 	"Serial Number" 	"|de|Seriennummer";
	TYPE	ASCII (16)
		{
		DEFAULT_VALUE "0000000000000000";
		}

	CLASS LOCAL;

}
VARIABLE VendorName
{
	LABEL 	"Vendor Name""|de|Geraetehersteller";
	CLASS	CONTAINED;
	TYPE	ASCII (12)
		{
			DEFAULT_VALUE "Hach-Lange";
		}
	HANDLING	READ;
}

VARIABLE ModelName
{
	LABEL 	"Fieldbus type" "|de|Feldbustyp";
	CLASS	CONTAINED;
	TYPE	ASCII (14)
		{
			DEFAULT_VALUE "DP/V1";
		}
	HANDLING	READ;
}

VARIABLE ModelNummer
{
	LABEL 	"Model Number""|de|Model Nummer";
	CLASS	CONTAINED;
	TYPE	ASCII (15)
		{
			DEFAULT_VALUE "";
		}
	HANDLING	READ;
}
VARIABLE Serial1
{
	LABEL 	"Serial No 1" 	"|de|Seriennummer 1";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{

		}
	HANDLING	READ;

}

VARIABLE Serial2
{
	LABEL 	"Serial No 2" 	"|de|Seriennummer 2";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{

		}
	HANDLING	READ;

}

VARIABLE Serial3
{
	LABEL 	"Serial No 3" 	"|de|Seriennummer 3";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{

		}
	HANDLING	READ;
        POST_READ_ACTIONS
          {
            METHOD_WOX1

          }
  }

VARIABLE ManufactID1
{
	LABEL 	"Manufacturer ID" 	"|de|Herstellerkennung";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{

		}
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE DeviceID1
{
	LABEL 	"Device ID" 	"|de|Geraetekennung";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{

			{10,			"3798 Cond"		},
			{12,			"LDO"			},
			{13,			"1720E"			},
			{17,			"pHD SC"		},
			{18,			"5740 DO"		},
			{19,			"34xx Cont. Cond."	},
			{20,			"37xx Ind. Cond."	},
			{21,			"pH SC"				},
			{26,   			"Surface Scatter 7" },
			{39,   			"SC200"   			},  
			{101,			"ULTRATURB SC"		},
			{102,			"Nitratax eco"  	},
			{103,			"Nitratax plus"		},
			{104,			"Solitax SC"    	},
			{105,			"Nitratax clear"	},
			{106,			"UVAS plus"     	},
			{107,			"S::CAN CARBO::LYZER"	},
			{108,			"S::CAN NITRO::LYZER"   },
			{109,			"PHOSPHAX SC"     	},
			{110,			"AMTAX SC"     	 	},
			{112,			"NH4D SC"     		},
			{113,			"SONATAX SC"     	},
			{114,			"PHOSPHAX SC"     	},
			{120,   		"NO3D SC"           }

		}
	HANDLING	READ;
}

VARIABLE Length1
{
	LABEL 	"Length Member table" 	"|de|Lnge Teilnehmertabelle";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{

		}
	HANDLING	READ;
}

VARIABLE Status1
{
	LABEL 	"Status";
	STYLE "MULTILINE 22 17";
	CLASS	DYNAMIC;
	TYPE	BIT_ENUMERATED (2)
	{

		{0,   	"OK"						"|de|OK"	 		 },
		{1,   	"Calibration start / in progress"		"|de|Kalibrierung aktiv"	 },
		{2,   	"Cleaning start / in progress"			"|de|Reinigungszyklus aktiv"	 },
		{4,   	"Enter(d) Service/Maintenance menu"		"|de|Betriebsart Service"	 },
		{8,   	"Common Error"					"|de|Sammelstrung"		 },
		{16,   	"Measurement 0 Quality Bad"			"|de|Messung 0 Qualittsfehler"	 },
		{32,   	"Measurement 0 low limit"			"|de|Messung 0 unterer Grenzwert"},
		{64,    "Measurement 0 high limit"			"|de|Messung 0 oberer Grenzwert" },
		{128,   "Measurement 1 Quality Bad"			"|de|Messung 1 Qualittsfehler"	 },
		{256,   "Measurement 1 low limit"			"|de|Messung 1 unterer Grenzwert"},
		{512,   "Measurement 1 high limit"			"|de|Messung 1 oberer Grenzwert" },
		{1024,  "Measurement 2 Quality Bad"			"|de|Messung 2 Qualittsfehler"	 },
		{2048,  "Measurement 2 low limit"			"|de|Messung 2 unterer Grenzwert"},
		{4096,  "Measurement 2 high limit"			"|de|Messung 2 oberer Grenzwert" },
		{8192,  "Measurement 3 Quality Bad"			"|de|Messung 3 Qualittsfehler"	 },
		{16384, "Measurement 3 low limit"			"|de|Messung 3 unterer Grenzwert"},
		{32768, "Measurement 3 high limit"			"|de|Messung 3 oberer Grenzwert" }

	}
	HANDLING	READ;
}

VARIABLE Error1
{
	LABEL	"Error Detection"		"|de|Fehlermeldung";
	CLASS	DYNAMIC;
	STYLE "MULTILINE 22 17";
	TYPE	BIT_ENUMERATED (2)
	{
			{0,   	"No Error"				"|de|Kein Fehler"			},
			{1,   	"Measurement calibration Error"		"|de|Kalibrierfehler"			},
			{2,   	"Electronic adjustment Error"		"|de|Elektronik / Einstellfehler"	},
			{4,   	"Cleaning Error"			"|de|Reinigungsfehler"			},
			{8,   	"Measuring module Error"		"|de|Messmodulfehler"			},
			{16,   	"Settings Error"			"|de|Fehler Einstellungen"		},
			{32,   	"Hardware Error"			"|de|Hardwarefehler"			},
			{64,    "Internal communication Error"		"|de|Interner Kommunikationsfehler"	},
			{128,   "Humidity Error"			"|de|Feuchtigkeit erkannt"		},
			{256,   "Temperatur Error"			"|de|Temperaturfehler"			},
			{512,   ""										},
			{1024,  ""										},
			{2048,  ""										},
			{4096,  "Questionable measurement Warning"	"|de|Warnung Messwert unsicher"		},
			{8192,  "Safety Warning"			"|de|Warnung Sicherheitseinrichtung"	},
			{16384, "Reagent Warning"			"|de|Warnung Reagenz"			},
			{32768, "Maintenance Warning"			"|de|Warnung Instandhaltung"		}

	}
	HANDLING	READ;
}


/************************************************************************/
/*-----------------------COMMANDS---------------------------------------*/
/************************************************************************/
 //----------------------------------------------
//------IDENTIFICATIONS-------------------------
//----------------------------------------------
COMMAND read_VendorName
{
	SLOT 0;
	INDEX 100;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            VendorName
        }
    }
}

COMMAND read_ModelName
{
	SLOT 0;
	INDEX 101;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            ModelName
        }
    }
}

COMMAND read_ModelNummer
{
	SLOT 0;
	INDEX 102;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            ModelNummer
        }
    }
}

COMMAND read_MemberTable
{
	SLOT 10;
	INDEX 0;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            Serial1,
            Serial2,
            Serial3,
            DeviceID1,
            ManufactID1,
            Length1,
            Error1,
            Status1
        }
    }
}

/************************************************************************/
/*  Upload from device to PC              Daten lesen vom Gert zum PC  */
/************************************************************************/

MENU download_variables
{
	LABEL	[menu_load_to_PC];
	ITEMS
	{   Serial1,
	    VendorName,
	    ModelName,
	    ModelNummer,
		Phosphax1_MEASURE_VALUE_1,
		Phosphax1_CHANNEL2,
		Phosphax1_ANALYZER_HEATING,
		Phosphax1_APPL,
		Phosphax1_PROCESS_STATE,
		Phosphax1_STRUCTURE,
		Phosphax1_LAST_CHA_FACTOR2,
		Phosphax1_TH9_LAST_TIME,
		Phosphax1_STAT_MODUL_WAR,
		Phosphax1_SEL_ADJ_METHOD		
	}
}


/************************************************************************/
/*  Write from PC to device        Datenschreiben vom PC zum Gert	*/
/************************************************************************/

MENU upload_variables
{
	LABEL	[menu_load_to_device];
	ITEMS
	{
	Phosphax1_CHANNEL1,
	Phosphax1_CHANNEL2,
	Phosphax1_HEATING_ON,
	Phosphax1_HEATING_OFF,
	Phosphax1_BUSACTION_ACTIVE,
	Phosphax1_BUS_ANALY_START,
	Phosphax1_BUS_SERVICE,
	Phosphax1_BUS_CLEANING,
	Phosphax1_BUS_PREPUMP_REA,
	Phosphax1_BUS_PREPUMP_CLEA,
	Phosphax1_BUS_PREPUMP_PRO,
	Phosphax1_BUS_PREPUMP_ALL,
	Phosphax1_GAIN_CORR_1,
	Phosphax1_DISCHARGE_CLEAN,
	Phosphax1_SET_OUTMODE_CLE,
	Phosphax1_SET_OUTMODE_SER,
	Phosphax1_MEAS_UNITS_1,
	Phosphax1_CLEANING_MODULES,
	Phosphax1_INTERVAL,
	Phosphax1_START,
	Phosphax1_SET_INTERVAL,
	Phosphax1_NEW_MODULES,
	Phosphax1_SET_PARAMETER_1,
	Phosphax1_GAIN_CORR_2,
	Phosphax1_SET_PARAMETER_2,
	Phosphax1_MEAS_UNITS_2,
	Phosphax1_FIELDBUS,
	Phosphax1_START_BY_BUS,
	Phosphax1_NUMBER_OF_MEAS,
	Phosphax1_AVERAGE,
	Phosphax1_NO_OF_VALUES_CH1,
	Phosphax1_NO_OF_VALUES_CH2,
	Phosphax1_DISCHARGE_VAL1,
	Phosphax1_DISCHARGE_VAL2,
	Phosphax1_DISCHARGE_BUS,
	Phosphax1_REAG_WARNING,
	Phosphax1_WARNING,
	Phosphax1_OPERATING_HOURS,
	Phosphax1_LAST_CHA_FACTOR1,
	Phosphax1_LAST_CHA_FACTOR2,
	Phosphax1_SAMPLE_DETECTION,
	Phosphax1_STATUS_MODUL_ERR,
	Phosphax1_STAT_MODUL_WAR,
	Phosphax1_EXHAUST_CONTROL,
	Phosphax1_BUBBLE_REJECT,
	Phosphax1_SEL_ADJ_METHOD,
	Phosphax1_EDIT_NAME,
	}
}
/************************************************************************/
/*	  Table: Specialist						*/
/************************************************************************/

MENU Table_Main_Specialist
{
	LABEL	DEVICE_TITLE ;

	ITEMS
	{
	Tab_s_preferences,
	Tab_s_preferencesM1,
	Tab_s_settings,
	Tab_s_diag,
	Tab_s_output_Offline
	}
}
/************************************************************************/
/*	  Main Menus							*/
/************************************************************************/
MENU Menu_Main_Specialist
{
    LABEL		[main_menu];
    ITEMS
    {
        Menu_File,
        Menu_S_Device,
        Menu_S_View,
        Menu_S_Options,
        Menu_Help
    }
}

/************************************************************************/
/*	  Menu: Device							*/
/************************************************************************/
MENU Menu_S_Device   //Menu: Device
{
    LABEL		"Online Menu" "|de|Online Men";
    ITEMS
    {
	Tab_s_preferences,
	Tab_s_preferencesM1,
	Tab_s_settings,
	Tab_s_diag,
	Tab_s_output_Online
    }
}


/************************************************************************/
/*	  Menu: View							*/
/************************************************************************/

MENU Menu_S_View
{
    LABEL		"Monitor" "|de|Beobachten";
    ITEMS
    {
	  Phosphax1_MEASURE_VALUE_1,  
	  Phosphax1_MEASURE_VALUE_2,
	  Status1,
      Error1
    }
}


/************************************************************************/
/*------------------------Online-Windows--------------------------------*/
/************************************************************************/

MENU Tab_s_preferences
{
    LABEL	"Profibus Interface"  "|de|Profibus Schnittstelle";
    ITEMS
    {
		VendorName,
		ModelName,
		ModelNummer
    }
}

MENU Tab_s_preferencesM1
{
    LABEL	"SC device"  "|de|SC Gert";
    ITEMS
    {
		DeviceID1,
		Serial1_WOX  (READ_ONLY),
		Phosphax1_EDIT_NAME,
    }
}

MENU Tab_s_output_Offline
{
	LABEL	"Output" "|de|Ausgang";
	ITEMS
	{
		Phosphax1_MEASURE_VALUE_1,
		Phosphax1_PHOSPHATE_P_1,
		Phosphax1_PHOS_PENTOXIDE1,
		Phosphax1_PHOSPHATE_1,
		Phosphax1_MEASURE_VALUE_2,
		Phosphax1_PHOSPHATE_P_2,
		Phosphax1_PHOS_PENTOXIDE2,
		Phosphax1_PHOSPHATE_2
    }						
}

MENU Tab_s_output_Online
{
	LABEL	"Output" "|de|Ausgang";
	ITEMS
	{
		Phosphax1_MEASURE_VALUE_1,
		Phosphax1_PHOSPHATE_P_1,
		Phosphax1_PHOS_PENTOXIDE1,
		Phosphax1_PHOSPHATE_1,
		Phosphax1_MEASURE_VALUE_2,
		Phosphax1_PHOSPHATE_P_2,
		Phosphax1_PHOS_PENTOXIDE2,
		Phosphax1_PHOSPHATE_2
	}
}

MENU Tab_s_diag
{
	LABEL	"Diagnostics" "|de|Diagnose";
	ITEMS
	{
//		DEF_GROUP_Phosphax_TEMP_NAME(1),
//		DEF_GROUP_Phosphax_KUEHL_NAME(1),
//		DEF_GROUP_Phosphax_FEUCHT_NAME(1),
//		DEF_GROUP_Phosphax_ZUSTAND_NAME(1),
//		DEF_Tab_Tab_Phosphax_Diag_ProbeInfo(1,0),
//		DEF_Tab_Tab_Phosphax_Diag_Counter(1,0),
//		DEF_Tab_Tab_Phosphax_Diag_Data(1,0),
//		DEF_Tab_Tab_Phosphax_Diag_WarnErr(1,0)
	}
}

MENU Tab_s_settings
{
	LABEL	"Settings" "|de|Einstellungen";
	ITEMS
	{
//		DEF_Tab_Tab_Phosphax_Settings_Base(1,0),
//		DEF_Tab_Tab_Phosphax_Settings_Calibration(1,0),
//		DEF_Tab_Tab_Phosphax_Settings_Fieldbus(1,0),										  					  					  
	}
}

