/*-----------------------------------------------------------------*/
/*	Copyright (C)	Hach-Lange (2011). All Rights Reserved.	   */
/*	Product:		SIMATIC PDM  			   */
/*	Device:			SC CLx10 Chlorine Analyzer	   */
/*	Description:		Device Description	           */
/*	Dictionary:		SIPADC01.dct			   */
/*  	$Revision:		0.1  $				   */
/*  	$Date:			June 2011			   */
/*	File:			SC200_CL1_CLx10.inc		   */
/*	Author:			T.Thiel Hach-Lange	           */
/*-----------------------------------------------------------------*/

/************************************************************************/
/*		Variablen						*/
/************************************************************************/



METHOD METHOD_WAIT
{
	LABEL "Update Settings";
	DEFINITION
	{
	DELAY (3, "Reload");
	}

}

VARIABLE CL1_Measurement1
{
	LABEL 	"pH Value" 	"|de|Messwert pH";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"pH";
}

VARIABLE CL1_Measurement2
{
	LABEL 	"Temperature" 	"|de|Temperatur";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";

}

UNIT Select_unit
{
	CL1_Unit_temp:
	CL1_Measurement2

}

VARIABLE CL1_Measurement3
{
	LABEL 	"Chlorine conc." 	"|de|Chlor";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"ppm mg/l";
}

VARIABLE CL1_Measurement4
{
	LABEL 	"Chlorine conc." 	"|de|Chlor";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"mg/l";
}

VARIABLE CL1_Measurement5
{
	LABEL 	"Chlorine conc." 	"|de|Chlor";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"ppb g/l";
}

VARIABLE CL1_Measurement6
{
	LABEL 	"Chlorine conc." 	"|de|Chlor";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"g/l";
}


VARIABLE CL1_Unit
{
	LABEL 	"Chlorine Unit" 			"|de|Einheit Chlor";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			{0,			"AUTO ppb-ppm"		},
			{1,			"AUTO g/l-mg/l"	},
			{2,			"FIXED ppm"  		},
			{3,			"FIXED mg/l"  		}
						
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE CL1_Unit_temp
{
	LABEL 	"Temperature Unit" 			"|de|Einheit Temperatur";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			{25,			"C"	},
			{26,			"F"	},

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	POST_WRITE_ACTIONS
				
		{
			METHOD_WAIT
				
          	}
}

VARIABLE CL1_Resolution
{
	LABEL 	"CL2 Display Format" 			"|de|CL Darstellung";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			{0,			"X.XXXX"	},
			{1,			"XX.XXX"	},
			{2,			"XXX.XX"   	},
			{3,			"XXXX.X"   	}
			
						
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE CL1_Parameter
{
	LABEL 	"CL2 Parameter" 	"|de|CL2 Parameter";
	CLASS	DYNAMIC;
	TYPE	ENUMERATED (2)
		{
			{0,			"Total CL" 	"|de|gesammt CL" 	},
			{1,			"Free CL" 	"|de|freies CL"		}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE CL1_pH_connected
{
	LABEL 	"pH sensor connected" 	"|de|pH Sensor angeschlossen";
	CLASS	DYNAMIC;
	TYPE	ENUMERATED (2)
		{
			{0,			"YES" 	"|de|JA" 	},
			{1,			"NO" 	"|de|NEIN"	}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE CL1_pH_type
{
	LABEL 	"pH sensor type" 	"|de|pH Sensortyp";
	CLASS	DYNAMIC;
	TYPE	ENUMERATED (2)
		{
			{0,			"Differential pH" 	},
			{1,			"Combination pH" 	}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE CL1_Correction
{
	LABEL 	"Factor "               "|de|Korrekturfaktor ";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  1.0;
			
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}



VARIABLE CL1_Offset
{
	LABEL 	"Offset Value"            "|de|Offsetwert";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  0.0;
			
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"mNTU";
}

VARIABLE CL1_Integration
{
	LABEL 	"CL2 Averaging"	"|de|CL2 Mittelwert in Sekunden";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
        {
		MIN_VALUE		0.0 ;
		MAX_VALUE		60  ;
	
		
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Seconds" "|de|Sekunden";
}

VARIABLE CL1_Integration_pH
{
	LABEL 	"pH Averaging"	"|de|pH Mittelwert in Sekunden";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
        {
		MIN_VALUE		0.0 ;
		MAX_VALUE		60  ;
	
		
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Seconds" "|de|Sekunden";
}

VARIABLE CL1_Integration_temp
{
	LABEL 	"Temp. Averaging"	"|de|Temp. Mittelwert in Sekunden";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
        {
		MIN_VALUE		0.0 ;
		MAX_VALUE		60  ;
	
		
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Seconds" "|de|Sekunden";
}

VARIABLE CL1_LogInterval
{
	LABEL 	"CL2 Data Log Interval" "|de|CL2 Datenloggerinteval";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{

		{0,	"OFF"					},
		{1,	"10 Sec"				},
		{2,	"30 Sec"				},
		{3,	"1 Minute"			    	},
		{4,	"5 Minutes"				},
		{5,	"15 Minutes"				},
		{6,	"60 Minutes"				}

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE CL1_LogInterval_pH
{
	LABEL 	"pH Data Log Interval" "|de|pH Datenloggerinteval";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{

		{0,	"OFF"					},
		{1,	"10 Sec"				},
		{2,	"30 Sec"				},
		{3,	"1 Minute"			    	},
		{4,	"5 Minutes"				},
		{5,	"15 Minutes"				},
		{6,	"60 Minutes"				}

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE CL1_LogInterval_temp
{
	LABEL 	"Temp Data Log Interval" "|de|Temp Datenloggerinteval";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{

		{0,	"OFF"					},
		{1,	"10 Sec"				},
		{2,	"30 Sec"				},
		{3,	"1 Minute"			    	},
		{4,	"5 Minutes"				},
		{5,	"15 Minutes"				},
		{6,	"60 Minutes"				}

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE CL1_Gain
{
	LABEL 	"Gain Value" 	"|de|Verstaerkunsfaktor";
	CLASS	CONTAINED;
	TYPE	FLOAT
	        {
				DEFAULT_VALUE  0.0;
				
	        }
	HANDLING	READ;
	DISPLAY_FORMAT 	".2f";
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
	
	
}

VARIABLE CL1_Flow
{
	LABEL 	"Flow Indicator" "|de|Durchflussueberwachung";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
        {
	
		MIN_VALUE		0 ;
		MAX_VALUE		1 ;
		{0,	"FLOW - OK"		},
		{1,	"NO FLOW !"		}
	
        }
	HANDLING	READ;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
	
}

VARIABLE CL1_SensorDays_CL
{
	LABEL 	"Days since CL sensor installation" "|de|Tage seit CL Sensorinstal.";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
        {
	
        }
	HANDLING	READ;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Days" "|de|Tage";
}

VARIABLE CL1_SensorDays_pH
{
	LABEL 	"Days since pH sensor installation" "|de|Tage seit pH Sensorinstal.";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
        {
	
        }
	HANDLING	READ;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Days" "|de|Tage";
}

VARIABLE CL1_CalDays_CL
{
	LABEL 	"Days since last CL calibration" "|de|Tage seit CL Kalibrierung";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
        {
	
        }
	HANDLING	READ;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Days" "|de|Tage";
}

VARIABLE CL1_CalDays_pH
{
	LABEL 	"Days since last pH calibration" "|de|Tage seit pH Kalibrierung";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
        {
	
        }
	HANDLING	READ;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Days" "|de|Tage";
}

VARIABLE CL1_CalMon
{
	LABEL 	"Calibratin Monitor" "|de|Kalibrierueberwachung";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
	        {
			MIN_VALUE				0 ;
			MAX_VALUE				3 ;
			{0,	"ALL"				},
			{1,	"CL2 ONLY"			},
			{2,	"pH ONLY"			},
			{3,	"NONE"				}		
	
	        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;

}

VARIABLE CL1_SelRange
{
	LABEL 	"Range Selection" "|de|Messbereich";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
	        {
		
			{0,	"0 - 10 ppm"		}
					
	
	        }
	HANDLING	READ;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;

}

VARIABLE CL1_pH_ConfLev
{
	LABEL 	"Confidence Level pH monitor CL/pH ONLY" ;
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
	        {
		MIN_VALUE			 -50;
		MAX_VALUE			  95;
	
	
	        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"%" ;

}

VARIABLE CL1_ALL_ConfLev
{
	LABEL 	"Confidence Level pH monitor ALL" ;
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
	        {
		MIN_VALUE			-50 ;
		MAX_VALUE			 95 ;
	
	
	        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"%" ;

}

VARIABLE CL1_LCC_ConfLev
{
	LABEL 	"Confidence Level pH monitor LCC" ;
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
	        {
		MIN_VALUE			 -50 ;
		MAX_VALUE			  95 ;
	
	
	        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"%" ;
	POST_WRITE_ACTIONS
			
		{
			METHOD_WAIT
			
          	}

}

VARIABLE CL1_SampleLocation
{
	LABEL 	"Probe Location" "|de|Einbauort";
	CLASS	CONTAINED;
	TYPE	ASCII (12)
		{
			DEFAULT_VALUE "";
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
	POST_WRITE_ACTIONS
				
		{
			METHOD_WAIT
				
          	}

}

VARIABLE CL1_SettingBlock_1
{
	LABEL 	"Setting data block I"	;
	CLASS	INPUT & OUTPUT;
	TYPE	INTEGER (22)
        {
	
        }
	HANDLING	READ & WRITE;

}

VARIABLE CL1_SettingBlock_2
{
	LABEL 	"Setting data block II"	;
	CLASS	INPUT & OUTPUT;
	TYPE	INTEGER (12)
        {
	
        }
	HANDLING	READ & WRITE;
	
}



/************************************************************************/
/*		COMMANDS														*/
/************************************************************************/

COMMAND read_CL1_SettingBlock_1
{
	SLOT 21;
	INDEX 19;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
	
        }
        REPLY
        {
            CL1_pH_connected,
            CL1_Unit,
            CL1_Resolution,
            CL1_Integration,
            CL1_LogInterval,
            CL1_CalMon,
            0,
            0,
            CL1_SelRange,
            CL1_Parameter,
            0,
            0,
            CL1_pH_ConfLev,
            CL1_ALL_ConfLev,
            CL1_LCC_ConfLev
        }
    }
}

COMMAND write_CL1_SettingBlock_1
{
	SLOT 21;
	INDEX 19;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
            CL1_pH_connected,
            CL1_Unit,
            CL1_Resolution,
            CL1_Integration,
            CL1_LogInterval,
            CL1_CalMon,
            0,
            0,
            CL1_SelRange,
            CL1_Parameter,
            0,
            0,
            CL1_pH_ConfLev,
            CL1_ALL_ConfLev,
            CL1_LCC_ConfLev
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_CL1_SettingBlock_2
{
	SLOT 21;
	INDEX 45;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {

        }
        REPLY
        {
            CL1_Integration_pH,
            CL1_LogInterval_pH,
            CL1_pH_type,
            0,
            0,
            CL1_Integration_temp,
            CL1_LogInterval_temp,
            CL1_Unit_temp

        }
    }
}

COMMAND write_CL1_SettingBlock_2
{
	SLOT 21;
	INDEX 45;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
            CL1_Integration_pH,
            CL1_LogInterval_pH,
            CL1_pH_type,
            0,
            0,
            CL1_Integration_temp,
            CL1_LogInterval_temp,
            CL1_Unit_temp
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_CL1_Measurement1
{
	SLOT 21;
	INDEX 0;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            CL1_Measurement1
        }
    }
}

COMMAND read_CL1_Measurement2
{
	SLOT 21;
	INDEX 2;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            CL1_Measurement2
        }
    }
}

COMMAND read_CL1_Measurement3
{
	SLOT 21;
	INDEX 4;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            CL1_Measurement3
        }
    }
}

COMMAND read_CL1_Measurement5
{
	SLOT 21;
	INDEX 6;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            CL1_Measurement5
        }
    }
}


COMMAND read_CL1_Flow
{
	SLOT 21;
	INDEX 11;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
//            0,
//            0,
            CL1_Flow
        }
    }
}


COMMAND read_CL1_Offset
{
	SLOT 21;
	INDEX 21;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            
            CL1_Offset
        }
    }
}



COMMAND write_CL1_Offset
{
	SLOT 21;
	INDEX 21;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CL1_Offset
        }
        REPLY
        {
            
        }
    }
}




COMMAND read_CL1_SensorDays_CL
{
	SLOT 21;
	INDEX 92;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {

            CL1_SensorDays_CL
        }
    }
}


COMMAND read_CL1_CL1_SensorDays_pH
{
	SLOT 21;
	INDEX 121;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {

            CL1_SensorDays_pH
        }
    }
}



COMMAND read_CL1_CalDays_CL
{
	SLOT 21;
	INDEX 99;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            

            CL1_CalDays_CL
        }
    }
}




COMMAND read_CL1_CalDays_pH
{
	SLOT 21;
	INDEX 101;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {

            CL1_CalDays_pH
        }
    }
}



COMMAND read_CL1_SampleLocation
{
	SLOT 21;
	INDEX 13;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            
            CL1_SampleLocation
        }
    }
}

COMMAND write_CL1_SampleLocation
{
	SLOT 21;
	INDEX 13;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CL1_SampleLocation
        }
        REPLY
        {
            
        }
    }
}

