/*------------------------------------------------------------------*/
/*	Copyright (C)	Hach-Lange (2010). All Rights Reserved.	   		*/	
/*	Product:		SIMATIC PDM  			   						*/
/*	Device:			SC1000 SC100 DP/V1     		   					*/
/*	Description:		Device Description	           				*/
/*	Dictionary:		SIPADC01.dct			   						*/
/*  	$Revision:		1.9  $				   						*/
/*  	$Date:			Maerz 2010			   						*/
/*	File:			C1_ContactCond.inc		   						*/
/*	Author:			T.Thiel Hach-Lange                 				*/
/*				R.Mellows Hach-Lange               					*/
/*				R.Stollenwerk Hach-Lange           					*/
/*------------------------------------------------------------------*/


/************************************************************************/
/*		Variables						*/
/************************************************************************/



VARIABLE CC1_Measurement1
{
	LABEL 	"Output Value" 	"|de|Messwert ";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;


}


VARIABLE CC1_Measurement3
{
	LABEL 	"Temperature Value" 	"|de|Temperatur";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;


}

VARIABLE CC1_Diag1
{
	LABEL 	"Temp A/D Counts" 	"|de|Temperatur A/D Wert";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"Count";
}

VARIABLE CC1_Diag2
{
	LABEL 	"Sensor A/D Counts" 	"|de|Sensor A/D Wert";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"Count";
}

VARIABLE CC1_Diag3
{
	LABEL 	"Calculated temp Ohms" 	"|de|Berechneter Widerstand Temp";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"Ohm";
}

VARIABLE CC1_Diag4
{
	LABEL 	"Raw temperature" 	"|de|Temperatur Rohwert";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;


}

VARIABLE CC1_Diag5
{
	LABEL 	"Sensor Log Interv." 			"|de|Sensor Logger";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			DEFAULT_VALUE 0;
			{0,			"Off"		"|de|Aus"},
			{5,			"5 sec"		"|de|5 s"},
			{10,			"10 sec"	"|de|10 s"},
			{15,			"15 sec"	"|de|15 s"},
			{30,			"30 sec"	"|de|30 s"},
			{60,			"1 Min"		"|de|1 min"},
			{300,			"5 Min"		"|de|5 min"},
			{900,			"15 Min"	"|de|15 min"},
			{1800,			"30 Min"	"|de|30 min"},
			{3600,			"1 hr"	        "|de|1 h"},
			{7200,			"2 hr"	        "|de|2 h"},
			{21600,			"6 hr"  	"|de|6 h"},
			{43200,			"12 hr"	        "|de|12 h"}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE CC1_Diag6
{
	LABEL 	"Temp.Log Interv." 			"|de|Temperatur Logger";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			DEFAULT_VALUE 0;
			{0,			"Off"		"|de|Aus"},
			{5,			"5 sec"		"|de|5 s"},
			{10,			"10 sec"	"|de|10 s"},
			{15,			"15 sec"	"|de|15 s"},
			{30,			"30 sec"	"|de|30 s"},
			{60,			"1 Min"		"|de|1 min"},
			{300,			"5 Min"		"|de|5 min"},
			{900,			"15 Min"	"|de|15 min"},
			{1800,			"30 Min"	"|de|30 min"},
			{3600,			"1 hr"	        "|de|1 h"},
			{7200,			"2 hr"	        "|de|2 h"},
			{21600,			"6 hr"  	"|de|6 h"},
			{43200,			"12 hr"	        "|de|12 h"}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}



VARIABLE CC1_Unit1
{
	LABEL 	"Conductivity Unit" 			"|de|Einheit LF";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			DEFAULT_VALUE 50;
			{50,			"S/cm"	},
			{51,			"mS/cm"	}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE CC1_Unit2
{
	LABEL 	"Resistivity Unit" 			"|de|Einheit Widerstand";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			DEFAULT_VALUE 36;
			{36,			"k Ohm"	},
			{37,			"M Ohm" }

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE CC1_Unit3
{
	LABEL 	"TDS Unit" 			"|de|Einheit TDS";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			DEFAULT_VALUE 2;

			{2,			"ppm"	},
			{38,			"ppb"   }


		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE CC1_Unit4
{
	LABEL 	"Salinity Unit" 			"|de|Einheit Salzgehalt";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			DEFAULT_VALUE 31;
			{31,			"ppt"	}



		}
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}



VARIABLE CC1_Unit5
{
	LABEL 	"Temperature Unit"			"|de|Einheit Temperatur";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			DEFAULT_VALUE 25;

			{25,			"C"   	},
			{26,			"F"     }


		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}


UNIT Select_unit_T		// dynymic unit relation
{
	CC1_Unit5:
	CC1_Measurement3,
	CC1_Setting8,
	CC1_Diag4

}



VARIABLE CC1_Setting1
{
	LABEL 	"Measurement Mode" 	"|de|Betriebsart";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			{0,			"Conductivity" 		"|de|Leitfaehigkeit" 	},
			{1,			"Resistivity" 		"|de|Widerstand"	},
			{2,			"TDS" 			"|de|TDS" 	        },
			{3,			"Salinity" 		"|de|Salzgehalt"	}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE CC1_Setting2
{
	LABEL 	"Filter/Averaging"	"|de|Filter/Mittelwert";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
        {

        }
	CONSTANT_UNIT 	"sec" "|de|s";
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE CC1_Setting3
{
	LABEL 	"Set Cell K"	"|de|Zellenkonstante";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {


        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}


VARIABLE CC1_Setting4
{
	LABEL 	"Select Cell K" 	"|de|Auswahl Zellenkonstante";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			{0,		"0.01" 		 	},
			{1,		"0.05" 	        	},
			{2,		"0.10" 			},
			{3,		"0.50" 			},
			{4,		"1.0 HACH" 	       	},
			{7,		"1.0 Polimetron" 	},
			{5,		"5.0" 		 	},
			{6,		"10.0" 			}
		}
	HANDLING	READ ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE CC1_Setting5
{
	LABEL 	"Temp Element" 	"|de|Temperaturelement";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			{0,		"Manual" 	"|de|Manuell" 	},
			{1,		"Pt100"         "|de|Pt100"	},
			{2,		"Pt1000" 	"|de|Pt1000" 	}

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE CC1_Setting6
{
	LABEL 	"Temperature Manual" 	"|de|Temp Handwert";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"C";
}

VARIABLE CC1_Setting7
{
	LABEL 	"Temp.Comp.Slope" 	"|de|Temp Steilheit";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"%/C";
}

VARIABLE CC1_Setting8
{
	LABEL 	"Temp.Comp Reference" 	"|de|Referenztemperatur";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;


}

VARIABLE CC1_Setting9
{
	LABEL 	"AC Frequency" 	"|de|Netzfrequenz";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			{0,		"50 Hz" 	 	},
			{1,		"60 Hz"         	}


		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE CC1_Setting10

{
	LABEL 	"Resolution" "|de|Auflsung";
	HELP	"Maximum number of decimal places";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{

	{0,	"x.xxx"   },
	{1,	"xx.xx"    },
	{2,	"xxx.x"    },
	{3,	"xxxx"    }

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE CC1_SampleLocation
{
	LABEL 	"Probe Location" "|de|Einbauort";
	CLASS	CONTAINED;
	TYPE	ASCII (12)
		{
			DEFAULT_VALUE "";
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//---EDD2DTM Dummy Byte-----
 VARIABLE dummy_byte
{
	LABEL "dummy";
	TYPE ASCII(1);
	CLASS LOCAL;

}


/************************************************************************/
/*		COMMANDS						*/
/************************************************************************/
COMMAND read_CC1_Float01
{
	SLOT 21;
	INDEX 2;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
CC1_Measurement1, // Sensor Measurement:40003(002)Float L(02)
CC1_Measurement3, // Temperature Measurement:40005(004)Float L(02)
dummy_byte, dummy_byte, // Minimum Meas. Value:40007(006)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // Maximum Meas. Value:40009(008)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // Display Format:40011(010)Unsigned Integer L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // Siemens Units:40013(012)Unsigned Integer L(01)
dummy_byte, dummy_byte, // Ohm Units:40014(013)Unsigned Integer L(01)
dummy_byte, dummy_byte, // TDS Units:40015(014)Unsigned Integer L(01)
dummy_byte, dummy_byte, // Salinity Units:40016(015)Unsigned Integer L(01)
dummy_byte, dummy_byte, // Degress C/F = 0/1:40017(016)Unsigned Integer L(01)
dummy_byte, dummy_byte, // Conductivity/Resistivity/TDS/Salinity = 0/1/2/3:40018(017)Unsigned Integer L(01)
dummy_byte, dummy_byte, // User Selected Display Format:40019(018)Unsigned Integer L(01)
dummy_byte, dummy_byte, // Number of samples to Average:40020(019)Unsigned Integer L(01)
dummy_byte, dummy_byte, // TDS Configuration:40021(020)Unsigned Integer L(01)
dummy_byte, dummy_byte, // TDS Multiplier:40022(021)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // Cell Constant Value:40024(023)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // Minimum Cell Constant Value:40026(025)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // Maximum Cell Constant Value:40028(027)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // Cell Constant Selection,0.01,0.05,0.1,0.5,1.0.5.0,10.0:40030(029)Unsigned Integer L(01)
dummy_byte, dummy_byte, // Temp. Comp. Menu 1:40031(030)Unsigned Integer L(01)
dummy_byte, dummy_byte, // Temp. Comp. Menu 2:40032(031)Unsigned Integer L(01)
CC1_Setting7, // Temp. Comp. Slope:40033(032)Float L(02)
CC1_Setting8, // Temp. Comp. Ref. Temp:40035(034)Float L(02)
dummy_byte, dummy_byte, // :40037(036) L(01)
dummy_byte, dummy_byte // :40038(037) L(01)

        }
    }
}

COMMAND read_CC1_Float02
{
	SLOT 21;
	INDEX 23;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
CC1_Setting3, // Cell Constant Value:40024(023)Float L(02)
dummy_byte, dummy_byte, // Minimum Cell Constant Value:40026(025)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // Maximum Cell Constant Value:40028(027)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // Cell Constant Selection,0.01,0.05,0.1,0.5,1.0.5.0,10.0:40030(029)Unsigned Integer L(01)
dummy_byte, dummy_byte, // Temp. Comp. Menu 1:40031(030)Unsigned Integer L(01)
dummy_byte, dummy_byte, // Temp. Comp. Menu 2:40032(031)Unsigned Integer L(01)
dummy_byte, dummy_byte, // Temp. Comp. Slope:40033(032)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // Temp. Comp. Ref. Temp:40035(034)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // :40037(036) L(01)
dummy_byte, dummy_byte, // :40038(037) L(01)
dummy_byte, dummy_byte, // :40039(038) L(01)
dummy_byte, dummy_byte, // :40040(039) L(01)
dummy_byte, dummy_byte, // Temp. Element - Manual,Pt100, Pt1000 = 0/1/2:40041(040)Unsigned Integer L(01)
dummy_byte, dummy_byte, // Temp. Element Offset:40042(041)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // :40044(043) L(01)
dummy_byte, dummy_byte, // :40045(044) L(01)
dummy_byte, dummy_byte, // :40046(045) L(01)
dummy_byte, dummy_byte, // :40047(046) L(01)
CC1_Setting6, // Temp. Manual Temperature:40048(047)Float L(02)
dummy_byte, dummy_byte, // Output Mode During Calibration - Active/Hjold/Transfer = 0/1/2:40050(049)Unsigned Integer L(01)
dummy_byte, dummy_byte, // :40051(050) L(01)
dummy_byte, dummy_byte, // Calib. Value:40052(051)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // Name of Sensor:40054(053)String L(06)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte

        }
    }
}

COMMAND read_CC1_Float03
{
	SLOT 21;
	INDEX 80;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
CC1_Diag1, // A/D Counts for Temperature:40081(080)Float L(02)
CC1_Diag2, // A/D Counts for Sensor:40083(082)Float L(02)
CC1_Diag3, // Calculated ohms of Temp. Sensor:40085(084)Float L(02)
dummy_byte, dummy_byte, // Autorange if set to 0:40087(086)Unsigned Integer L(01)
dummy_byte, dummy_byte, // Gain setting of Sensor - 0/1/2:40088(087)Unsigned Integer L(01)
dummy_byte, dummy_byte, // A/D Counts for Gain Level 0:40089(088)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // A/D Counts for Gain Level 1:40091(090)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // A/D Counts for Gain Level 2:40093(092)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // :40095(094) L(01)
dummy_byte, dummy_byte, // :40096(095) L(01)
dummy_byte, dummy_byte, // :40097(096) L(01)
dummy_byte, dummy_byte, // :40098(097) L(01)
dummy_byte, dummy_byte, // :40099(098) L(01)
dummy_byte, dummy_byte, // :40100(099) L(01)
dummy_byte, dummy_byte, // :40101(100) L(01)
dummy_byte, dummy_byte, // :40102(101) L(01)
dummy_byte, dummy_byte, // :40103(102) L(01)
dummy_byte, dummy_byte, // :40104(103) L(01)
dummy_byte, dummy_byte, // :40105(104) L(01)
dummy_byte, dummy_byte, // :40106(105) L(01)
dummy_byte, dummy_byte, // :40107(106) L(01)
dummy_byte, dummy_byte, // :40108(107) L(01)
dummy_byte, dummy_byte, // :40109(108) L(01)
dummy_byte, dummy_byte, // :40110(109) L(01)
dummy_byte, dummy_byte, // :40111(110) L(01)
dummy_byte, dummy_byte, // :40112(111) L(01)
dummy_byte, dummy_byte, // :40113(112) L(01)
dummy_byte, dummy_byte, // :40114(113) L(01)
dummy_byte, dummy_byte, // :40115(114) L(01)
dummy_byte, dummy_byte // :40116(115) L(01)

        }
    }
}

COMMAND read_CC1_Float04
{
	SLOT 21;
	INDEX 126;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
dummy_byte, dummy_byte, // :40126(125) L(01)
dummy_byte, dummy_byte, // :40127(126) L(01)
dummy_byte, dummy_byte, // :40128(127) L(01)
dummy_byte, dummy_byte, // :40129(128) L(01)
dummy_byte, dummy_byte, // :40130(129) L(01)
dummy_byte, dummy_byte, // :40131(130) L(01)
dummy_byte, dummy_byte, // :40132(131) L(01)
dummy_byte, dummy_byte, // :40133(132) L(01)
dummy_byte, dummy_byte, // :40134(133) L(01)
dummy_byte, dummy_byte, // :40135(134) L(01)
dummy_byte, dummy_byte, // :40136(135) L(01)
dummy_byte, dummy_byte, // :40137(136) L(01)
dummy_byte, dummy_byte, // :40138(137) L(01)
dummy_byte, dummy_byte, // :40139(138) L(01)
dummy_byte, dummy_byte, // :40140(139) L(01)
dummy_byte, dummy_byte, // :40141(140) L(01)
dummy_byte, dummy_byte, // :40142(141) L(01)
dummy_byte, dummy_byte, // :40143(142) L(01)
dummy_byte, dummy_byte, // :40144(143) L(01)
dummy_byte, dummy_byte, // :40145(144) L(01)
dummy_byte, dummy_byte, // 50/60 Hertz Rejection:40146(145)Unsigned Integer L(01)
dummy_byte, dummy_byte, // Driver Version:40147(146)Unsigned Integer L(06)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
CC1_Diag4, // Actual Temperature:40154(153)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte

        }
    }
}

COMMAND read_CC1_Var01
{
	SLOT 21;
	INDEX 10;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
CC1_Unit1, // Siemens Units:40013(012)Unsigned Integer L(01)
CC1_Unit2, // Ohm Units:40014(013)Unsigned Integer L(01)
CC1_Unit3, // TDS Units:40015(014)Unsigned Integer L(01)
CC1_Unit4, // Salinity Units:40016(015)Unsigned Integer L(01)
CC1_Unit5, // Degress C/F = 0/1:40017(016)Unsigned Integer L(01)
CC1_Setting1, // Conductivity/Resistivity/TDS/Salinity = 0/1/2/3:40018(017)Unsigned Integer L(01)
CC1_Setting10, // User Selected Display Format:40019(018)Unsigned Integer L(01)
CC1_Setting2, // Number of samples to Average:40020(019)Unsigned Integer L(01)
dummy_byte, dummy_byte, // TDS Configuration:40021(020)Unsigned Integer L(01)
dummy_byte, dummy_byte, // TDS Multiplier:40022(021)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // Cell Constant Value:40024(023)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // Minimum Cell Constant Value:40026(025)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // Maximum Cell Constant Value:40028(027)Float L(02)
dummy_byte, dummy_byte,
CC1_Setting4, // Cell Constant Selection,0.01,0.05,0.1,0.5,1.0.5.0,10.0:40030(029)Unsigned Integer L(01)
dummy_byte, dummy_byte, // Temp. Comp. Menu 1:40031(030)Unsigned Integer L(01)
dummy_byte, dummy_byte, // Temp. Comp. Menu 2:40032(031)Unsigned Integer L(01)
dummy_byte, dummy_byte, // Temp. Comp. Slope:40033(032)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // Temp. Comp. Ref. Temp:40035(034)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // :40037(036) L(01)
dummy_byte, dummy_byte, // :40038(037) L(01)
dummy_byte, dummy_byte, // :40039(038) L(01)
dummy_byte, dummy_byte, // :40040(039) L(01)
CC1_Setting5 // Temp. Element - Manual,Pt100, Pt1000 = 0/1/2:40041(040)Unsigned Integer L(01)

        }
    }
}

COMMAND read_CC1_Var02
{
	SLOT 21;
	INDEX 53;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
CC1_SampleLocation, // Name of Sensor:40054(053)String L(06)
dummy_byte, dummy_byte, // Version of Driver:40060(059)String L(08)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // Sensor Serial Number:40068(067)String L(06)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // Function Code tag:40074(073)Unsigned Integer L(01)
dummy_byte, dummy_byte, // Next State Tag:40075(074)Unsigned Integer L(01)
dummy_byte, dummy_byte, // Factory Diagnostic:40076(075)Float L(02)
dummy_byte, dummy_byte,
dummy_byte, dummy_byte, // Factory Diagnostic:40078(077)Unsigned Integer L(01)
CC1_Diag5, // Log Interval 0..13=Off/5,10,15,30,60 sec , 5,10,15,30,60 min, 1,2,6,12 hours:40079(078)Unsigned Integer L(01)
CC1_Diag6 // Log Interval 0..13=Off/5,10,15,30,60 sec , 5,10,15,30,60 min, 1,2,6,12 hours:40080(079)Unsigned Integer L(01)

        }
    }
}

COMMAND read_CC1_Var03
{
	SLOT 21;
	INDEX 124;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
dummy_byte, dummy_byte, // :40125(124) L(01)
dummy_byte, dummy_byte, // :40126(125) L(01)
dummy_byte, dummy_byte, // :40127(126) L(01)
dummy_byte, dummy_byte, // :40128(127) L(01)
dummy_byte, dummy_byte, // :40129(128) L(01)
dummy_byte, dummy_byte, // :40130(129) L(01)
dummy_byte, dummy_byte, // :40131(130) L(01)
dummy_byte, dummy_byte, // :40132(131) L(01)
dummy_byte, dummy_byte, // :40133(132) L(01)
dummy_byte, dummy_byte, // :40134(133) L(01)
dummy_byte, dummy_byte, // :40135(134) L(01)
dummy_byte, dummy_byte, // :40136(135) L(01)
dummy_byte, dummy_byte, // :40137(136) L(01)
dummy_byte, dummy_byte, // :40138(137) L(01)
dummy_byte, dummy_byte, // :40139(138) L(01)
dummy_byte, dummy_byte, // :40140(139) L(01)
dummy_byte, dummy_byte, // :40141(140) L(01)
dummy_byte, dummy_byte, // :40142(141) L(01)
dummy_byte, dummy_byte, // :40143(142) L(01)
dummy_byte, dummy_byte, // :40144(143) L(01)
dummy_byte, dummy_byte, // :40145(144) L(01)
CC1_Setting9 // 50/60 Hertz Rejection:40146(145)Unsigned Integer L(01)

        }
    }
}
//------------------------------------------------------



COMMAND write_CC1_Diag5
{
	SLOT 21;
	INDEX 78;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CC1_Diag5
        }
        REPLY
        {

        }
    }
}

COMMAND write_CC1_Diag6
{
	SLOT 21;
	INDEX 79;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CC1_Diag6
        }
        REPLY
        {

        }
    }
}



COMMAND write_CC1_Unit1
{
	SLOT 21;
	INDEX 12;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
            CC1_Unit1
        }
        REPLY
        {

        }
    }
}

COMMAND write_CC1_Unit2
{
	SLOT 21;
	INDEX 13;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {

            CC1_Unit2
        }
        REPLY
        {

        }
    }
}

COMMAND write_CC1_Unit3
{
	SLOT 21;
	INDEX 14;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
            CC1_Unit3
        }
        REPLY
        {

        }
    }
}

COMMAND write_CC1_Unit5
{
	SLOT 21;
	INDEX 16;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
            CC1_Unit5
        }
        REPLY
        {

        }
    }
}

COMMAND write_CC1_Setting1
{
	SLOT 21;
	INDEX 17;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CC1_Setting1
        }
        REPLY
        {

        }
    }
}

COMMAND write_CC1_Setting2
{
	SLOT 21;
	INDEX 19;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CC1_Setting2
        }
        REPLY
        {

        }
    }
}


COMMAND write_CC1_Setting3
{
	SLOT 21;
	INDEX 23;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CC1_Setting3
        }
        REPLY
        {

        }
    }
}




COMMAND write_CC1_Setting5
{
	SLOT 21;
	INDEX 40;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CC1_Setting5
        }
        REPLY
        {

        }
    }
}



COMMAND write_CC1_Setting6
{
	SLOT 21;
	INDEX 47;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CC1_Setting6
        }
        REPLY
        {

        }
    }
}


COMMAND write_CC1_Setting7
{
	SLOT 21;
	INDEX 32;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CC1_Setting7
        }
        REPLY
        {

        }
    }
}


COMMAND write_CC1_Setting8
{
	SLOT 21;
	INDEX 34;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CC1_Setting8
        }
        REPLY
        {

        }
    }
}


COMMAND write_CC1_Setting9
{
	SLOT 21;
	INDEX 145;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CC1_Setting9
        }
        REPLY
        {

        }
    }
}

COMMAND write_CC1_Setting10
{
	SLOT 21;
	INDEX 18;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CC1_Setting10
        }
        REPLY
        {

        }
    }
}

COMMAND write_CC1_SampleLocation
{
	SLOT 21;
	INDEX 53;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              CC1_SampleLocation
        }
        REPLY
        {

        }
    }
}



