/*-----------------------------------------------------------------*/
/*	Copyright (C)	Hach-Lange (2011). All Rights Reserved.	   */
/*	Product:		SIMATIC PDM  			   */
/*	Device:			SC FP360 Oil in Water 		   */
/*	Description:		Device Description	           */
/*	Dictionary:		SIPADC01.dct			   */
/*  	$Revision:		0.1  $				   */
/*  	$Date:			June 2011			   */
/*	File:			SC200_F1_FP360.inc		   */
/*	Author:			T.Thiel Hach-Lange	           */
/*-----------------------------------------------------------------*/

/************************************************************************/
/*		Variablen						*/
/************************************************************************/



VARIABLE F1_Measurement1
{
	LABEL 	"PAH Value ppb" 	"|de|Messwert PAK in ppb";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"ppb g/l";
}

VARIABLE F1_Measurement2
{
	LABEL 	"PAH Value ppm" 	"|de|Messwert PAK in ppm";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"ppm mg/l";
}

VARIABLE F1_Measurement3
{
	LABEL 	"OIL Value ppb" 	"|de|Messwert OEL ppb";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"ppb g/l";
}

VARIABLE F1_Measurement4
{
	LABEL 	"OIL Value ppm" 	"|de|Messwert OEL ppm";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"ppm mg/l";
}



VARIABLE F1_Unit
{
	LABEL 	"Measurement Unit" 			"|de|Einheit ";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			{0,			"mg/l"	},
			{2,			"ppm"	},
			{38,			"ppb"   },
			{39,			"g/l"  }
			
						
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE F1_Calmethod
{
	LABEL 	"Calibration Method" 			"|de|Kalibrierverfahren ";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			{0,			"Factor"	},
			{1,			"Offset"	},
			{2,			"2 Point"   	},
			{3,			"3 Point"   	},
			{4,			"4 Point"  	},
			{5,			"5 Point"  	}
			
						
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE F1_Parameter
{
	LABEL 	"Measurement Mode" 	"|de|Betriebsart";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			{47,			"PAH" 	"|de|PAK" 	},
			{48,			"OIL" 	"|de|OEL"	}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE F1_Correction
{
	LABEL 	"Factor "               "|de|Korrekturfaktor ";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  1.0;
			
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}



VARIABLE F1_Offset
{
	LABEL 	"Offset value"            "|de|Offsetwert";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  0.0;
			
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE F1_Integration
{
	LABEL 	"Averaging"	"|de|Mittelwert in Sekunden";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
        {
	
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Seconds" "|de|Sekunden";
}

VARIABLE F1_LogInterval
{
	LABEL 	"Data Loggger Interval" "|de|Datenloggerinteval";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{

		{5,	"5 Sec."					},
		{30,	"30 Sec"					},
		{60,	"1 Minutes"					},
		{120,	"2 Minutes"			    		},
		{180,	"3 Minutes"	  				},
		{240,	"4 Minutes"					},
		{300,	"5 Minutes"					},
		{360,	"6 Minutes"					},
		{600,	"10 Minutes"					},
		{900,	"15 Minutes"					},
		{1800,	"30 minutes"					}
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE F1_Gain
{
	LABEL 	"Gain Value" 	"|de|Verstaerkunsfaktor";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{
		{0,	"Automatic"		"|de|Automatik"},
		{1,	"0.01-500 PPB"		"|de|0.01-500 PPB"},
		{2,	"0.01-1000 PPB"		"|de|0.01-1000 PPB"}
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	
}

VARIABLE F1_Bulb
{
	LABEL 	"Lamp Change Days Left" "|de|Lampenaustauschzaehler";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
        {
	
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Days" "|de|Tage";
}

VARIABLE F1_Maint
{
	LABEL 	"Next Maintenance/Days Left" "|de|Tage bis Service/Inspektion";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
        {
	
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Days" "|de|Tage";
}

VARIABLE F1_Operating
{
	LABEL 	"Hours of Operation" "|de|Betriebsstunden";
	CLASS	CONTAINED;
	TYPE	INTEGER (4)
	        {
		
	        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Hours" "|de|Stunden";

}

VARIABLE F1_LampCurrent
{
	LABEL 	"Lamp Current" "|de|Lampenstrom";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
        {
	
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"mA" "|de|mA";
}

VARIABLE F1_SampleLocation
{
	LABEL 	"Probe Location" "|de|Einbauort";
	CLASS	CONTAINED;
	TYPE	ASCII (16)
		{
			DEFAULT_VALUE "";
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}


/************************************************************************/
/*		COMMANDS														*/
/************************************************************************/


COMMAND read_F1_Measurement1
{
	SLOT 21;
	INDEX 1;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            F1_Measurement1
        }
    }
}

COMMAND read_F1_Measurement2
{
	SLOT 21;
	INDEX 3;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            F1_Measurement2
        }
    }
}

COMMAND read_F1_Measurement3
{
	SLOT 21;
	INDEX 5;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            F1_Measurement3
        }
    }
}

COMMAND read_F1_Measurement4
{
	SLOT 21;
	INDEX 7;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            F1_Measurement4
        }
    }
}



COMMAND read_F1_Unit
{
	SLOT 21;
	INDEX 30;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {

            F1_Unit
        }
    }
}

COMMAND write_F1_Unit
{
	SLOT 21;
	INDEX 30;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              F1_Unit
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_F1_Calmethod
{
	SLOT 21;
	INDEX 47;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {

            F1_Calmethod
        }
    }
}

COMMAND write_F1_Calmethod
{
	SLOT 21;
	INDEX 47;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              F1_Calmethod
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_F1_Offset
{
	SLOT 21;
	INDEX 39;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            
            F1_Offset
        }
    }
}

COMMAND write_F1_Offset
{
	SLOT 21;
	INDEX 39;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              F1_Offset
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_F1_Correction
{
	SLOT 21;
	INDEX 41;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            
            F1_Correction
        }
    }
}

COMMAND write_F1_Correction
{
	SLOT 21;
	INDEX 41;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              F1_Correction
        }
        REPLY
        {
            
        }
    }
}



COMMAND read_F1_Integration
{
	SLOT 21;
	INDEX 50;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {

            F1_Integration
        }
    }
}

COMMAND write_F1_Integration
{
	SLOT 21;
	INDEX 50;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              F1_Integration
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_F1_LogInterval
{
	SLOT 21;
	INDEX 49;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {

            F1_LogInterval
        }
    }
}

COMMAND write_F1_LogInterval
{
	SLOT 21;
	INDEX 49;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              F1_LogInterval
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_F1_Gain
{
	SLOT 21;
	INDEX 51;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {

            F1_Gain
        }
    }
}

COMMAND write_F1_Gain
{
	SLOT 21;
	INDEX 51;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              F1_Gain
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_F1_Operating
{
	SLOT 21;
	INDEX 67;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
              
        }
        REPLY
        {
        F1_Operating    
        }
    }
}

COMMAND read_F1_Bulb
{
	SLOT 21;
	INDEX 65;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {

            F1_Bulb
        }
    }
}

COMMAND read_F1_Maint
{
	SLOT 21;
	INDEX 66;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {

            F1_Maint
        }
    }
}

COMMAND read_F1_LampCurrent
{
	SLOT 21;
	INDEX 74;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {

            F1_LampCurrent
        }
    }
}


COMMAND read_F1_Parameter
{
	SLOT 21;
	INDEX 29;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {

            F1_Parameter
        }
    }
}

COMMAND write_F1_Parameter
{
	SLOT 21;
	INDEX 29;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
        F1_Parameter
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_F1_SampleLocation
{
	SLOT 21;
	INDEX 21;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            
            F1_SampleLocation
        }
    }
}

COMMAND write_F1_SampleLocation
{
	SLOT 21;
	INDEX 21;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              F1_SampleLocation
        }
        REPLY
        {
            
        }
    }
}

