/*-----------------------------------------------------------------*/
/*	Copyright (C)	Hach-Lange (2011). All Rights Reserved.	   */
/*	Product:		SIMATIC PDM  			   */
/*	Device:			SC FP360 Oil in Water  		   */
/*	Description:		Device Description	           */
/*	Dictionary:		SIPADC01.dct			   */
/*  	$Revision:		0.1  $				   */
/*  	$Date:			June 2011			   */
/*	File:			SC_FP360.ddl     		   */
/*	Author:			T.Thiel Hach-Lange	           */
/*-----------------------------------------------------------------*/

MANUFACTURER		 	213,
DEVICE_TYPE			1,
DEVICE_REVISION  		1,
DD_REVISION			1

#define READ_TIMEOUT_VAL 0
#define WRITE_TIMEOUT_VAL 0
#define DEVICE_TITLE			"SC200 FP360"

#include	"SC200_F1_FP360.inc"	//FP360 first or single sc200 device 

/**********************************************************************/
/*      Method                                                        */
/**********************************************************************/

METHOD METHOD_WOX1
{
	LABEL "Without1 0x";
	DEFINITION
	{
	DD_STRING Serial_str1,Serial_str2,Serial_str3;
	unsigned int zw;
	unsigned int s1,s2,s3,s4;

        zw=Serial1;
        s1=zw>>12;
        zw=zw-(s1<<12);
        s2=zw>>8;
        zw=zw-(s2<<8);
        s3=zw>>4;
        zw=zw-(s3<<4);
        s4=zw;
	Serial_str1=itoa(s1)+itoa(s2)+itoa(s3)+itoa(s4);

        zw=Serial2;
        s1=zw>>12;
        zw=zw-(s1<<12);
        s2=zw>>8;
        zw=zw-(s2<<8);
        s3=zw>>4;
        zw=zw-(s3<<4);
        s4=zw;
        Serial_str2=itoa(s1)+itoa(s2)+itoa(s3)+itoa(s4);

        zw=Serial3;
        s1=zw>>12;
        zw=zw-(s1<<12);
        s2=zw>>8;
        zw=zw-(s2<<8);
        s3=zw>>4;
        zw=zw-(s3<<4);
        s4=zw;
        Serial_str3=itoa(s1)+itoa(s2)+itoa(s3)+itoa(s4);

        Serial1_WOX= Serial_str1+Serial_str2+Serial_str3;

	}

}



/************************************************************************/
/*		Variables						*/
/************************************************************************/

VARIABLE VendorName
{
	LABEL 	"Vendor Name""|de|Geraetehersteller";
	CLASS	CONTAINED;
	TYPE	ASCII (16)
		{
			DEFAULT_VALUE "Hach";
		}
	HANDLING	READ;
}

VARIABLE ModelName
{
	LABEL 	"Fieldbus type" "|de|Profibustyp";
	CLASS	CONTAINED;
	TYPE	ASCII (32)
		{
			DEFAULT_VALUE "SC device";
		}
	HANDLING	READ;
}

VARIABLE ModelNummer
{
	LABEL 	"Model Number""|de|Profibusversion";
	CLASS	CONTAINED;
	TYPE	ASCII (32)
		{
			DEFAULT_VALUE "";
		}
	HANDLING	READ;
}

VARIABLE Serial1
{
	LABEL 	"Serial No 1" 	"|de|Seriennummer 1";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{

		}
	HANDLING	READ;

}

VARIABLE Serial2
{
	LABEL 	"Serial No 2" 	"|de|Seriennummer 2";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{

		}
	HANDLING	READ;

}

VARIABLE Serial3
{
	LABEL 	"Serial No 3" 	"|de|Seriennummer 3";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{

		}
	HANDLING	READ;
        POST_READ_ACTIONS
          {
            METHOD_WOX1

          }
  }

VARIABLE DeviceID1
{
	LABEL 	"Device ID" 	"|de|Geraetekennung";
	CLASS	DYNAMIC;
	TYPE	INTEGER (2)
		{
		
			{12,			"LDO"			},
			{17,			"pHD"			},
			{19,			"34xx Contactact Cond."	},
			{20,			"37xx Inductive Cond."	},
			{41,			"CLF/CLT10"		},
			{101,			"ULTRATURB SC"		},
			{102,			"Nitratax eco"  	},
			{103,			"Nitratax plus"		},
			{104,			"FP360 SC"    		},
			{105,			"Nitratax clear"	},
			{106,			"UVAS plus"     	},
			{107,			"S::CAN CARBO::LYZER"	},
			{108,			"S::CAN NITRO::LYZER"   },
			{109,			"PHOSPHAX SC"     	},
			{109,			"AMTAX SC"     	 	},
			{118,			"FP360 Oil in Water"	},
					
								
		}
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE ManufactID1
{
	LABEL 	"Manufacturer ID" 	"|de|Herstellerkennung";
	CLASS	DYNAMIC;
	TYPE	INTEGER (2)
		{
			
		}
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE Length1
{
	LABEL 	"Length Member table" 	"|de|Lnge Teilnehmertabelle";
	CLASS	DYNAMIC;
	TYPE	INTEGER (2)
		{
			
		}
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE Status1
{
	LABEL 	"FP360 Sensor Status ";
	CLASS	DYNAMIC;
	STYLE   "MULTILINE 22 17";
	TYPE	BIT_ENUMERATED (2)
	{
		
		{0,   	"OK"						"|de|OK"	 		 },
		{1,   	"Calibration start / in progress"		"|de|Kalibrierung aktiv"	 },
		{2,   	"Cleaning start / in progress"			"|de|Reinigungszyklus aktiv"	 },
		{4,   	"Enter(d) Service/Maintenance menu"		"|de|Betriebsart Service"	 },
		{8,   	"Common Error"					"|de|Sammelstrung"		 },
		{16,   	"Measurement 0 Quality Bad"			"|de|Messung 0 Qualittsfehler"	 },
		{32,   	"Measurement 0 low limit"			"|de|Messung 0 unterer Grenzwert"},
		{64,    "Measurement 0 high limit"			"|de|Messung 0 oberer Grenzwert" },
		{128,   "Measurement 1 Quality Bad"			"|de|Messung 1 Qualittsfehler"	 },
		{256,   "Measurement 1 low limit"			"|de|Messung 1 unterer Grenzwert"},
		{512,   "Measurement 1 high limit"			"|de|Messung 1 oberer Grenzwert" },
		{1024,  "Measurement 2 Quality Bad"			"|de|Messung 2 Qualittsfehler"	 },
		{2048,  "Measurement 2 low limit"			"|de|Messung 2 unterer Grenzwert"},	
		{4096,  "Measurement 2 high limit"			"|de|Messung 2 oberer Grenzwert" },
		{8192,  "Measurement 3 Quality Bad"			"|de|Messung 3 Qualittsfehler"	 },
		{16384, "Measurement 3 low limit"			"|de|Messung 3 unterer Grenzwert"},
		{32768, "Measurement 3 high limit"			"|de|Messung 3 oberer Grenzwert" }
					
	}	
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE MemberTable
{
	LABEL 	"Member Table"		"|de|Teilnehmertabelle";
	CLASS	INPUT & OUTPUT;
	TYPE	INTEGER (16)
        {
	
        }
	HANDLING	READ & WRITE;
}

VARIABLE Error1
{
	LABEL	"FP360 Error Message"		"|de|Fehlermeldung";
	CLASS	CONTAINED;
	STYLE   "MULTILINE 22 17";
	TYPE	BIT_ENUMERATED (2)
	{
			{0,   	"No Error"				"|de|Kein Fehler"			},
			{1,   	"Measurement calibration Error"		"|de|Kalibrierfehler"			},
			{2,   	"Electronic adjustment Error"		"|de|Elektronik / Einstellfehler"	},
			{4,   	"Cleaning Error"			"|de|Reinigungsfehler"			},
			{8,   	"Measuring module Error"		"|de|Messmodulfehler"			},
			{16,   	"Settings Error"			"|de|Fehler Einstellungen"		},
			{32,   	"Hardware Error"			"|de|Hardwarefehler"			},
			{64,    "Internal communication Error"		"|de|Interner Kommunikationsfehler"	},
			{128,   "Humidity Error"			"|de|Feuchtigkeit erkannt"		},
			{256,   "Temperatur Error"			"|de|Temperaturfehler"			},
			{512,   ""										},
			{1024,  ""										},
			{2048,  ""										},	
			{4096,  "Questionable measurement Warning"	"|de|Warnung Messwert unsicher"		},
			{8192,  "Safety Warning"			"|de|Warnung Sicherheitseinrichtung"	},
			{16384, "Reagent Warning"			"|de|Warnung Reagenz"			},
			{32768, "Maintenance Warning"			"|de|Warnung Instandhaltung"		},
			{36960, "Sensor Disconnected"			"|de|Sensor Verbindung gestrt"		},
					
	}
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE Profile
{
	LABEL 	"Modbus Profile"	"|de|Modbus Profile";
	CLASS	INPUT & OUTPUT;
	TYPE	INTEGER (42)
        {
	
        }
	HANDLING	READ & WRITE;
}





VARIABLE Errorclasses
{
	LABEL	"Error Classes"		"|de|Fehlerklassen";
	CLASS	CONTAINED;
	TYPE	BIT_ENUMERATED (2)
	{
			{0,   	"No Error"				"|de|Kein Fehler"			},
			{1,   	"Measurement calibration Error"		"|de|Kalibrierfehler"			},
			{2,   	"Electronic adjustment Error"		"|de|Elektronik / Einstellfehler"	},
			{4,   	"Cleaning Error"			"|de|Reinigungsfehler"			},
			{8,   	"Measuring module Error"		"|de|Messmodulfehler"			},
			{16,   	"Settings Error"			"|de|Fehler Einstellungen"		},
			{32,   	"Hardware Error"			"|de|Hardwarefehler"			},
			{64,    "Internal communication Error"		"|de|Interner Kommunikationsfehler"	},
			{128,   "Humidity Error"			"|de|Feuchtigkeit erkannt"		},
			{256,   "Temperatur Error"			"|de|Temperaturfehler"			},
			{512,   ""										},
			{1024,  ""										},
			{2048,  ""										},	
			{4096,  "Questionable measurement Warning"	"|de|Warnung Messwert unsicher"		},
			{8192,  "Safety Warning"			"|de|Warnung Sicherheitseinrichtung"	},
			{16384, "Reagent Warning"			"|de|Warnung Reagenz"			},
			{32768, "Maintenance Warning"			"|de|Warnung Instandhaltung"		}
					
	}
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}




VARIABLE Channel_1
{
	LABEL 	"Channel 1";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
}

VARIABLE Channel_2
{
	LABEL 	"Channel 2";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
}





/************************************************************************/
/*		COMMANDS														*/
/************************************************************************/




COMMAND read_VendorName
{
	SLOT 0;
	INDEX 100;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            VendorName
        }
    }
}

COMMAND read_ModelName
{
	SLOT 0;
	INDEX 101;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            ModelName
        }
    }
}

COMMAND read_ModelNummer
{
	SLOT 0;
	INDEX 102;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            ModelNummer
        }
    }
}


COMMAND read_MemberTable
{
	SLOT 10;
	INDEX 0;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            Serial1,
            Serial2,
            Serial3,
            DeviceID1,
            ManufactID1,
            Length1,
            Error1,
            Status1
        }
    }
}




COMMAND read_Errorclasses
{
	SLOT 1;
	INDEX 0;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {

            Errorclasses
        }
    }
}


 


/************************************************************************/
/*  Upload from device to PC              Daten lesen vom Gert zum PC	*/
/************************************************************************/

MENU download_variables
{
	LABEL	[menu_load_to_PC];
	ITEMS
	{ 
		VendorName,
//		Profile,
		ModelName,
		ModelNummer,
		F1_SampleLocation,
		F1_Measurement1,
		F1_Measurement2,
		F1_Measurement3,
		F1_Measurement4,
		F1_Correction,
		F1_Calmethod,
		F1_Offset,
		F1_Gain,
		F1_Bulb,
		F1_Maint,
		F1_LampCurrent,
		F1_Operating,
		F1_LogInterval,
		F1_Integration,
		F1_Unit,
		F1_Parameter,
		Status1,
		Serial1,
		Serial2,
		Serial3,
		DeviceID1,
		Error1
		
		
		
	}
} 


/************************************************************************/
/*  Write from PC to device        Datenschreiben vom PC zum Gert	*/
/************************************************************************/

MENU upload_variables
{
	LABEL	[menu_load_to_device];
	ITEMS
	{
		F1_SampleLocation,
		F1_Correction,
		F1_Integration,
		F1_LogInterval,
		F1_Unit,
		F1_Calmethod,
		F1_Offset,
		F1_Gain,
		F1_Parameter
	}
}

/************************************************************************/
/*	  Table: Specialist													*/
/************************************************************************/

MENU Table_Main_Specialist
{
	LABEL	DEVICE_TITLE ;

	ITEMS
	{
		Tab_s_preferences,
		Tab_s_preferencesM1,
		Tab_s_settings,
		Tab_s_diag,
		Tab_s_output
	}
}

/************************************************************************/
/*	  Main Menus														*/
/************************************************************************/

/************************************************************************/
/*	  Menu: Bar															*/
/************************************************************************/

MENU Menu_Main_Specialist
{
    LABEL		[main_menu];
    ITEMS
    {
        Menu_File,
        Menu_S_Device,
        Menu_S_View,
        Menu_S_Options,
        Menu_Help
    }
}

/************************************************************************/
/*	  Menu: Device														*/
/************************************************************************/

MENU Menu_S_Device
{
    LABEL		[menu_Device];
    ITEMS
    {
        std_LoadinDevice,
        std_LoadinPC,
        SEPARATOR,
	OnlineWindow_range_preferences,
	OnlineWindow_display
//	OnlineWindow_clean_calib
    }
}

/************************************************************************/
/*	  Menu: View														*/
/************************************************************************/

MENU Menu_S_View
{
    LABEL		[menu_View];
    ITEMS
    {
        
        OnlineWindow_display,
//	OnlineWindow_actual_mode
    }
}

/************************************************************************/
/*	  Online-Windows													*/
/************************************************************************/

MENU OnlineWindow_range_preferences
{
    LABEL	"Settings" "|de|Einstelldaten";
    ITEMS
    {
		Page_range_preferences
    }
}

MENU Page_range_preferences
{
    LABEL	"Settings" "|de|Voreinstellungen" ;
    ITEMS
    	{
		F1_SampleLocation,
		F1_LogInterval,
		F1_Calmethod,
		F1_Correction,
		F1_Offset,
		F1_Integration,
		F1_Unit,
		F1_Parameter,
		F1_Gain
	}
}

MENU OnlineWindow_clean_calib
{
    LABEL	"Values"  	"|de|Messwerte";
    ITEMS
    {
		Page_clean_calib 
    }
}

MENU Page_clean_calib
{
    LABEL	"Service"	"|de|Funktionen";
    ITEMS
    	{
	F1_Measurement1,
	F1_Measurement2,
	F1_Measurement3,
	F1_Measurement4,
	F1_Unit,
	F1_Parameter,
	F1_Gain
	}
}


MENU Tab_s_preferences
{
    LABEL	"SC Interface"  "|de|SC Kommunikation";
    ITEMS
    {
		VendorName,
		ModelName,
		ModelNummer,
				

    }
}

MENU Tab_s_preferencesM1
{
    LABEL	"Identification probe 1"  "|de|SC erstes Gert";
    ITEMS
    {
		DeviceID1,
		Serial1_WOX,
		F1_SampleLocation
			

    }
}

MENU Tab_s_output
{
	LABEL		[menu_output];
	ITEMS
	{
		F1_Measurement1,
		F1_Measurement2,
		F1_Measurement3,
		F1_Measurement4


	}
}

MENU Tab_s_diag
{
	LABEL	"Diagnostics" "|de|Diagnose erstes Gert";
	ITEMS
	{
		Status1,
		Error1,
		F1_Bulb,
		F1_LampCurrent,
		F1_Maint,		
		F1_Operating
	}
}

MENU Tab_s_settings
{
	LABEL	"Settings" "|de|Einstelldaten erstes Gert";
	ITEMS
	{
		F1_Parameter,
		F1_Unit,
		F1_Calmethod,
		F1_Correction,
		F1_Offset,
		F1_Integration,
		F1_LogInterval,
		F1_Gain
				
	}
}


/************************************************************************/
/*	  Table: Maintenance												*/
/************************************************************************/

MENU Table_Main_Maintenance
{
	LABEL	DEVICE_TITLE ;

	ITEMS
	{
		Tab_m_preferences,
		Tab_m_output,
		Tab_m_settings,
		Tab_m_diag
	}
}

/************************************************************************/
/*	  Main Menus														*/
/************************************************************************/

/************************************************************************/
/*	  Menu: Bar															*/
/************************************************************************/

MENU Menu_Main_Maintenance
{
    LABEL		[main_menu];
    ITEMS
    {
        Menu_File,
        Menu_M_Device,
        Menu_M_View,
        //Menu_M_Options,
        Menu_Help
    }
}

/************************************************************************/
/*	  Menu: Device														*/
/************************************************************************/

MENU Menu_M_Device
{
    LABEL		[menu_Device];
    ITEMS
    {
        std_LoadinDevice,
        std_LoadinPC,
        OnlineWindow_display
    }
}

/************************************************************************/
/*	  Menu: View														*/
/************************************************************************/

MENU Menu_M_View
{
    LABEL		[menu_View];
    ITEMS
    {
        OnlineWindow_display,
//	OnlineWindow_actual_mode
    }
}

/************************************************************************/
/*	  Online-Windows													*/
/************************************************************************/

MENU Tab_m_preferences
{
    LABEL	"Overview" "|de|Allgemein";
    ITEMS
    {
		VendorName,
		ModelName,
		ModelNummer,
		Serial1_WOX  (READ_ONLY),
		F1_SampleLocation
		

    }
}

MENU Tab_m_output
{
	LABEL		[menu_output];
	ITEMS
	{
		F1_Measurement1,
		F1_Measurement2,
		F1_Measurement3,
		F1_Measurement4

	}
}

MENU Tab_m_diag
{
	LABEL	"Diagnostics" "|de|Diagnose erstes Gert";
	ITEMS
	{
		Status1,
		Error1,
		F1_Bulb,
		F1_LampCurrent,
		F1_Maint,
		F1_Operating
	}
}

MENU Tab_m_settings
{
	LABEL	"Settings" "|de|Einstelldaten erstes Gert";
	ITEMS
	{
		F1_Unit  		(READ_ONLY),
		F1_Calmethod            (READ_ONLY),
		F1_Correction   	(READ_ONLY),
		F1_Offset		(READ_ONLY),
		F1_Integration		(READ_ONLY),
		F1_LogInterval		(READ_ONLY),
		F1_Gain			(READ_ONLY),
		F1_Parameter		(READ_ONLY)
		
	}
}

MENU OnlineWindow_actual_mode
{
	LABEL	"Current mode" "|de|Aktuell";
	ITEMS
	{
		F1_Measurement1,
		F1_Measurement2,
		F1_Measurement3,
		F1_Measurement4

	}
}

MENU OnlineWindow_display
{
	LABEL	"FP360 Dynamic Display" "|de|FP360 Messwerte";
	ITEMS
	{
		Page_display_func1
	}
}

MENU Page_display_func1
{
	LABEL   "Measured Values" "|de|Messwertanzeigen" ;
	ITEMS
	{
		BarVal_out_display_func1,
		BarVal_out_display_func2,
		BarVal_out_display_func3,
		BarVal_out_display_func4,
		F1_Parameter (READ_ONLY),
		Status1,
		Error1
	}
}


MENU BarVal_out_display_func1
{
	LABEL		"PAH PPB Value" 	"|de|Messwert PAK PPB";
	HELP		[func_ai_out_value_help];
	ITEMS
	{
		F1_Measurement1

	}
}

MENU BarVal_out_display_func2
{
	LABEL		"PAH PPM Value" 	"|de|Messwert PAK PPM";
	HELP		[func_ai_out_value_help];
	ITEMS
	{
		F1_Measurement2

	}
}

MENU BarVal_out_display_func3
{
	LABEL		"Oil PPB Value" 	"|de|Messwert Oel PPB";
	HELP		[func_ai_out_value_help];
	ITEMS
	{
		F1_Measurement3

	}
}

MENU BarVal_out_display_func4
{
	LABEL		"Oil PPM Value" 	"|de|Messwert Oel PPM";
	HELP		[func_ai_out_value_help];
	ITEMS
	{
		F1_Measurement4

	}
}
