/*-----------------------------------------------------------------*/
/*	Copyright (C)	Hach-Lange (2011). All Rights Reserved.	   */
/*	Product:		SIMATIC PDM  			   */
/*	Device:			SC200 FT660 FilterTrak 		   */
/*	Description:		Device Description	           */
/*	Dictionary:		SIPADC01.dct			   */
/*  	$Revision:		0.1  $				   */
/*  	$Date:			June 2011			   */
/*	File:			SC200_FT1_FT660.inc		   */
/*	Author:			T.Thiel Hach-Lange	           */
/*-----------------------------------------------------------------*/

/************************************************************************/
/*		Variablen						*/
/************************************************************************/



VARIABLE FT1_Measurement1
{
	LABEL 	"Turbidity high-res" 	"|de|Messwert mNTU";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"mNTU/mFTU";
}

VARIABLE FT1_Measurement2
{
	LABEL 	"Turbidity low-res" 	"|de|Messwert NTU";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"NTU/FTU/mg/l";
}

VARIABLE FT1_Measurement3
{
	LABEL 	"RSD Relative Standard Deviation" 	"|de|Relative Standard Abweichung";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"%";
}

VARIABLE FT1_Measurement4
{
	LABEL 	"Temperature" 	"|de|Temperatur";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"C";
}



VARIABLE FT1_Unit
{
	LABEL 	"Measurement Unit" 			"|de|Einheit ";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			{0,			"mg/l"	},
			{7,			"NTU"	},
			{20,			"mNTU"  },
			{21,			"mFTU"  },
			{42,			"FTU"   },
			{60,			"DEG"   }
			
						
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE FT1_Resolution
{
	LABEL 	"Resolution" 			"|de|Aufloesung";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			{0,			"X.XXXX"	},
			{1,			"XX.XXX"	},
			{2,			"XXX.XX"   	},
			{3,			"XXXX.X"   	}
			
						
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE FT1_Parameter
{
	LABEL 	"Bubble Reject" 	"|de|Luftblasen-Unterdrueckung";
	CLASS	DYNAMIC;
	TYPE	ENUMERATED (2)
		{
			{0,			"OFF" 	"|de|AUS" 	},
			{1,			"ON" 	"|de|EIN"	}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE FT1_Correction
{
	LABEL 	"Factor "               "|de|Korrekturfaktor ";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  1.0;
			
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}



VARIABLE FT1_Offset
{
	LABEL 	"Offset Value"            "|de|Offsetwert";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  0.0;
			
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"mNTU";
}

VARIABLE FT1_Integration
{
	LABEL 	"Averaging"	"|de|Mittelwert in Sekunden";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
        {
		{0,	"1 Seconds"					},
		{1,	"6 Seconds"					},
		{2,	"30 Seconds"					},
		{3,	"60 Seconds"			    		},
		{4,	"90 Seconds"					}
		
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Seconds" "|de|Sekunden";
}

VARIABLE FT1_LogInterval
{
	LABEL 	"Data Loggger Interval" "|de|Datenloggerinteval";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{

		{0,	"5 Sec."					},
		{1,	"30 Sec"					},
		{2,	"1 Minutes"					},
		{3,	"2 Minutes"			    		},
		{4,	"5 Minutes"					},
		{6,	"10 Minutes"					},
		{7,	"15 Minutes"					},
		{8,	"30 minutes"					},
		{9,	"60 Minutes"					},
		{10,	"4 Hours"					}
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE FT1_Gain
{
	LABEL 	"Gain Value" 	"|de|Verstaerkunsfaktor";
	CLASS	CONTAINED;
	TYPE	FLOAT
	        {
				DEFAULT_VALUE  0.0;
				
	        }
	HANDLING	READ;
	DISPLAY_FORMAT 	".2f";
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	
	
}

VARIABLE FT1_Bulb
{
	LABEL 	"Lamp Change Days Left" "|de|Lampenaustauschzaehler";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
        {
	
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Days" "|de|Tage";
}

VARIABLE FT1_Maint
{
	LABEL 	"Next Maintenance/Days Left" "|de|Tage bis Service/Inspektion";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
        {
	
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Days" "|de|Tage";
}

VARIABLE FT1_Operating
{
	LABEL 	"Hours of Operation" "|de|Betriebsstunden";
	CLASS	CONTAINED;
	TYPE	INTEGER (4)
	        {
		
	        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Hours" "|de|Stunden";

}

VARIABLE FT1_LampCurrent
{
	LABEL 	"Laser Current" "|de|Lampenstrom";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"mA" "|de|mA";
}

VARIABLE FT1_LaserVoltage
{
	LABEL 	"Laser Voltage" "|de|Lampenspannung";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"Volt" "|de|Volt";
}

VARIABLE FT1_5V
{
	LABEL 	"5V DC Supply" "|de|5 V Versorgung";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"Volt" "|de|Volt";
}

VARIABLE FT1_12V
{
	LABEL 	"Input 12V" "|de|12 V Versorgung";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"Volt" "|de|Volt";
}

VARIABLE FT1_15V
{
	LABEL 	"PMT 15V" "|de|15V PMT";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"Volt" "|de|Volt";
}

VARIABLE FT1_RV
{
	LABEL 	"2.5V Reference" "|de|2.5V Rweferenzspannung";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"Volt" "|de|Volt";
}

VARIABLE FT1_SampleLocation
{
	LABEL 	"Probe Location" "|de|Einbauort";
	CLASS	CONTAINED;
	TYPE	ASCII (16)
		{
			DEFAULT_VALUE "";
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}





/************************************************************************/
/*		COMMANDS														*/
/************************************************************************/


COMMAND read_FT1_Measurement1
{
	SLOT 21;
	INDEX 0;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            FT1_Measurement1
        }
    }
}

COMMAND read_FT1_Measurement2
{
	SLOT 21;
	INDEX 2;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            FT1_Measurement2
        }
    }
}

COMMAND read_FT1_Measurement3
{
	SLOT 21;
	INDEX 4;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            FT1_Measurement3
        }
    }
}

COMMAND read_FT1_Measurement4
{
	SLOT 21;
	INDEX 73;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            FT1_Measurement4
        }
    }
}



COMMAND read_FT1_Unit
{
	SLOT 21;
	INDEX 10;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {

            FT1_Unit
        }
    }
}

COMMAND write_FT1_Unit
{
	SLOT 21;
	INDEX 10;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              FT1_Unit
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_FT1_Resolution
{
	SLOT 21;
	INDEX 19;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {

            FT1_Resolution
        }
    }
}

COMMAND write_FT1_Resolution
{
	SLOT 21;
	INDEX 19;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              FT1_Resolution
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_FT1_Offset
{
	SLOT 21;
	INDEX 21;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            
            FT1_Offset
        }
    }
}



COMMAND write_FT1_Offset
{
	SLOT 21;
	INDEX 21;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              FT1_Offset
        }
        REPLY
        {
            
        }
    }
}




COMMAND read_FT1_Integration
{
	SLOT 21;
	INDEX 9;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {

            FT1_Integration
        }
    }
}

COMMAND write_FT1_Integration
{
	SLOT 21;
	INDEX 9;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              FT1_Integration
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_FT1_LogInterval
{
	SLOT 21;
	INDEX 20;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {

            FT1_LogInterval
        }
    }
}

COMMAND write_FT1_LogInterval
{
	SLOT 21;
	INDEX 20;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              FT1_LogInterval
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_FT1_Gain
{
	SLOT 21;
	INDEX 50;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            FT1_Gain
        }
    }
}




COMMAND read_FT1_Parameter
{
	SLOT 21;
	INDEX 8;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {

            FT1_Parameter
        }
    }
}

COMMAND write_FT1_Parameter
{
	SLOT 21;
	INDEX 8;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
        FT1_Parameter
        }
        REPLY
        {
            
        }
    }
}


COMMAND read_FT1_LaserVoltage
{
	SLOT 21;
	INDEX 85;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            FT1_LaserVoltage
        }
    }
}

COMMAND read_FT1_LampCurrent
{
	SLOT 21;
	INDEX 87;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            FT1_LampCurrent
        }
    }
}

COMMAND read_FT1_5V
{
	SLOT 21;
	INDEX 89;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            FT1_5V
        }
    }
}

COMMAND read_FT1_12V
{
	SLOT 21;
	INDEX 91;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            FT1_12V
        }
    }
}

COMMAND read_FT1_15V
{
	SLOT 21;
	INDEX 93;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            FT1_15V
        }
    }
}

COMMAND read_FT1_RV
{
	SLOT 21;
	INDEX 95;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            FT1_RV
        }
    }
}

COMMAND read_FT1_SampleLocation
{
	SLOT 21;
	INDEX 11;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            
            FT1_SampleLocation
        }
    }
}

COMMAND write_FT1_SampleLocation
{
	SLOT 21;
	INDEX 11;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              FT1_SampleLocation
        }
        REPLY
        {
            
        }
    }
}

