/*----------------------------------------------------------------------*/
/*Copyright (C)	Hach-Lange (2010). All Rights Reserved.    				*/
/*Product:		SIMATIC PDM  	           								*/
/*Device:		SC PHD        	           								*/
/*Description:	Device Description	           							*/
/*Dictionary:	SIPADC01.dct	           								*/
/*$Revision:	1.0  $  	           									*/
/*$Date:		Maerz 2010	           									*/
/*File:			sc_phd.ddl   	           								*/
/*	Author:		T.Thiel Hach-Lange          	            			*/
/*				R.Mellows Hach-Lange                    				*/
/*				R.Stollenwerk Hach-Lange                				*/
/*----------------------------------------------------------------------*/

/************************************************************************/
/*---------------------Variablen----------------------------------------*/
/************************************************************************/

//-----------------Messwerte------Anfang------------------------------


VARIABLE PHD2_Measurement1 //40002 Float pH /Orp Measurement
{
 LABEL 	"Output value" 	"|de|Messwert";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//--------------
VARIABLE PHD2_Measurement2   //40005 Float Temperature Measurement
{
 LABEL 	"Temperature Measurement" 	"|de|Temperatur Messwert";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

}
//--------------
VARIABLE PHD2_Measurement3   //40056 Float pH mV
{
 LABEL 	"pH mV" 	"|de|pH mV";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"mV";

}
//--------------
VARIABLE PHD2_Measurement4   //40060 Float Standard Electrode
{
 LABEL 	"Standard Electrode Impedance" 	"|de|Standard Elektrodenimpedanz";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"MOhm";

}
//--------------
VARIABLE PHD2_Measurement5   //40062 Float Reference Electrode Impedance
{
 LABEL 	"Reference Electrode Impedance" 	"|de|Referenz Elektrodenimpedanz";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"MOhm";

}

//--------------
VARIABLE PHD2_Unit1   //40015 Integer Measurement Type- Orp
{
 LABEL 	"Sensor Type pH/ORP" 	"|de|Sensor pH/Redox";
 HELP         	"Measurement Type-pH or ORP";
 CLASS	CONTAINED;
 TYPE	ENUMERATED (2)
        {

         MIN_VALUE 0 ;
	 MAX_VALUE 1 ;

	{0,	"pH"   },
	{1,	"mV"   }

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//--------------
VARIABLE PHD2_Unit2   //40016 Integer Temperature Units-C or F
{
 LABEL 	"Temperature Unit" 	"|de|Temperatureinheit";
 HELP         	"Temperature Units-C or F";
 CLASS	CONTAINED;
 TYPE	ENUMERATED (2)

        {
         MIN_VALUE 25 ;
	 MAX_VALUE 26 ;

	{25,	"C"   },
	{26,	"F"   }

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

UNIT Select_PHD2_Unit1   //40015 Integer Measurement Type-pH or Orp
{
	PHD2_Unit1:
	PHD2_Measurement1
}

//--------------

UNIT Select_PHD2_Unit2   //40016 Integer Temperature Units-C or F
{
	PHD2_Unit2:
	PHD2_Measurement2

}


//-----------------Messwerte------Ende------------------------------


//-----------------Sensor Daten------Anfang------------------------------


VARIABLE PHD2_Diag1   //40035 Float pH Slope
{
 LABEL 	"pH Slope" 	"|de|pH Steigung";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"mV/pH";
}
//--------------
VARIABLE PHD2_IDENT1   //40037 String Software Version
{
 LABEL 	"Software Version" 	"|de|Software Version";
 CLASS	CONTAINED;
 TYPE	ASCII (12)
        {

        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//--------------
VARIABLE PHD2_Diag7   //40068 Integer Electrode Status
{
 LABEL 	"Electrode Status" 	"|de|Status Elektrode";
 CLASS	DYNAMIC;
 TYPE	ENUMERATED  (2)
        {
	{1,	"good" "|de|gut"  }

        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//--------------

VARIABLE PHD2_IDENT3   //40069 Integer Sensor Type
{
 LABEL 	"Sensor Type" 	"|de|Sensor Typ";
 CLASS	DYNAMIC;
 TYPE	ENUMERATED (2)
        {
           	{0,	"DIFF pH"   },
           	{1,	"DIFF ORP"   }

        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

//--------------
VARIABLE PHD2_IDENT4   //40071 String Device Driver
{
 LABEL 	"Device Driver" 	"|de|Gerte Treiber";
 CLASS	CONTAINED;
 TYPE	ASCII (10)
        {

        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//--------------
VARIABLE PHD2_Diag8   //40078 Integer Senor Adc Counts
{
 LABEL 	"Sensor Adc Counts" 	"|de|Senor Adc Zhler";
 CLASS	DYNAMIC;
 TYPE	UNSIGNED_INTEGER(4)
        {

        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//--------------
VARIABLE PHD2_Diag9   //40080 Integer Temperature Adc Counts
{
 LABEL 	"Temperature Adc Counts" 	"|de|Temperatur Adc Zhler";
 CLASS	DYNAMIC;
 TYPE	UNSIGNED_INTEGER (4)
        {

        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//--------------
VARIABLE PHD2_Diag10   //40091 Float Minimum User Temperature value
{
 LABEL 	"Minimum User Temperature" 	"|de|Minimum Benutzer Temperatur";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//--------------
VARIABLE PHD2_Diag11   //40095 Float Impedanz Measuring Ckt
{
 LABEL 	"Imedance Measuring Ckt Enabled" 	"|de|Impedanz Messung Ckt aktiv";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//--------------
VARIABLE PHD2_Setting2   //40026 Integer Pure H2O Compensation Type
{
 LABEL 	"Pure H2O Compensation Type" 	"|de|Reinwasser Kompensationstyp";
 HELP         	"pH /Orp Measurement";
 CLASS	CONTAINED;
 TYPE	ENUMERATED (2)
        {
                                 MIN_VALUE 0 ;
	 MAX_VALUE 8 ;

 	{0,     "None"        "|de|Kein"},
	{1,	"Ammonia"     "|de|Ammonium" },
	{2,	"Morpholine"  "|de|Morpholin" },
	{3,	"Pure Water"  "|de|Reinwasser"  },
	{4,	"Matrix 1"   },
	{5,	"Matrix 2"   },
	{6,	"Matrix 3"   },
	{7,	"Matrix 4"   },
	{8,	"User Define" "|de|Benutzerdefiniert" }

        }
	HANDLING	READ & WRITE ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//--------------

VARIABLE PHD2_Setting1   //40007 String Sensor Name
{
	LABEL 	"Probe Location" "|de|Einbauort";
 HELP         	"Sensor Name";
 CLASS	CONTAINED;
 TYPE	ASCII (12)
        {

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//-----------------Sensor Daten------Ende------------------------------



//-----------------Settings------Anfang------------------------------
VARIABLE PHD2_Setting3   //40020 Integer Sensor Filter
{
 LABEL 	"Sensor Filter" 	"|de|Sensor Dmpfung";
 CLASS	CONTAINED;
 TYPE	UNSIGNED_INTEGER (2)
        {

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"s";
}
//--------------
VARIABLE PHD2_Setting4   //40021 Integer Temeperature Element Type
{
 LABEL 	"Temperature Element Type" 	"|de|Temperaturelementtyp";
 CLASS	CONTAINED;
 TYPE	ENUMERATED (2)
        {
                                 MIN_VALUE 0 ;
	 MAX_VALUE 4 ;

	{0,	"PT 100"  },
	{1,	"PT 1000" },
	{2,	"NTC 300" },
	{4,	"Manual"  }
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//--------------
VARIABLE PHD2_Setting5   //40023 Float Temperature User Value
{
 LABEL 	"Temperature User Value" 	"|de|Temperatur Benutzerwert";
 CLASS	CONTAINED;
 TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"C/F";
}
//--------------
VARIABLE PHD2_Setting6   //40025 Integer pH Buffer Type
{
 LABEL 	"pH Buffer Type" 	"|de|pH Buffertyp";
 CLASS	CONTAINED;
 TYPE	ENUMERATED (2)
        {
         MIN_VALUE 0 ;
	 MAX_VALUE 1 ;

 	{0,              	"4, 7, 10"},
	{1,	"DIN 19267"   }

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//--------------

VARIABLE PHD2_Setting7   //40027 Float Pure H2O Compensation User Val
{
 LABEL 	"Pure H2O Compensation User Val" "|de|Reinwasser Kompensations Benutzerwert";
 CLASS	CONTAINED;
 HELP   "slope +- 0.1  equal to +- 10%";
 TYPE	FLOAT
        {
         MIN_VALUE -0.1 ;
	 MAX_VALUE 0.1 ;
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"pH/C";
}

//--------------
VARIABLE PHD2_Setting10   //40054 Integer Sensor Data Log Interval
{
 LABEL 	"Sensor Data Log Interval" 	"|de|Sensor Daten Log Interval";
 CLASS	CONTAINED;
 TYPE	ENUMERATED (2)
        {
                                 MIN_VALUE 0 ;
	 MAX_VALUE 43200 ;

	{0,	"Disabled"   "|de|Deaktiviert"},
	{5,	"5 s" },
	{10,	"10 s" },
	{15,	"15 s" },
	{30,	"30 s" },
	{60,	"1 min"   },
	{300,	"5 min"   },
	{600,	"10 min" },
	{900,	"15 min" },
	{1800,	"30 min" },
	{3600,	"1 h" },
	{7200,	"2 h" },
	{21600,	"6 h" },
	{43200,	"12 h" }
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//--------------
VARIABLE PHD2_Setting11   //40055 Integer Temperature Data Log Interval
{
 LABEL 	"Temperature Data Log Interval" 	"|de|Temperatur Daten Log Interval";
 CLASS	CONTAINED;
 TYPE	ENUMERATED  (2)
        {
                                 MIN_VALUE 0 ;
	 MAX_VALUE 43200 ;

	{0,	"Disabled"   "|de|Deaktiviert"},
	{5,	"5 s" },
	{10,	"10 s" },
	{15,	"15 s" },
	{30,	"30 s" },
	{60,	"1 min"   },
	{300,	"5 min"   },
	{600,	"10 min" },
	{900,	"15 min" },
	{1800,	"30 min" },
	{3600,	"1 h" },
	{7200,	"2 h" },
	{21600,	"6 h" },
	{43200,	"12 h" }

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//--------------
VARIABLE PHD2_Setting12   //40070 Integer Reject Frequency
{
 LABEL 	"Reject Frequency" 	"|de|Ausschluss Frequenz";
 CLASS	CONTAINED;
 TYPE	ENUMERATED (2)
        {
                                 MIN_VALUE 0 ;
	 MAX_VALUE 1 ;

	{0,	"60 Hz" },
	{1,	"50 Hz" }

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//--------------
VARIABLE PHD2_Setting13   //40076 Integer Calibration Warning Days
{
 LABEL 	"Calibration Warning Days" 	"|de|Kalibrierungswarnung in Tagen";
 CLASS	CONTAINED;
 TYPE	UNSIGNED_INTEGER (2)
        {

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//--------------
VARIABLE PHD2_Setting14   //40077 Integer Sensor Warning Days
{
 LABEL 	"Sensor Warning Days" 	"|de|Sensorwarnung in Tagen";
 CLASS	CONTAINED;
 TYPE	UNSIGNED_INTEGER  (2)
        {

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//--------------
VARIABLE PHD2_Setting16   //40088 Integer Imedance Measuring Ckt Enabled(1)
{
 LABEL 	"Impedance Status Enabled" "|de|Impedanz Messung Ein";
 CLASS	CONTAINED;
 TYPE	ENUMERATED (2)
        {
         MIN_VALUE 0 ;
	 MAX_VALUE 1 ;

	{0,	"Disable" "|de|Deaktivieren"  },
	{1,	"Enable" "|de|Aktivieren"  }

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}
//--------------

//---EDD2DTM Dummy Byte-----
 VARIABLE dummy_byte
{
	LABEL "dummy";
	TYPE ASCII(1);
	CLASS LOCAL;

}
/************************************************************************/
/*-----------------------COMMANDS---------------------------------------*/
/************************************************************************/
//-----------------Messwerte------Anfang------------------------------
COMMAND read_PHD2_Float01
{
        SLOT PHD2_SLOTADR;
        INDEX 1;
        OPERATION READ;
        TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          PHD2_Measurement1, // pH /Orp Measurement:40002(001)Float L(02)
          dummy_byte,dummy_byte, // Temperature Measurement Tag:40004(003)Integer L(01)
          dummy_byte,dummy_byte, // Temperature Measurement :40005(004)Float L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Sensor Name:40007(006)String L(06)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Function Code tag:40013(012)Integer L(01)
          dummy_byte,dummy_byte, // Next State Tag:40014(013)Integer L(01)
          dummy_byte,dummy_byte, // Measurement Type-pH or Orp:40015(014)Integer L(01)
          dummy_byte,dummy_byte, // Temperature Units-C or F:40016(015)Integer L(01)
          dummy_byte,dummy_byte, // pH Display Format:40017(016)Integer L(01)
          dummy_byte,dummy_byte, // pH Display Tagged Format:40018(017)Unsigned Integer L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Sensor Filter:40020(019)Integer L(01)
          dummy_byte,dummy_byte, // Temeperature Element Type:40021(020)Integer L(01)
          dummy_byte,dummy_byte, // Temperature User Value Tag:40022(021)Integer L(01)
          dummy_byte,dummy_byte, // Temperature User Value:40023(022)Float L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // pH Buffer Type:40025(024)Integer L(01)
          dummy_byte,dummy_byte, // Pure H2O Compensation Type:40026(025)Integer L(01)
          dummy_byte,dummy_byte, // Pure H2O Compensation User Val:40027(026)Float L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Output Mode:40029(028)Integer L(01)
          dummy_byte,dummy_byte, // Cal Leave Mode:40030(029)Integer L(01)
          dummy_byte,dummy_byte, // Cal Abort Mode:40031(030)Integer L(01)
          dummy_byte,dummy_byte, // Cal Edit Value Tag:40032(031)Integer L(01)
          dummy_byte,dummy_byte, // Cal Edit Value:40033(032)Float L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // pH Slope:40035(034)Float L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte // Software Version:40037(036)String L(06)
        }
    }
}

COMMAND read_PHD2_Float02
{
        SLOT PHD2_SLOTADR;
        INDEX 4;
        OPERATION READ;
        TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          PHD2_Measurement2, // Temperature Measurement :40005(004)Float L(02)
          dummy_byte,dummy_byte, // Sensor Name:40007(006)String L(06)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Function Code tag:40013(012)Integer L(01)
          dummy_byte,dummy_byte, // Next State Tag:40014(013)Integer L(01)
          dummy_byte,dummy_byte, // Measurement Type-pH or Orp:40015(014)Integer L(01)
          dummy_byte,dummy_byte, // Temperature Units-C or F:40016(015)Integer L(01)
          dummy_byte,dummy_byte, // pH Display Format:40017(016)Integer L(01)
          dummy_byte,dummy_byte, // pH Display Tagged Format:40018(017)Unsigned Integer L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Sensor Filter:40020(019)Integer L(01)
          dummy_byte,dummy_byte, // Temeperature Element Type:40021(020)Integer L(01)
          dummy_byte,dummy_byte, // Temperature User Value Tag:40022(021)Integer L(01)
          PHD2_Setting5, // Temperature User Value:40023(022)Float L(02)
          dummy_byte,dummy_byte, // pH Buffer Type:40025(024)Integer L(01)
          dummy_byte,dummy_byte, // Pure H2O Compensation Type:40026(025)Integer L(01)
          PHD2_Setting7, // Pure H2O Compensation User Val:40027(026)Float L(02)
          dummy_byte,dummy_byte, // Output Mode:40029(028)Integer L(01)
          dummy_byte,dummy_byte, // Cal Leave Mode:40030(029)Integer L(01)
          dummy_byte,dummy_byte, // Cal Abort Mode:40031(030)Integer L(01)
          dummy_byte,dummy_byte, // Cal Edit Value Tag:40032(031)Integer L(01)
          dummy_byte,dummy_byte, // Cal Edit Value:40033(032)Float L(02)
          dummy_byte,dummy_byte,
          PHD2_Diag1, // pH Slope:40035(034)Float L(02)
          dummy_byte,dummy_byte, // Software Version:40037(036)String L(06)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte
        }
    }
}

COMMAND read_PHD2_Float03
{
        SLOT PHD2_SLOTADR;
        INDEX 55;
        OPERATION READ;
        TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            PHD2_Measurement3, // pH mV:40056(055)Float L(02)
            dummy_byte,dummy_byte, // Production Date:40058(057)Unsigned Integer L(02)
            dummy_byte,dummy_byte,
            PHD2_Measurement4, // Standard Electrode Impedance:40060(059)Float L(02)
            PHD2_Measurement5, // Reference Electrode Impedance:40062(061)Float L(02)
            dummy_byte,dummy_byte, // Last Calibration Date:40064(063)Unsigned Integer L(02)
            dummy_byte,dummy_byte,
            dummy_byte,dummy_byte, // Sensor Running Days:40066(065)Integer L(01)
            dummy_byte,dummy_byte, // Electrode Running Days:40067(066)Integer L(01)
            dummy_byte,dummy_byte, // Electrode Status:40068(067)Integer L(01)
            dummy_byte,dummy_byte, // Sensor Type:40069(068)Integer L(01)
            dummy_byte,dummy_byte, // Reject Frequency:40070(069)Integer L(01)
            dummy_byte,dummy_byte, // Device Driver:40071(070)String L(05)
            dummy_byte,dummy_byte,
            dummy_byte,dummy_byte,
            dummy_byte,dummy_byte,
            dummy_byte,dummy_byte,
            dummy_byte,dummy_byte, // Calibration Warning Days:40076(075)Integer L(01)
            dummy_byte,dummy_byte, // Sensor Warning Days:40077(076)Integer L(01)
            PHD2_Diag8, // Senor Adc Counts:40078(077)Integer L(02)
            PHD2_Diag9, // Temperature Adc Counts:40080(079)Integer L(02)
            dummy_byte,dummy_byte, // Set User Temperature:40082(081)Float L(02)
	    dummy_byte,dummy_byte,
            dummy_byte,dummy_byte, // Minimum User Temperature value:40084(083)Float L(02)
            dummy_byte,dummy_byte,
            dummy_byte,dummy_byte, // Maximum User Temperature Value :40086(085)Float L(02)
            dummy_byte,dummy_byte,
            dummy_byte,dummy_byte, // Imedance Measuring Ckt Enabled(1):40088(087)Integer L(01)
            dummy_byte,dummy_byte, // Set User Temperature:40089(088)Float L(02)
            dummy_byte,dummy_byte,
            dummy_byte,dummy_byte // Minimum User Temperature value:40091(090)Float L(02)

        }
    }
}


COMMAND read_PHD2_Var01
{
        SLOT PHD2_SLOTADR;
        INDEX 6;
        OPERATION READ;
        TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          PHD2_Setting1, // Sensor Name:40007(006)String L(06)
          dummy_byte,dummy_byte, // Function Code tag:40013(012)Integer L(01)
          dummy_byte,dummy_byte, // Next State Tag:40014(013)Integer L(01)
          PHD2_Unit1, // Measurement Type-pH or Orp:40015(014)Integer L(01)
          PHD2_Unit2, // Temperature Units-C or F:40016(015)Integer L(01)
          dummy_byte,dummy_byte, // pH Display Format:40017(016)Integer L(01)
          dummy_byte,dummy_byte, // pH Display Tagged Format:40018(017)Unsigned Integer L(02)
          dummy_byte,dummy_byte,
          PHD2_Setting3, // Sensor Filter:40020(019)Integer L(01)
          PHD2_Setting4, // Temeperature Element Type:40021(020)Integer L(01)
          dummy_byte,dummy_byte, // Temperature User Value Tag:40022(021)Integer L(01)
          dummy_byte,dummy_byte, // Temperature User Value:40023(022)Float L(02)
          dummy_byte,dummy_byte,
          PHD2_Setting6, // pH Buffer Type:40025(024)Integer L(01)
          PHD2_Setting2 // Pure H2O Compensation Type:40026(025)Integer L(01)

        }
    }
}

COMMAND read_PHD2_Var02
{
        SLOT PHD2_SLOTADR;
        INDEX 36;
        OPERATION READ;
        TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          PHD2_IDENT1, // Software Version:40037(036)String L(06)
          dummy_byte,dummy_byte, // Serial Number:40043(042)String L(06)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // pH Offset:40049(048)Float L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Orp Offset:40051(050)Float L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Cal Code:40053(052)Integer L(01)
          PHD2_Setting10, // Sensor Data Log Interval:40054(053)Integer L(01)
          PHD2_Setting11, // Temperature Data Log Interval:40055(054)Integer L(01)
          dummy_byte,dummy_byte, // pH mV:40056(055)Float L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Production Date:40058(057)Unsigned Integer L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Standard Electrode Impedance:40060(059)Float L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Reference Electrode Impedance:40062(061)Float L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Last Calibration Date:40064(063)Unsigned Integer L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Sensor Running Days:40066(065)Integer L(01)
          dummy_byte,dummy_byte, // Electrode Running Days:40067(066)Integer L(01)
          PHD2_Diag7, // Electrode Status:40068(067)Integer L(01)
          PHD2_IDENT3, // Sensor Type:40069(068)Integer L(01)
          PHD2_Setting12 // Reject Frequency:40070(069)Integer L(01)
        }
    }
}


COMMAND read_PHD2_Var03
{
        SLOT PHD2_SLOTADR;
        INDEX 59;
        OPERATION READ;
        TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          dummy_byte,dummy_byte, // Standard Electrode Impedance:40060(059)Float L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Reference Electrode Impedance:40062(061)Float L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Last Calibration Date:40064(063)Unsigned Integer L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Sensor Running Days:40066(065)Integer L(01)
          dummy_byte,dummy_byte, // Electrode Running Days:40067(066)Integer L(01)
          dummy_byte,dummy_byte, // Electrode Status:40068(067)Integer L(01)
          dummy_byte,dummy_byte, // Sensor Type:40069(068)Integer L(01)
          dummy_byte,dummy_byte, // Reject Frequency:40070(069)Integer L(01)
          PHD2_IDENT4, // Device Driver:40071(070)String L(05)
          PHD2_Setting13, // Calibration Warning Days:40076(075)Integer L(01)
          PHD2_Setting14, // Sensor Warning Days:40077(076)Integer L(01)
          dummy_byte,dummy_byte, // Senor Adc Counts:40078(077)Integer L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Temperature Adc Counts:40080(079)Integer L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Set User Temperature:40082(081)Float L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Minimum User Temperature value:40084(083)Float L(02)
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Maximum User Temperature Value :40086(085)Float L(02)
          dummy_byte,dummy_byte,
          PHD2_Setting16, // Imedance Measuring Ckt Enabled(1):40088(087)Integer L(01)
          dummy_byte,dummy_byte
        }
    }
}

//----------------------------------------------------------
//----------------------------------------------
//------IDENTIFICATIONS-------------------------
//----------------------------------------------


//----------------------Comand Write------------------------------------------
COMMAND write_PHD2_Setting1   //40007 String Sensor Name
{
SLOT PHD2_SLOTADR;
INDEX 6;
OPERATION WRITE;
TRANSACTION
    {
        REQUEST
        {
        PHD2_Setting1
        }
        REPLY
        {

        }
    }
}


COMMAND write_PHD2_Setting3   //40020 Integer Sensor Filter
{
          SLOT PHD2_SLOTADR;
          INDEX 19;
          OPERATION WRITE;
          TRANSACTION
          {
           REQUEST
	    {
	     PHD2_Setting3
            }
	   REPLY
            {

            }
          }
}

COMMAND write_PHD2_Setting5   //40023 Float Temperature User Value
{
          SLOT PHD2_SLOTADR;
          INDEX 22;
          OPERATION WRITE;
          TRANSACTION
          {
           REQUEST
            {
            PHD2_Setting5
            }
	   REPLY
            {

            }
	    
          }
}
COMMAND write_PHD2_Setting6   //40025 Integer pH Buffer Type
{
          SLOT PHD2_SLOTADR;
          INDEX 24;
          OPERATION WRITE;
          TRANSACTION
          {
          REQUEST
          {
           PHD2_Setting6
          }
	   REPLY
            {

            }
	  
          }
}
COMMAND write_PHD2_Setting2   //40026 Integer Pure H2O Compensation Type
{
          SLOT PHD2_SLOTADR ;
                    INDEX 25;
                    OPERATION WRITE;
                    TRANSACTION
	           {
	               REQUEST
                   {
                   PHD2_Setting2
                   }
	           REPLY
                   {

                   }	   
    }
}
COMMAND write_PHD2_Setting7   //40027 Float Pure H2O Compensation User Val
{
          SLOT PHD2_SLOTADR;
          INDEX 26;
          OPERATION WRITE;
          TRANSACTION
	    {
	      REQUEST
	         {
	          PHD2_Setting7
                 }
	   REPLY
            {

            }
		 
    }
}

COMMAND write_PHD2_Setting10   //40054 Integer Sensor Data Log Interval
{
          SLOT PHD2_SLOTADR;
                    INDEX 53;
                    OPERATION WRITE;
                              TRANSACTION
                                 {
	     REQUEST
	          {
	          PHD2_Setting10
        }
	   REPLY
            {

            }
	
    }
}
COMMAND write_PHD2_Setting11   //40055 Integer Temperature Data Log Interval
{
          SLOT PHD2_SLOTADR;
                    INDEX 54;
                              OPERATION WRITE;
                                        TRANSACTION
	           {
	               REQUEST
	                    {
	                    PHD2_Setting11
        }
	   REPLY
            {

            }
	
    }
}
COMMAND write_PHD2_Setting12   //40070 Integer Reject Frequency
{
          SLOT PHD2_SLOTADR;
                    INDEX 69;
                              OPERATION WRITE;
                                        TRANSACTION
	           {
	               REQUEST
	                    {
	                    PHD2_Setting12
        }
	   REPLY
            {

            }
	
    }
}
COMMAND write_PHD2_Setting13   //40076 Integer Calibration Warning Days   //INTEGER  (2)
{
          SLOT PHD2_SLOTADR;
                    INDEX 75;
                              OPERATION WRITE;
                                        TRANSACTION
	           {
	               REQUEST
	                    {
	PHD2_Setting13
        }
	   REPLY
            {

            }
	
    }
}
COMMAND write_PHD2_Setting14   //40077 Integer Sensor Warning Days    //INTEGER  (2)
{
          SLOT PHD2_SLOTADR;
                    INDEX 76;
                              OPERATION WRITE;
                                        TRANSACTION
	           {
	               REQUEST
	                    {
	                    PHD2_Setting14
        }
	   REPLY
            {

            }
	
    }
}


COMMAND write_PHD2_Setting16   //40088 Integer Imedance Measuring Ckt Enabled(1)
{
          SLOT PHD2_SLOTADR;
          INDEX 87;
          OPERATION WRITE;
          TRANSACTION
    {
        REQUEST
        {
              PHD2_Setting16
        }
        REPLY
        {

        }
    }
}

COMMAND write_PHD2_Setting4
{
	SLOT PHD2_SLOTADR;
	INDEX 20;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
         PHD2_Setting4   	           //40021 Integer Temeperature Element Type
        }
	   REPLY
            {

            }
	
    }
}

COMMAND write_Select_PHD2_Unit1   //40015 Integer Measurement Type-pH or Orp
{
          SLOT PHD2_SLOTADR;
                    INDEX 14;
                              OPERATION WRITE;
                                        TRANSACTION
	           {
	               REQUEST
	                    {
	                    PHD2_Unit1
        }
	   REPLY
            {

            }
	
    }
}
COMMAND write_Select_PHD2_Unit2   //40016 Integer Temperature Units-C or F
{
          SLOT PHD2_SLOTADR;
                INDEX 15;
                OPERATION WRITE;
                                        TRANSACTION
	           {
	               REQUEST
	                    {
	                    PHD2_Unit2
        }
	   REPLY
            {

            }
	
    }
}



