/*------------------------------------------------------------------*/
/*Copyright (C)	Hach-Lange (2010). All Rights Reserved.    			*/
/*	Product:		SIMATIC PDM  			   						*/
/*	Device:			SC DP/V1     		           					*/
/*	Description:	Device Description	           					*/
/*	Dictionary:		SIPADC01.dct			   						*/
/*	$Revision:		1.0  $  	           							*/
/*	$Date:			Maerz 2010	         							*/
/*	File:			I1_InduCond.inc		           					*/
/*	Author:			T.Thiel Hach-Lange                 				*/
/*					R.Mellows Hach-Lange               				*/
/*					R.Stollenwerk Hach-Lange           				*/
/*------------------------------------------------------------------*/


/************************************************************************/
/*		Variables						*/
/************************************************************************/



VARIABLE IC1_Measurement1
{
	LABEL 	"Output Value" 	"|de|Messwert ";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;


}



VARIABLE IC1_Measurement3
{
	LABEL 	"Temperature Value" 	"|de|Temperatur";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE IC1_Diag1
{
	LABEL 	"Sensor Running Days" 			"|de|Sensor Tage in Betrieb";
	HELP 	"Sensor Livetime";
	CLASS	DYNAMIC;
	TYPE	UNSIGNED_INTEGER (2)
		{

		}
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Day";
}

VARIABLE IC1_Diag2
{
	LABEL 	"Calibration Warning Days" 			"|de|Kalibrierwarnung";
	HELP 	"Preset Value for Cal. Warning";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Day";
}


VARIABLE IC1_Diag3
{
	LABEL 	"Sensor Warning Days" 			"|de|Sensorwarnung";
	HELP 	"Preset Value for Sensor Replacement Warning";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Day";
}
VARIABLE IC1_Diag5
{
	LABEL 	"Sensor Log Interv." 			"|de|Sensor Logger";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)

		{
			DEFAULT_VALUE 		0;
			MIN_VALUE		0;
			MAX_VALUE		43200 ;

			{0,			"Off"		"|de|Aus"},
			{5,			"5 sec"		"|de|5 s"},
			{10,			"10 Sec"	"|de|10 s"},
			{15,			"15 sec"	"|de|15 s"},
			{30,			"30 sec"	"|de|30 s"},
			{60,			"1 min"		"|de|1 min"},
			{300,			"5 min"		"|de|5 min"},
			{600,			"10 min"	"|de|10 min"},
			{900,			"15 min"	"|de|15 min"},
			{1800,			"30 min"	"|de|30 min"},
			{3600,			"1 hr"	        "|de|1 h"},
			{7200,			"2 hr"	        "|de|2 h"},
			{21600,			"6 hr"	        "|de|6 h"},
			{43200,			"12 hr"	        "|de|12 h"}

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE IC1_Diag6
{
	LABEL 	"Temp.Log Interv." 			"|de|Temperatur Logger";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			DEFAULT_VALUE 		0;
			MIN_VALUE		0 ;
			MAX_VALUE		43200 ;

			{0,			"Off"		"|de|Aus"},
			{5,			"5 sec"		"|de|5 s"},
			{10,			"10 Sec"	"|de|10 s"},
			{15,			"15 sec"	"|de|15 s"},
			{30,			"30 sec"	"|de|30 s"},
			{60,			"1 min"		"|de|1 min"},
			{300,			"5 min"		"|de|5 min"},
			{600,			"10 min"	"|de|10 min"},
			{900,			"15 min"	"|de|15 min"},
			{1800,			"30 min"	"|de|30 min"},
			{3600,			"1 hr"	        "|de|1 h"},
			{7200,			"2 hr"	        "|de|2 h"},
			{21600,			"6 hr"	        "|de|6 h"},
			{43200,			"12 hr"	        "|de|12 h"}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}



VARIABLE IC1_Unit1
{
	LABEL 	"Conductivity Unit" 			"|de|Einheit LF";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			MIN_VALUE		32 ;
			MAX_VALUE		51 ;
			DEFAULT_VALUE 50;
			{32,			"S/cm"	},
			{50,			"S/cm"	},
			{51,			"mS/cm"	}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE IC1_Unit2
{
	LABEL 	"Resistivity Unit" 			"|de|Einheit Wiederstand";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			MIN_VALUE		0 ;
			MAX_VALUE		37 ;
			DEFAULT_VALUE 36;
			{0,			" "	},
			{36,			"K Ohm"	},
			{37,			"M Ohm" }

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE IC1_Unit3
{
	LABEL 	"TDS Unit" 			"|de|Einheit TDS";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			MIN_VALUE		2 ;
			MAX_VALUE		38 ;
			DEFAULT_VALUE 2;

			{2,			"ppm"	},
			{38,			"ppb"   }


		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE IC1_Unit5
{
	LABEL 	"Temperature Unit"			"|de|Einheit Temperatur";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			MIN_VALUE		25 ;
			MAX_VALUE		26 ;
			DEFAULT_VALUE 25;

			{25,			"C"   	},
			{26,			"F"     }


		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

UNIT Select_unit_T		// dynymic unit relation
{
	IC1_Unit5:
	IC1_Measurement3
}


VARIABLE IC1_Setting1
{
	LABEL 	"Measurement Mode" 	"|de|Betriebsart";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			MIN_VALUE		0 ;
			MAX_VALUE		2 ;
			DEFAULT_VALUE 		0;
			{0,			"Conductivity" 		"|de|Leitfaehigkeit" 	},
			{1,			"Concentration" 	"|de|Konzentration"	},
			{2,			"TDS" 			"|de|TDS" 	        }
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE IC1_Setting2
{
	LABEL 	"Filtering"	"|de|Filter";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
        {

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Sec";
}

VARIABLE IC1_Setting3
{
	LABEL 	"Cell Constant"	"|de|Zellenkonstante";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {


        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}


VARIABLE IC1_Setting4
{
	LABEL 	"Select Cell K" 	"|de|Zellenkonstante";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			{0,		"0.01" 		 	},
			{1,		"0.05" 	        	},
			{2,		"0.10" 			},
			{3,		"0.50" 			},
			{4,		"1.0 HACH" 	       	},
			{7,		"1.0 Polimetron" 	},
			{5,		"5.0" 		 	},
			{6,		"10.0" 			}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE IC1_Setting5
{
	LABEL 	"Temp Element" 	"|de|Temperaturelement";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{

			MIN_VALUE		0 ;
			MAX_VALUE		2 ;

			{1,		"Pt1000"        "|de|Pt1000"	},
			{2,		"Manual" 	"|de|Manuell" 	}

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE IC1_Setting6
{
	LABEL 	"Temperature Manual" 	"|de|Temp Handwert";
	HELP 	"Used when Temp Element = Manual";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"C/F";
}

VARIABLE IC1_Setting7
{
	LABEL 	"Linear Temp.Comp.Slope" 	"|de|Lineare Temp.Kompensationssteilheit";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
        CONSTANT_UNIT 	"%/C";
}

VARIABLE IC1_Setting8
{
	LABEL 	"Linear Temp.Comp.Reference" 	"|de|Referenztemperatur";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"C";
}

VARIABLE IC1_Setting9
{
	LABEL 	"AC Frequency" 	"|de|Netzfrequenz";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			MIN_VALUE		0 ;
			MAX_VALUE		1 ;
			DEFAULT_VALUE 		1 ;
			{0,		"60 Hz" 	 	},
			{1,		"50 Hz"         	}


		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE IC1_Setting10
{
	LABEL 	"Temperature Factor" 	"|de|Temp. Faktor";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"Ohm";
}

VARIABLE IC1_Setting11
{
	LABEL 	"Temp. Compensation Type" 	"|de|Temp. Kompensationstyp";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			MIN_VALUE		0 ;
			MAX_VALUE		4 ;
			DEFAULT_VALUE 		0 ;
			{0,		"None" 		 	"|de|Kein"},
			{1,		"Linear"         	"|de|Linear"},
			{3,		"Natural Water" 	"|de|Rohwasser"},
			{4,		"Temp Table" 		"|de|Temp Tabelle"}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE IC1_Setting12
{
	LABEL 	"Concentration Comp. Type" 	"|de|Konzentration Typ";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			MIN_VALUE		0 ;
			MAX_VALUE		1 ;
			DEFAULT_VALUE 		0 ;
			{0,		"Build In" 	 "|de|Eingebaut"	},
			{1,		"User"        	 "|de|Benutzer"	}

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE IC1_Setting13
{
	LABEL 	"Concentration Build In Type Type" 	"|de|Konzentration Typ";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			MIN_VALUE		0 ;
			MAX_VALUE		12 ;
			DEFAULT_VALUE 		2 ;
			{1,		"H3PO4 0-40%" 	 	},
			{2,		"HCl 0-18%"         	},
			{3,		"HCl 22-36%" 		},
			{4,		"NaOH 0-16%" 		},
			{5,		"CaCl2 0-22%" 	 	},
			{6,		"HNO3 0-28%"         	},
			{7,		"HNO3 36-96%" 		},
			{8,		"H2SO4 0-30%" 		},
			{9,		"H2SO4 40-80%" 	 	},
			{10,		"H2SO4 93-99%"         	},
			{11,		"HF 0-30%" 		},
			{12,		"NaCl 0-25%" 		}

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE IC1_Setting14
{
	LABEL 	"TDS Factor Type" 	"|de|TDS Faktortyp";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			MIN_VALUE		0 ;
			MAX_VALUE		1 ;
			DEFAULT_VALUE 		0 ;
			{0,		"NaCl" 	 	"|de|NaCl"},
			{1,		"User"      	"|de|Benutzer"}

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE IC1_Setting15
{
	LABEL 	"TDS Factor" 	"|de|TDS Faktor";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;


}

VARIABLE IC1_CorrectionSlope
{
	LABEL 	"Correction Slope"	"|de|Korrekturfaktor Steilheit";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
		MIN_VALUE		0.5 ;
		MAX_VALUE		1.5 ;

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE IC1_Correction
{
	LABEL 	"Calib Value"		"|de|Kalibrierwert";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
		MIN_VALUE		 0.0 ;
		MAX_VALUE		 20.0 ;

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE IC1_Offset
{
	LABEL 	"Offset "		"|de|Offset";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
		MIN_VALUE		-5.0 ;
		MAX_VALUE		 5.0 ;

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 4000;
}

VARIABLE IC1_Integration
{
	LABEL 	"Integration in  seconds"	"|de|Integration in Sekunden";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
        {

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}


VARIABLE IC1_SampleLocation
{
	LABEL 	"Probe Location" "|de|Einbauort";
	CLASS	CONTAINED;
	TYPE	ASCII (12)
		{
			DEFAULT_VALUE "";
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

//---EDD2DTM Dummy Byte-----
 VARIABLE dummy_byte
{
	LABEL "dummy";
	TYPE ASCII(1);
	CLASS LOCAL;

}
/************************************************************************/
/*		READ COMMANDS						*/
/************************************************************************/
COMMAND read_IC1_Float01
{
	SLOT IC1_SLOTADR;
	INDEX 1;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          IC1_Measurement1, // Conductivity Measurement:40002(001)Float L(02)   Conductivity Measurement
          dummy_byte,dummy_byte, // Temperature Measurement Tag:40004(003)Integer L(01)    Temperature Measurement Tag
          dummy_byte,dummy_byte,
          dummy_byte,dummy_byte, // Temperature Measurement :40005(004)Float L(02)     Temperature Measurement
          dummy_byte,dummy_byte, // Sensor Name:40007(006)String L(06)     Sensor Name
          dummy_byte,dummy_byte, // Sensor Name:40007(006)String L(06)     Sensor Name
          dummy_byte,dummy_byte, // Sensor Name:40007(006)String L(06)     Sensor Name
          dummy_byte,dummy_byte, // Sensor Name:40007(006)String L(06)     Sensor Name
          dummy_byte,dummy_byte, // Sensor Name:40007(006)String L(06)     Sensor Name
          dummy_byte,dummy_byte, // Sensor Name:40007(006)String L(06)     Sensor Name
          dummy_byte,dummy_byte, // Function Code tag:40013(012)Integer L(01)
          dummy_byte,dummy_byte, // Next State Tag:40014(013)Integer L(01)
          dummy_byte,dummy_byte, // Measurement Type:40015(014)Integer L(01)
          dummy_byte,dummy_byte, // Temperature Units-C or F:40016(015)Integer L(01)
          dummy_byte,dummy_byte, // Sensor Filter:40017(016)Integer L(01)
          dummy_byte,dummy_byte, // Temeperature Element Type:40018(017)Integer L(01)
          dummy_byte,dummy_byte, // Temperature User Value Tag:40019(018)Integer L(01)
          IC1_Setting6, // Temperature User Value:40020(019)Float L(02)
          IC1_Setting10,// Temperature Factor:40022(021)Float L(02)
          dummy_byte,dummy_byte, // Output Mode:40024(023)Integer L(01)
          dummy_byte,dummy_byte, // Cal Leave Mode:40025(024)Integer L(01)
          dummy_byte,dummy_byte, // Cal Abort Mode:40026(025)Integer L(01)
          dummy_byte,dummy_byte, // Software Version:40027(026)String L(06)
          dummy_byte,dummy_byte, // Software Version:40027(026)String L(06)
          dummy_byte,dummy_byte, // Software Version:40027(026)String L(06)
          dummy_byte,dummy_byte, // Software Version:40027(026)String L(06)
          dummy_byte,dummy_byte, // Software Version:40027(026)String L(06)
          dummy_byte,dummy_byte, // Software Version:40027(026)String L(06)
          dummy_byte,dummy_byte, // Serial Number:40033(032)String L(06)
          dummy_byte,dummy_byte, // Serial Number:40033(032)String L(06)
          dummy_byte,dummy_byte, // Serial Number:40033(032)String L(06)
          dummy_byte,dummy_byte, // Serial Number:40033(032)String L(06)
          dummy_byte,dummy_byte // Serial Number:40033(032)String L(06)
        }
    }
}

COMMAND read_IC1_Float02
{
	SLOT IC1_SLOTADR;
	INDEX 4;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          IC1_Measurement3, // Temperature Measurement :40005(004)Float L(02)
          dummy_byte,dummy_byte, // Sensor Name:40007(006)String L(06)
          dummy_byte,dummy_byte, // Sensor Name:40007(006)String L(06)
          dummy_byte,dummy_byte, // Sensor Name:40007(006)String L(06)
          dummy_byte,dummy_byte, // Sensor Name:40007(006)String L(06)
          dummy_byte,dummy_byte, // Sensor Name:40007(006)String L(06)
          dummy_byte,dummy_byte, // Sensor Name:40007(006)String L(06)
          dummy_byte,dummy_byte, // Function Code tag:40013(012)Integer L(01)
          dummy_byte,dummy_byte, // Next State Tag:40014(013)Integer L(01)
          dummy_byte,dummy_byte, // Measurement Type:40015(014)Integer L(01)
          dummy_byte,dummy_byte, // Temperature Units-C or F:40016(015)Integer L(01)
          dummy_byte,dummy_byte, // Sensor Filter:40017(016)Integer L(01)
          dummy_byte,dummy_byte, // Temeperature Element Type:40018(017)Integer L(01)
          dummy_byte,dummy_byte, // Temperature User Value Tag:40019(018)Integer L(01)
          dummy_byte,dummy_byte, // Temperature User Value:40020(019)Float L(02)
          dummy_byte,dummy_byte, // Temperature User Value:40020(019)Float L(02)
          dummy_byte,dummy_byte, // Temperature Factor:40022(021)Float L(02)
          dummy_byte,dummy_byte, // Temperature Factor:40022(021)Float L(02)
          dummy_byte,dummy_byte, // Output Mode:40024(023)Integer L(01)
          dummy_byte,dummy_byte, // Cal Leave Mode:40025(024)Integer L(01)
          dummy_byte,dummy_byte, // Cal Abort Mode:40026(025)Integer L(01)
          dummy_byte,dummy_byte, // Software Version:40027(026)String L(06)
          dummy_byte,dummy_byte, // Software Version:40027(026)String L(06)
          dummy_byte,dummy_byte, // Software Version:40027(026)String L(06)
          dummy_byte,dummy_byte, // Software Version:40027(026)String L(06)
          dummy_byte,dummy_byte, // Software Version:40027(026)String L(06)
          dummy_byte,dummy_byte, // Software Version:40027(026)String L(06)
          dummy_byte,dummy_byte, // Serial Number:40033(032)String L(06)
          dummy_byte,dummy_byte, // Serial Number:40033(032)String L(06)
          dummy_byte,dummy_byte, // Serial Number:40033(032)String L(06)
          dummy_byte,dummy_byte, // Serial Number:40033(032)String L(06)
          dummy_byte,dummy_byte, // Serial Number:40033(032)String L(06)
          dummy_byte,dummy_byte, // Serial Number:40033(032)String L(06)
          dummy_byte,dummy_byte, // Cal Code:40039(038)Integer L(01)
          dummy_byte,dummy_byte // Sensor Data Log Interval:40040(039)Integer L(01)
        }
    }
}


COMMAND read_IC1_Float03
{
	SLOT IC1_SLOTADR;
	INDEX 55;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          IC1_Setting3, // Conductivity Cell Value:40056(055)Float L(02)
          dummy_byte,dummy_byte, // Conductivity Solution Cal Reference Temperature:40058(057)Float L(02)
          dummy_byte,dummy_byte, // Conductivity Solution Cal Reference Temperature:40058(057)Float L(02)
          dummy_byte,dummy_byte, // Conductivity Solution Cal Temperature Slope:40060(059)Float L(02)
          dummy_byte,dummy_byte, // Conductivity Solution Cal Temperature Slope:40060(059)Float L(02)
          IC1_Setting8, // Linear Temp Compensation Reference Temperature:40062(061)Float L(02)
          IC1_Setting7, // Linear Temp Compensation Temperature Slope:40064(063)Float L(02)
          dummy_byte,dummy_byte, // Sensor Offset Adc Counts:40066(065)Float L(02)
          dummy_byte,dummy_byte, // Sensor Offset Adc Counts:40066(065)Float L(02)
          dummy_byte,dummy_byte, // Conductivity Value during solution cal:40068(067)Float L(02)
          dummy_byte,dummy_byte, // Conductivity Value during solution cal:40068(067)Float L(02)
          dummy_byte,dummy_byte, // Cal Edit Value Tag:40070(069)Integer L(01)
          dummy_byte,dummy_byte, // Cal Edit Value:40071(070)Float L(02)
          dummy_byte,dummy_byte, // Cal Edit Value:40071(070)Float L(02)
          dummy_byte,dummy_byte, // Temperature Compensation Type:40073(072)Integer L(01)
          dummy_byte,dummy_byte, // Concentration Compensation Type:40074(073)Integer L(01)
          dummy_byte,dummy_byte, // Conc Built-in Compensation Type:40075(074)Integer L(01)
          dummy_byte,dummy_byte, // TDS Factor Type:40076(075)Integer L(01)
          dummy_byte,dummy_byte, // TDS Factor :40077(076)Float L(02)
          dummy_byte,dummy_byte, // TDS Factor :40078(076)Float L(02)
          dummy_byte,dummy_byte, // Table X Units:40079(078)Integer L(01)
          dummy_byte,dummy_byte, // Table Y Units:40080(079)Integer L(01)
          dummy_byte,dummy_byte, // Table X Minimum Value:40081(080)Float L(02)
          dummy_byte,dummy_byte, // Table X Minimum Value:40081(080)Float L(02)
          dummy_byte,dummy_byte, // Table X Maximum Value:40083(082)Float L(02)
          dummy_byte,dummy_byte, // Table X Maximum Value:40083(082)Float L(02)
          dummy_byte,dummy_byte, // Table Y Minimum Value:40085(084)Float L(02)
          dummy_byte,dummy_byte, // Table Y Minimum Value:40085(084)Float L(02)
          dummy_byte,dummy_byte, // Table Y Maximum Value:40087(086)Float L(02)
          dummy_byte,dummy_byte, // Table Y Maximum Value:40087(086)Float L(02)
          dummy_byte,dummy_byte, // Table X Value:40089(088)Float L(02)
          dummy_byte,dummy_byte, // Table X Value:40089(088)Float L(02)
          dummy_byte,dummy_byte // Table Y Value:40091(090)Float L(02)
        }
    }
}

COMMAND read_IC1_Float04
{
	SLOT IC1_SLOTADR;
	INDEX 76;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          IC1_Setting15, // TDS Factor :40077(076)Float L(02)
          dummy_byte,dummy_byte, // Table X Units:40079(078)Integer L(01)
          dummy_byte,dummy_byte, // Table Y Units:40080(079)Integer L(01)
          dummy_byte,dummy_byte, // Table X Minimum Value:40081(080)Float L(02)
          dummy_byte,dummy_byte, // Table X Minimum Value:40081(080)Float L(02)
          dummy_byte,dummy_byte, // Table X Maximum Value:40083(082)Float L(02)
          dummy_byte,dummy_byte, // Table X Maximum Value:40083(082)Float L(02)
          dummy_byte,dummy_byte, // Table Y Minimum Value:40085(084)Float L(02)
          dummy_byte,dummy_byte, // Table Y Minimum Value:40085(084)Float L(02)
          dummy_byte,dummy_byte, // Table Y Maximum Value:40087(086)Float L(02)
          dummy_byte,dummy_byte, // Table Y Maximum Value:40087(086)Float L(02)
          dummy_byte,dummy_byte, // Table X Value:40089(088)Float L(02)
          dummy_byte,dummy_byte, // Table X Value:40089(088)Float L(02)
          dummy_byte,dummy_byte, // Table Y Value:40091(090)Float L(02)
          dummy_byte,dummy_byte, // Table Y Value:40091(090)Float L(02)
          dummy_byte,dummy_byte, // Table Point:40093(092)Integer L(01)
          dummy_byte,dummy_byte, // Table Editting Action:40094(093)Integer L(01)
          dummy_byte,dummy_byte, // Table Pt1 X Value:40095(094)Float L(02)
          dummy_byte,dummy_byte, // Table Pt1 X Value:40095(094)Float L(02)
          dummy_byte,dummy_byte, // Table Pt2 X Value:40097(096)Float L(02)
          dummy_byte,dummy_byte, // Table Pt2 X Value:40097(096)Float L(02)
          dummy_byte,dummy_byte, // Table Pt3 X Value:40099(098)Float L(02)
          dummy_byte,dummy_byte, // Table Pt3 X Value:40099(098)Float L(02)
          dummy_byte,dummy_byte, // Table Pt4 X Value:40101(100)Float L(02)
          dummy_byte,dummy_byte, // Table Pt4 X Value:40101(100)Float L(02)
          dummy_byte,dummy_byte, // Table Pt5 X Value:40103(102)Float L(02)
          dummy_byte,dummy_byte, // Table Pt5 X Value:40103(102)Float L(02)
          dummy_byte,dummy_byte, // Table Pt6 X Value:40105(104)Float L(02)
          dummy_byte,dummy_byte, // Table Pt6 X Value:40105(104)Float L(02)
          dummy_byte,dummy_byte, // Table Pt7 X Value:40107(106)Float L(02)
          dummy_byte,dummy_byte, // Table Pt7 X Value:40107(106)Float L(02)
          dummy_byte,dummy_byte, // Table Pt8 X Value:40109(108)Float L(02)
          dummy_byte,dummy_byte, // Table Pt8 X Value:40109(108)Float L(02)
          dummy_byte,dummy_byte, // Table Pt9 X Value:40111(110)Float L(02)
          dummy_byte,dummy_byte // Table Pt9 X Value:40111(110)Float L(02)

        }
    }
}


COMMAND read_IC1_Var01
{
	SLOT IC1_SLOTADR;
	INDEX 14;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          IC1_Setting1, // Measurement Type:40015(014)Integer L(01)
          IC1_Unit5, // Temperature Units-C or F:40016(015)Integer L(01)
          IC1_Setting2, // Sensor Filter:40017(016)Integer L(01)
          IC1_Setting5, // Temeperature Element Type:40018(017)Integer L(01)
          dummy_byte,dummy_byte, // Temperature User Value Tag:40019(018)Integer L(01)
          dummy_byte,dummy_byte, // Temperature User Value:40020(019)Float L(02)
          dummy_byte,dummy_byte, // Temperature User Value:40020(019)Float L(02)
          dummy_byte,dummy_byte, // Temperature Factor:40022(021)Float L(02)
          dummy_byte,dummy_byte, // Temperature Factor:40022(021)Float L(02)
          dummy_byte,dummy_byte, // Output Mode:40024(023)Integer L(01)
          dummy_byte,dummy_byte, // Cal Leave Mode:40025(024)Integer L(01)
          dummy_byte,dummy_byte, // Cal Abort Mode:40026(025)Integer L(01)
          dummy_byte,dummy_byte, // Software Version:40027(026)String L(06)
          dummy_byte,dummy_byte, // Software Version:40027(026)String L(06)
          dummy_byte,dummy_byte, // Software Version:40027(026)String L(06)
          dummy_byte,dummy_byte, // Software Version:40027(026)String L(06)
          dummy_byte,dummy_byte, // Software Version:40027(026)String L(06)
          dummy_byte,dummy_byte, // Software Version:40027(026)String L(06)
          dummy_byte,dummy_byte, // Serial Number:40033(032)String L(06)
          dummy_byte,dummy_byte, // Serial Number:40033(032)String L(06)
          dummy_byte,dummy_byte, // Serial Number:40033(032)String L(06)
          dummy_byte,dummy_byte, // Serial Number:40033(032)String L(06)
          dummy_byte,dummy_byte, // Serial Number:40033(032)String L(06)
          dummy_byte,dummy_byte, // Serial Number:40033(032)String L(06)
          dummy_byte,dummy_byte, // Cal Code:40039(038)Integer L(01)
          IC1_Diag5, // Sensor Data Log Interval:40040(039)Integer L(01)
          IC1_Diag6, // Temperature Data Log Interval:40041(040)Integer L(01)
          dummy_byte,dummy_byte, // Production Date:40042(041)Unsigned Integer L(02)
          dummy_byte,dummy_byte, // Production Date:40042(041)Unsigned Integer L(02)
          dummy_byte,dummy_byte, // Last Calibration Date:40044(043)Unsigned Integer L(02)
          dummy_byte,dummy_byte, // Last Calibration Date:40044(043)Unsigned Integer L(02)
          IC1_Diag1, // Sensor Running Days:40046(045)Integer L(01)
          IC1_Setting9 // Reject Frequency:40047(046)Integer L(01)
        }
    }
}

COMMAND read_IC1_Var02
{
	SLOT IC1_SLOTADR;
	INDEX 52;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          IC1_Diag2, // Calibration Warning Days:40053(052)Integer L(01)
          IC1_Diag3, // Sensor Warning Days:40054(053)Integer L(01)
          IC1_Unit1, // Conductivity Units:40055(054)Integer L(01)
          dummy_byte,dummy_byte,// Conductivity Cell Value:40056(055)Float L(02)
          dummy_byte,dummy_byte,// Conductivity Cell Value:40057(055)Float L(02)
          dummy_byte,dummy_byte,// Conductivity Solution Cal Reference Temperature:40058(057)Float L(02)
          dummy_byte,dummy_byte,// Conductivity Solution Cal Reference Temperature:40059(057)Float L(02)
          dummy_byte,dummy_byte,// Conductivity Solution Cal Temperature Slope:40060(059)Float L(02)
          dummy_byte,dummy_byte,// Conductivity Solution Cal Temperature Slope:40061(059)Float L(02)
          dummy_byte,dummy_byte,// Linear Temp Compensation Reference Temperature:40062(061)Float L(02)
          dummy_byte,dummy_byte,// Linear Temp Compensation Reference Temperature:40063(061)Float L(02)
          dummy_byte,dummy_byte,// Linear Temp Compensation Temperature Slope:40064(063)Float L(02)
          dummy_byte,dummy_byte,// Linear Temp Compensation Temperature Slope:40065(063)Float L(02)
          dummy_byte,dummy_byte,// Sensor Offset Adc Counts:40066(065)Float L(02)
          dummy_byte,dummy_byte,// Sensor Offset Adc Counts:40067(065)Float L(02)
          dummy_byte,dummy_byte,// Conductivity Value during solution cal:40068(067)Float L(02)
          dummy_byte,dummy_byte,// Conductivity Value during solution cal:40069(067)Float L(02)
          dummy_byte,dummy_byte,// Cal Edit Value Tag:40070(069)Integer L(01)
          dummy_byte,dummy_byte,// Cal Edit Value:40071(070)Float L(02)
          dummy_byte,dummy_byte,// Cal Edit Value:40072(070)Float L(02)
          IC1_Setting11, // Temperature Compensation Type:40073(072)Integer L(01)
          IC1_Setting12, // Concentration Compensation Type:40074(073)Integer L(01)
          IC1_Setting13, // Conc Built-in Compensation Type:40075(074)Integer L(01)
          IC1_Setting14 // TDS Factor Type:40076(075)Integer L(01)
        }
    }
}

COMMAND read_IC1_Var03
{
	SLOT IC1_SLOTADR;
	INDEX 6;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
        IC1_SampleLocation // Sensor Name:40007(006)String L(06)

        }
    }
}



/************************************************************************/
/*		WRITE COMMANDS						*/
/************************************************************************/
COMMAND write_IC1_SampleLocation
{
	SLOT IC1_SLOTADR;
	INDEX 6;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              IC1_SampleLocation
        }
        REPLY
        {
            
        }
    }
}


COMMAND write_IC1_Set01
{
	SLOT IC1_SLOTADR;
	INDEX 14;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              IC1_Setting1,
              IC1_Unit5,
              IC1_Setting2,
              IC1_Setting5
        }
        REPLY
        {
            
        }
    }
}


COMMAND write_IC1_Setting6
{
	SLOT IC1_SLOTADR;
	INDEX 19;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              IC1_Setting6
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_IC1_Setting10
{
	SLOT IC1_SLOTADR;
	INDEX 21;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              IC1_Setting10
        }
        REPLY
        {
            
        }
    }
}


COMMAND write_IC1_Diag5
{
	SLOT IC1_SLOTADR;
	INDEX 39;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              IC1_Diag5
        }
        REPLY
        {

        }
    }
}

COMMAND write_IC1_Diag6
{
	SLOT IC1_SLOTADR;
	INDEX 40;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              IC1_Diag6
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_IC1_Diag1
{
	SLOT IC1_SLOTADR;
	INDEX 45;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              IC1_Diag1
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_IC1_Setting12
{
	SLOT IC1_SLOTADR;
	INDEX 73;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              IC1_Setting12
        }
        REPLY
        {

        }
    }
}

COMMAND write_IC1_Setting9
{
	SLOT IC1_SLOTADR;
	INDEX 46;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              IC1_Setting9
        }
        REPLY
        {

        }
    }
}

COMMAND write_IC1_Set03
{
	SLOT IC1_SLOTADR;
	INDEX 52;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              IC1_Diag2,
              IC1_Diag3,
              IC1_Unit1
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_IC1_Setting3
{
	SLOT IC1_SLOTADR;
	INDEX 55;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              IC1_Setting3
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_IC1_Setting7
{
	SLOT IC1_SLOTADR;
	INDEX 63;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              IC1_Setting7
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_IC1_Setting8
{
	SLOT IC1_SLOTADR;
	INDEX 61;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              IC1_Setting8
        }
        REPLY
        {

        }
    }
}

COMMAND write_IC1_Set05
{
	SLOT IC1_SLOTADR;
	INDEX 72;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              IC1_Setting11
        }
        REPLY
        {

        }
    }
}


COMMAND write_IC1_Set04_1
{
	SLOT IC1_SLOTADR;
	INDEX 74;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              IC1_Setting13

        }
        REPLY
        {

        }
    }
}

COMMAND write_IC1_Set04_2
{
	SLOT IC1_SLOTADR;
	INDEX 75;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              IC1_Setting14
        }
        REPLY
        {

        }
    }
}


COMMAND write_IC1_Setting15
{
	SLOT IC1_SLOTADR;
	INDEX 76;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              IC1_Setting15
        }
        REPLY
        {
            
        }
    }
}





