/*---------------------------------------------------------------------------*/
/*Copyright (C)	Hach-Lange (2010). All Rights Reserved.                      */
/*Product:	SIMATIC PDM  	                                                 */
/*Device:	SC200 InduCond-PHD  	                                         */
/*Description:	Device Description	                                         */
/*Dictionary:	SIPADC01.dct	                                             */
/*$Revision:	1.0  $  	                                                 */
/*$Date:		Maerz 2010	                                                 */
/*File:			sc200_InduCond_phd.ddl                                       */
/*	Author:		T.Thiel Hach-Lange                                       	 */
/*				R.Mellows Hach-Lange                                         */
/*				R.Stollenwerk Hach-Lange                                     */
/*---------------------------------------------------------------------------*/

MANUFACTURER	213,
DEVICE_TYPE	    1,
DEVICE_REVISION 1,
DD_REVISION     0

#define READ_TIMEOUT_VAL 0
#define WRITE_TIMEOUT_VAL 0

#define DEVICE_TITLE			"SC200 Inductive Conductivity + pHD"

#define IC1_SLOTADR 21
#define PHD2_SLOTADR 23



#include	"I1_InduCond.inc"  	//erstes Geraet
#include	"2_phd.inc"  		//zweites Geraet

/************************************************************************/
/*      Methoden                                                        */
/************************************************************************/
METHOD METHOD_WOX1
{
	LABEL "Without1 0x";
	DEFINITION
	{
	DD_STRING Serial_str1,Serial_str2,Serial_str3,pos_str;
	unsigned int zw;
	unsigned int s1,s2,s3,s4;

        zw=Serial1_1;
        s1=zw>>12;
        zw=zw-(s1<<12);
        s2=zw>>8;
        zw=zw-(s2<<8);
        s3=zw>>4;
        zw=zw-(s3<<4);
        s4=zw;
	Serial_str1=itoa(s1)+itoa(s2)+itoa(s3)+itoa(s4);

        zw=Serial1_2;
        s1=zw>>12;
        zw=zw-(s1<<12);
        s2=zw>>8;
        zw=zw-(s2<<8);
        s3=zw>>4;
        zw=zw-(s3<<4);
        s4=zw;
        Serial_str2=itoa(s1)+itoa(s2)+itoa(s3)+itoa(s4);

        zw=Serial1_3;
        s1=zw>>12;
        zw=zw-(s1<<12);
        s2=zw>>8;
        zw=zw-(s2<<8);
        s3=zw>>4;
        zw=zw-(s3<<4);
        s4=zw;
        Serial_str3=itoa(s1)+itoa(s2)+itoa(s3)+itoa(s4);

        Serial1_WOX= Serial_str1+Serial_str2+Serial_str3;
	}
}

METHOD METHOD_WOX2
{
	LABEL "Without2 0x";
	DEFINITION
	{
	DD_STRING Serial_str1,Serial_str2,Serial_str3,pos_str;
	unsigned int zw;
	unsigned int s1,s2,s3,s4;

        zw=Serial2_1;
        s1=zw>>12;
        zw=zw-(s1<<12);
        s2=zw>>8;
        zw=zw-(s2<<8);
        s3=zw>>4;
        zw=zw-(s3<<4);
        s4=zw;
	Serial_str1=itoa(s1)+itoa(s2)+itoa(s3)+itoa(s4);

        zw=Serial2_2;
        s1=zw>>12;
        zw=zw-(s1<<12);
        s2=zw>>8;
        zw=zw-(s2<<8);
        s3=zw>>4;
        zw=zw-(s3<<4);
        s4=zw;
        Serial_str2=itoa(s1)+itoa(s2)+itoa(s3)+itoa(s4);

        zw=Serial2_3;
        s1=zw>>12;
        zw=zw-(s1<<12);
        s2=zw>>8;
        zw=zw-(s2<<8);
        s3=zw>>4;
        zw=zw-(s3<<4);
        s4=zw;
        Serial_str3=itoa(s1)+itoa(s2)+itoa(s3)+itoa(s4);

        Serial2_WOX= Serial_str1+Serial_str2+Serial_str3;
	}
}


/************************************************************************/
/*		Variablen						*/
/************************************************************************/

//--Lokale Seriennummer ohne 0x--
VARIABLE Serial1_WOX
{
	LABEL 	"Serial No, Device 1" 	"|de|Seriennummer, Gert 1";
	TYPE	ASCII (16)
		{
		DEFAULT_VALUE "0000000000000000";
		}

	CLASS LOCAL;

}

VARIABLE Serial2_WOX
{
	LABEL 	"Serial No, Device 2" 	"|de|Seriennummer, Gert 2";
	TYPE	ASCII (16)
		{
		DEFAULT_VALUE "0000000000000000";
		}

	CLASS LOCAL;

}


VARIABLE VendorName
{
	LABEL 	"Vendor Name""|de|Geraetehersteller";
	CLASS	CONTAINED;
	TYPE	ASCII (12)
		{
			DEFAULT_VALUE "Hach-Lange";
		}
	HANDLING	READ;
}

VARIABLE ModelName
{
	LABEL 	"Fieldbus type" "|de|Feldbustyp";
	CLASS	CONTAINED;
	TYPE	ASCII (14)
		{
			DEFAULT_VALUE "SC device";
		}
	HANDLING	READ;
}

VARIABLE ModelNummer
{
	LABEL 	"Model Number""|de|Model Nummer";
	CLASS	CONTAINED;
	TYPE	ASCII (15)
		{
			DEFAULT_VALUE "";
		}
	HANDLING	READ;
}
//------------Serien Nr-------------
VARIABLE Serial1_1
{
	LABEL 	"Serial No 1" 	"|de|Seriennummer 1";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{
		}
	HANDLING	READ;
}

VARIABLE Serial1_2
{
	LABEL 	"Serial No 2" 	"|de|Seriennummer 2";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{
		}
	HANDLING	READ;
}

VARIABLE Serial1_3
{
	LABEL 	"Serial No 3" 	"|de|Seriennummer 3";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{
		}
	HANDLING	READ;
        POST_READ_ACTIONS
          {
            METHOD_WOX1
          }
}

//-------

VARIABLE Serial2_1
{
	LABEL 	"Serial No 1" 	"|de|Seriennummer 1";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{
		}
	HANDLING	READ;
}

VARIABLE Serial2_2
{
	LABEL 	"Serial No 2" 	"|de|Seriennummer 2";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{
		}
	HANDLING	READ;
}

VARIABLE Serial2_3
{
	LABEL 	"Serial No 3" 	"|de|Seriennummer 3";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{
		}
	HANDLING	READ;
        POST_READ_ACTIONS
          {
            METHOD_WOX2
          }
}
//------------Serien Nr-------------ENDE---

VARIABLE DeviceID1
{
	LABEL 	"Device ID" 	"|de|Geraetekennung";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{

			{10,			"3798 Cond"		},
			{12,			"LDO"			},
			{13,			"1720E"			},
			{17,			"pHD SC"		},
			{18,			"5740 DO"		},
			{19,			"34xx Cont. Cond."	},
			{20,			"37xx Ind. Cond."	},
			{21,			"pH SC"				},
			{26,   			"Surface Scatter 7" },
			{39,   			"SC200"   			},  
			{101,			"ULTRATURB SC"		},
			{102,			"Nitratax eco"  	},
			{103,			"Nitratax plus"		},
			{104,			"Solitax SC"    	},
			{105,			"Nitratax clear"	},
			{106,			"UVAS plus"     	},
			{107,			"S::CAN CARBO::LYZER"	},
			{108,			"S::CAN NITRO::LYZER"   },
			{109,			"PHOSPHAX SC"     	},
			{110,			"AMTAX SC"     	 	},
			{112,			"NH4D SC"     		},
			{113,			"SONATAX SC"     	},
			{114,			"PHOSPHAX SC"     	},
			{120,   		"NO3D SC"           }

		}
	HANDLING	READ;
}

VARIABLE DeviceID2
{
	LABEL 	"Device ID" 	"|de|Geraetekennung";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{

			{10,			"3798 Cond"		},
			{12,			"LDO"			},
			{13,			"1720E"			},
			{17,			"pHD SC"		},
			{18,			"5740 DO"		},
			{19,			"34xx Cont. Cond."	},
			{20,			"37xx Ind. Cond."	},
			{21,			"pH SC"				},
			{26,   			"Surface Scatter 7" },
			{39,   			"SC200"   			},  
			{101,			"ULTRATURB SC"		},
			{102,			"Nitratax eco"  	},
			{103,			"Nitratax plus"		},
			{104,			"Solitax SC"    	},
			{105,			"Nitratax clear"	},
			{106,			"UVAS plus"     	},
			{107,			"S::CAN CARBO::LYZER"	},
			{108,			"S::CAN NITRO::LYZER"   },
			{109,			"PHOSPHAX SC"     	},
			{110,			"AMTAX SC"     	 	},
			{112,			"NH4D SC"     		},
			{113,			"SONATAX SC"     	},
			{114,			"PHOSPHAX SC"     	},
			{120,   		"NO3D SC"           }

		}
	HANDLING	READ;
}


VARIABLE ManufactID1
{
	LABEL 	"Manufacturer ID" 	"|de|Herstellerkennung";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{

		}
	HANDLING	READ;
}

VARIABLE ManufactID2
{
	LABEL 	"Manufacturer ID" 	"|de|Herstellerkennung";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{

		}
	HANDLING	READ;
}

VARIABLE Length1
{
	LABEL 	"Length Member table" 	"|de|Lnge Teilnehmertabelle";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{
		}
	HANDLING	READ;
}

VARIABLE Length2
{
	LABEL 	"Length Member table" 	"|de|Lnge Teilnehmertabelle";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{
		}
	HANDLING	READ;
}

VARIABLE Status1
{
	LABEL 	"Status ";
	CLASS	DYNAMIC;
	STYLE "MULTILINE 22 17";
	TYPE	BIT_ENUMERATED (2)
	{

		{0,   	"OK"						"|de|OK"	 		 },
		{1,   	"Calibration start / in progress"		"|de|Kalibrierung aktiv"	 },
		{2,   	"Cleaning start / in progress"			"|de|Reinigungszyklus aktiv"	 },
		{4,   	"Enter(d) Service/Maintenance menu"		"|de|Betriebsart Service"	 },
		{8,   	"Common Error"					"|de|Sammelstrung"		 },
		{16,   	"Measurement 0 Quality Bad"			"|de|Messung 0 Qualittsfehler"	 },
		{32,   	"Measurement 0 low limit"			"|de|Messung 0 unterer Grenzwert"},
		{64,    "Measurement 0 high limit"			"|de|Messung 0 oberer Grenzwert" },
		{128,   "Measurement 1 Quality Bad"			"|de|Messung 1 Qualittsfehler"	 },
		{256,   "Measurement 1 low limit"			"|de|Messung 1 unterer Grenzwert"},
		{512,   "Measurement 1 high limit"			"|de|Messung 1 oberer Grenzwert" },
		{1024,  "Measurement 2 Quality Bad"			"|de|Messung 2 Qualittsfehler"	 },
		{2048,  "Measurement 2 low limit"			"|de|Messung 2 unterer Grenzwert"},
		{4096,  "Measurement 2 high limit"			"|de|Messung 2 oberer Grenzwert" },
		{8192,  "Measurement 3 Quality Bad"			"|de|Messung 3 Qualittsfehler"	 },
		{16384, "Measurement 3 low limit"			"|de|Messung 3 unterer Grenzwert"},
		{32768, "Measurement 3 high limit"			"|de|Messung 3 oberer Grenzwert" }

	}
	HANDLING	READ;
}

VARIABLE Status2
{
	LABEL 	"Status ";
	CLASS	DYNAMIC;
	STYLE "MULTILINE 22 17";
	TYPE	BIT_ENUMERATED (2)
	{

		{0,   	"OK"						"|de|OK"	 		 },
		{1,   	"Calibration start / in progress"		"|de|Kalibrierung aktiv"	 },
		{2,   	"Cleaning start / in progress"			"|de|Reinigungszyklus aktiv"	 },
		{4,   	"Enter(d) Service/Maintenance menu"		"|de|Betriebsart Service"	 },
		{8,   	"Common Error"					"|de|Sammelstrung"		 },
		{16,   	"Measurement 0 Quality Bad"			"|de|Messung 0 Qualittsfehler"	 },
		{32,   	"Measurement 0 low limit"			"|de|Messung 0 unterer Grenzwert"},
		{64,    "Measurement 0 high limit"			"|de|Messung 0 oberer Grenzwert" },
		{128,   "Measurement 1 Quality Bad"			"|de|Messung 1 Qualittsfehler"	 },
		{256,   "Measurement 1 low limit"			"|de|Messung 1 unterer Grenzwert"},
		{512,   "Measurement 1 high limit"			"|de|Messung 1 oberer Grenzwert" },
		{1024,  "Measurement 2 Quality Bad"			"|de|Messung 2 Qualittsfehler"	 },
		{2048,  "Measurement 2 low limit"			"|de|Messung 2 unterer Grenzwert"},
		{4096,  "Measurement 2 high limit"			"|de|Messung 2 oberer Grenzwert" },
		{8192,  "Measurement 3 Quality Bad"			"|de|Messung 3 Qualittsfehler"	 },
		{16384, "Measurement 3 low limit"			"|de|Messung 3 unterer Grenzwert"},
		{32768, "Measurement 3 high limit"			"|de|Messung 3 oberer Grenzwert" }

	}
	HANDLING	READ;
}


VARIABLE Error1
{
	LABEL	"Error Detection"		"|de|Fehlermeldung";
	CLASS	DYNAMIC;
	STYLE "MULTILINE 22 17";
	TYPE	BIT_ENUMERATED (2)
	{
			{0,   	"No Error"				"|de|Kein Fehler"			},
			{1,   	"Measurement calibration Error"		"|de|Kalibrierfehler"			},
			{2,   	"Electronic adjustment Error"		"|de|Elektronik / Einstellfehler"	},
			{4,   	"Cleaning Error"			"|de|Reinigungsfehler"			},
			{8,   	"Measuring module Error"		"|de|Messmodulfehler"			},
			{16,   	"Settings Error"			"|de|Fehler Einstellungen"		},
			{32,   	"Hardware Error"			"|de|Hardwarefehler"			},
			{64,    "Internal communication Error"		"|de|Interner Kommunikationsfehler"	},
			{128,   "Humidity Error"			"|de|Feuchtigkeit erkannt"		},
			{256,   "Temperatur Error"			"|de|Temperaturfehler"			},
			{512,   ""										},
			{1024,  ""										},
			{2048,  ""										},
			{4096,  "Questionable measurement Warning"	"|de|Warnung Messwert unsicher"		},
			{8192,  "Safety Warning"			"|de|Warnung Sicherheitseinrichtung"	},
			{16384, "Reagent Warning"			"|de|Warnung Reagenz"			},
			{32768, "Maintenance Warning"			"|de|Warnung Instandhaltung"		}
	}
	HANDLING	READ;
}

VARIABLE Error2
{
	LABEL	"Error Detection"		"|de|Fehlermeldung";
	CLASS	DYNAMIC;
	STYLE "MULTILINE 22 17";
	TYPE	BIT_ENUMERATED (2)
	{
			{0,   	"No Error"				"|de|Kein Fehler"			},
			{1,   	"Measurement calibration Error"		"|de|Kalibrierfehler"			},
			{2,   	"Electronic adjustment Error"		"|de|Elektronik / Einstellfehler"	},
			{4,   	"Cleaning Error"			"|de|Reinigungsfehler"			},
			{8,   	"Measuring module Error"		"|de|Messmodulfehler"			},
			{16,   	"Settings Error"			"|de|Fehler Einstellungen"		},
			{32,   	"Hardware Error"			"|de|Hardwarefehler"			},
			{64,    "Internal communication Error"		"|de|Interner Kommunikationsfehler"	},
			{128,   "Humidity Error"			"|de|Feuchtigkeit erkannt"		},
			{256,   "Temperatur Error"			"|de|Temperaturfehler"			},
			{512,   ""										},
			{1024,  ""										},
			{2048,  ""										},
			{4096,  "Questionable measurement Warning"	"|de|Warnung Messwert unsicher"		},
			{8192,  "Safety Warning"			"|de|Warnung Sicherheitseinrichtung"	},
			{16384, "Reagent Warning"			"|de|Warnung Reagenz"			},
			{32768, "Maintenance Warning"			"|de|Warnung Instandhaltung"		}
	}
	HANDLING	READ;
}

/************************************************************************/
/*-----------------------COMMANDS---------------------------------------*/
/************************************************************************/
 //----------------------------------------------
//------IDENTIFICATIONS-------------------------
//----------------------------------------------
COMMAND read_VendorName
{
	SLOT 0;
	INDEX 100;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            VendorName
        }
    }
}

COMMAND read_ModelName
{
	SLOT 0;
	INDEX 101;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            ModelName
        }
    }
}

COMMAND read_ModelNummer
{
	SLOT 0;
	INDEX 102;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            ModelNummer
        }
    }
}

COMMAND read_MemberTable
{
	SLOT 10;
	INDEX 0;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
           Serial1_1, //Index 0,,,
           Serial1_2, //Index 1,,,
           Serial1_3, //Index 2,,,
           DeviceID1, //Index 3,,,
           ManufactID1, //Index 4,,,
           Length1, //Index 5,,,
           Error1, //Index 6,,,
		   Status1,
		   dummy_byte,dummy_byte,
		   dummy_byte,dummy_byte,
		   dummy_byte,dummy_byte,
		   dummy_byte,dummy_byte,
		   dummy_byte,dummy_byte,
		   dummy_byte,dummy_byte,
		   dummy_byte,dummy_byte,
		   dummy_byte,dummy_byte,
           Serial2_1, //Index 0,,,
           Serial2_2, //Index 1,,,
           Serial2_3, //Index 2,,,
           DeviceID2, //Index 3,,,
           ManufactID2, //Index 4,,,
           Length2, //Index 5,,,
           Error2, //Index 6,,,
		   Status2
        }
    }
}

/************************************************************************/
/*  Upload from device to PC              Daten lesen vom Gert zum PC  */
/************************************************************************/


MENU download_variables
{
	LABEL	[menu_load_to_PC];
	ITEMS
	{ 
		VendorName,
		ModelName,
		ModelNummer,
		IC1_Measurement1,
		IC1_Measurement3,
		IC1_Unit1,
		IC1_Unit5,		
		IC1_Diag1,
		IC1_Diag2,
		IC1_Diag3,
		IC1_Diag5,
		IC1_Diag6,
		IC1_Setting1,
		IC1_Setting2,
		IC1_Setting3,
		IC1_Setting5,
		IC1_Setting6,
		IC1_Setting7,
		IC1_Setting8,
		IC1_Setting9,
		IC1_Setting10,
		IC1_Setting11,
		IC1_Setting12,
		IC1_Setting13,
		IC1_Setting14,
		IC1_Setting15,
		IC1_SampleLocation,
		Serial1_1,
///////////////// 2nd device //////////	
	     PHD2_Unit1,
	     PHD2_Unit2,
	     PHD2_Measurement1,
	     PHD2_Measurement2,
	     PHD2_Measurement3,
	     PHD2_Measurement4,
	     PHD2_Measurement5,
	     PHD2_SeriaInst,
	     PHD2_Setting1,
	     PHD2_Setting3,
	     PHD2_Setting4,
	     PHD2_Setting5,
	     PHD2_Setting10,
         PHD2_Setting11,
         PHD2_Setting12,
         PHD2_Setting13,
         PHD2_Setting14,
         PHD2_Setting16,
         PHD2_Setting2,
         PHD2_Setting6,
         PHD2_Setting7,
         PHD2_IDENT1,
         PHD2_IDENT4,
         PHD2_Diag1,
	     PHD2_Diag7,
	     PHD2_Diag8,
	     PHD2_Diag9,
	     PHD2_Diag10,
	     PHD2_Diag11
	}
} 


/************************************************************************/
/*  Write from PC to device        Datenschreiben vom PC zum Gert	*/
/************************************************************************/

MENU upload_variables
{
	LABEL	[menu_load_to_device];
	ITEMS
	{
		IC1_SampleLocation,
		IC1_Unit1,
		IC1_Unit5,
		IC1_Setting1,
		IC1_Setting2,
		IC1_Setting3,
		IC1_Setting5,
		IC1_Setting6,
		IC1_Setting7,
		IC1_Setting8,
		IC1_Setting9,
		IC1_Setting10,
		IC1_Setting11,
		IC1_Setting12,
		IC1_Setting13,
		IC1_Setting14,
		IC1_Setting15,
		IC1_Diag2,
		IC1_Diag3,
		IC1_Diag5,
		IC1_Diag6,
///////////////// 2nd device //////////
         PHD2_Unit1,
         PHD2_Unit2,
	     PHD2_Setting1,
	     PHD2_Setting3,
	     PHD2_Setting4,
	     PHD2_Setting5,
	     PHD2_Setting10,
	     PHD2_Setting11,
	     PHD2_Setting12,
	     PHD2_Setting13,
	     PHD2_Setting14,
	     PHD2_Setting16,
	     PHD2_Settings20,
	     PHD2_Setting2,
	     PHD2_Setting6,
	     PHD2_Setting7
		
	}
}

/************************************************************************/
/*	  Table: Specialist						*/
/************************************************************************/

MENU Table_Main_Specialist
{
	LABEL	DEVICE_TITLE ;

	ITEMS
	{
		Tab_s_preferences,
		Tab_s_preferencesM1,
		Tab_s_preferencesM2,
		Tab_s_settings,
		Tab_s_diag,
		Tab_s_output,
		Tab_s_settings2,
		Tab_s_diag2,
		Tab_s_output2			
	}
}

/************************************************************************/
/*	  Main Menus							*/
/************************************************************************/

/************************************************************************/
/*	  Menu: Bar							*/
/************************************************************************/

MENU Menu_Main_Specialist
{
    LABEL		[main_menu];
    ITEMS
    {
        Menu_File,
        Menu_S_Device,
        Menu_S_View,
        Menu_S_Options,
        Menu_Help
    }
}

/************************************************************************/
/*	  Menu: Device							*/
/************************************************************************/

MENU Menu_S_Device
{
    LABEL		[menu_Device];
    ITEMS
    {
    std_LoadinDevice,
    std_LoadinPC,
    SEPARATOR,
	OnlineWindow_range_preferences,
	OnlineWindow_range_preferences2,
	OnlineWindow_clean_calib,
	OnlineWindow_clean_calib2
    }
}

/************************************************************************/
/*	  Menu: View							*/
/************************************************************************/

MENU Menu_S_View
{
    LABEL		[menu_View];
    ITEMS
    {
        OnlineWindow_display,
//	OnlineWindow_actual_mode
    }
}

/************************************************************************/
/*	  Online-Windows						*/
/************************************************************************/

MENU OnlineWindow_range_preferences
{
    LABEL	"Settings sensor 1" "|de|Einstelldaten 1";
    ITEMS
    {
		Page_range_preferences
    }
}

MENU OnlineWindow_range_preferences2
{
    LABEL	"Settings sensor 2" "|de|Einstelldaten 2";
    ITEMS
    {
		Page_range_preferences2
    }
}

MENU Page_range_preferences
{
    LABEL	"Settings 1" "|de|Voreinstellungen 1" ;
    ITEMS
    	{
		IC1_SampleLocation,
		IC1_Unit1,
		IC1_Unit5,
		IC1_Setting1,
		IC1_Setting2,
		IC1_Setting3,
		IC1_Setting5,
		IC1_Setting6,
		IC1_Setting7,
		IC1_Setting8,
		IC1_Setting9,
		IC1_Setting10,
		IC1_Setting11,
		IC1_Setting12,
		IC1_Setting13,
		IC1_Setting14,
		IC1_Setting15,
		IC1_Diag2,
		IC1_Diag3,
		IC1_Diag5,
		IC1_Diag6
	}
}

MENU Page_range_preferences2
{
    LABEL	"Settings 2" "|de|Voreinstellungen 2" ;
    ITEMS
    	{
                PHD2_Settings20,
		PHD2_Unit1,
		PHD2_Unit2,
		PHD2_Setting1,
		PHD2_Setting3,
		PHD2_Setting4,
		PHD2_Setting5,
		PHD2_Setting10,
		PHD2_Setting11,
		PHD2_Setting12,
		PHD2_Setting13,
		PHD2_Setting14,
		PHD2_Setting16,
        PHD2_Setting2,
        PHD2_Setting6,
        PHD2_Setting7
	}
}


MENU OnlineWindow_clean_calib
{
    LABEL	"Change Location 1"  	"|de|ndern Einbauort 1";
    ITEMS
    {
		Page_clean_calib 
    }
}

MENU Page_clean_calib
{
    LABEL	"Change Location 1"  	"|de|ndern Einbauort 1";
    ITEMS
    	{
	IC1_SampleLocation

	}
}

MENU OnlineWindow_clean_calib2
{
    LABEL	"Change Location 2"  	"|de|ndern Einbauort 2";
    ITEMS
    {
		Page_clean_calib2 
    }
}

MENU Page_clean_calib2
{
    LABEL	"Change Location 2"  	"|de|ndern Einbauort 2";
    ITEMS
    	{
	PHD2_Setting1

	}
}

MENU Tab_s_preferences
{
    LABEL	"Profibus Interface"  "|de|Profibus Interface";
    ITEMS
    {
		VendorName,
		ModelName,
		ModelNummer,
				

    }
}

MENU Tab_s_preferencesM1
{
    LABEL	"Identification probe 1"  "|de|Identifikation erstes Gert";
    ITEMS
    {
		DeviceID1,
		Serial1_WOX  (READ_ONLY),
		IC1_SampleLocation
			

    }
}

MENU Tab_s_preferencesM2
{
    LABEL	"Identification probe 2"  "|de|Identifikation zweites Gert";
    ITEMS
    {
		DeviceID2,
		Serial2_WOX  (READ_ONLY),
		PHD2_Setting1
    }
}

MENU Tab_s_output
{
	LABEL	"Measurements probe 1"  "|de|Messwerte 1";
	ITEMS
	{
		IC1_Measurement1,
		IC1_Setting1,
		IC1_Unit1,
		IC1_Measurement3,
		Status1
		
	}
}

MENU Tab_s_output2
{
	LABEL	"Measurements probe 2"  "|de|Messwerte 2";
	ITEMS
	{
		PHD2_Measurement1,
		PHD2_Measurement2,
		PHD2_Measurement3
		Status2
		
	}
}

MENU Tab_s_diag
{
	LABEL	"Diagnostics 1" "|de|Diagnose erstes Gert";
	ITEMS
	{
		Status1,
		Error1,
		IC1_Diag1,
		IC1_Diag2,
		IC1_Diag3,
		IC1_Diag5,
		IC1_Diag6,
	}
}

MENU Tab_s_diag2
{
	LABEL	"Diagnostics 2" "|de|Diagnose zweites Gert";
	ITEMS
	{
		Status2,
		Error2,
        PHD2_Diag1,
		PHD2_Measurement4,
		PHD2_Measurement5
	}
}

MENU Tab_s_settings
{
	LABEL	"Settings 1" "|de|Einstelldaten erstes Gert";
	ITEMS
	{

		IC1_Unit1,
		IC1_Unit5,
		IC1_Setting1,
		IC1_Setting2,
		IC1_Setting3,
		IC1_Setting5,
		IC1_Setting6,
		IC1_Setting7,
		IC1_Setting8,
		IC1_Setting9,
		IC1_Setting10,
		IC1_Setting11,
		IC1_Setting12,
		IC1_Setting13,
		IC1_Setting14,
		IC1_Setting15			
	}
}

MENU Tab_s_settings2
{
	LABEL	"Settings 2" "|de|Einstelldaten zweites Gert";
	ITEMS
	{

		PHD2_Unit1,
		PHD2_Unit2,
		PHD2_Setting1,
		PHD2_Setting3,
		PHD2_Setting4,
		PHD2_Setting5,
		PHD2_Setting10,
		PHD2_Setting11,
		PHD2_Setting12,
		PHD2_Setting13,
		PHD2_Setting14,
        PHD2_Setting16,
        PHD2_Setting2,
        PHD2_Setting6,
        PHD2_Setting7			
	}
}

/************************************************************************/
/*	  Table: Maintenance						*/
/************************************************************************/

MENU Table_Main_Maintenance
{
	LABEL	DEVICE_TITLE ;

	ITEMS
	{
		Tab_s_preferences,
		Tab_s_preferencesM1,
		Tab_s_preferencesM2,
		Tab_m_settings,
		Tab_m_diag,
		Tab_s_output,
		Tab_m_settings2,
		Tab_m_diag2,
		Tab_s_output2
	}
}

/************************************************************************/
/*	  Main Menus							*/
/************************************************************************/

/************************************************************************/
/*	  Menu: Bar							*/
/************************************************************************/

MENU Menu_Main_Maintenance
{
    LABEL		[main_menu];
    ITEMS
    {
        Menu_File,
        Menu_M_Device,
        Menu_M_View,
        //Menu_M_Options,
        Menu_Help
    }
}

/************************************************************************/
/*	  Menu: Device							*/
/************************************************************************/

MENU Menu_M_Device
{
    LABEL		[menu_Device];
    ITEMS
    {
        std_LoadinDevice,
        std_LoadinPC
    }
}

/************************************************************************/
/*	  Menu: View							*/
/************************************************************************/

MENU Menu_M_View
{
    LABEL		[menu_View];
    ITEMS
    {
        OnlineWindow_display,
//	OnlineWindow_actual_mode
    }
}

/************************************************************************/
/*	  Online-Windows						*/
/************************************************************************/

MENU Tab_m_preferences
{
    LABEL	"Overview" "|de|Allgemein";
    ITEMS
    {
		VendorName,
		ModelName,
		ModelNummer,
		IC1_SampleLocation
		

    }
}

MENU Tab_m_output
{
	LABEL		[menu_output];
	ITEMS
	{
		IC1_Measurement1,
		IC1_Measurement3
	
	}
}

MENU Tab_m_diag
{
	LABEL	"Diagnostics 1" "|de|Diagnose erstes Gert";
	ITEMS
	{
		Status1,
		Error1,
		IC1_Diag1	(READ_ONLY),
		IC1_Diag2	(READ_ONLY),
		IC1_Diag3	(READ_ONLY),
		IC1_Diag5	(READ_ONLY),
		IC1_Diag6	(READ_ONLY)
	}
}

MENU Tab_m_diag2
{
	LABEL	"Diagnostics 2" "|de|Diagnose zweites Gert";
	ITEMS
	{
		Status2,
		Error2,
        PHD2_Diag1,
		PHD2_Measurement4,
		PHD2_Measurement5
	}
}

MENU Tab_m_settings
{
	LABEL	"Settings" "|de|Einstelldaten erstes Gert";
	ITEMS
	{
		IC1_Unit1	(READ_ONLY),
		IC1_Unit5	(READ_ONLY),
		IC1_Setting1	(READ_ONLY),
		IC1_Setting2	(READ_ONLY),
		IC1_Setting3	(READ_ONLY),
		IC1_Setting5	(READ_ONLY),
		IC1_Setting6	(READ_ONLY),
		IC1_Setting7	(READ_ONLY),
		IC1_Setting8	(READ_ONLY),
		IC1_Setting9	(READ_ONLY),
		IC1_Setting10	(READ_ONLY),
		IC1_Setting11	(READ_ONLY),
		IC1_Setting12	(READ_ONLY),
		IC1_Setting13	(READ_ONLY),
		IC1_Setting14	(READ_ONLY),
		IC1_Setting15	(READ_ONLY)
				
	}
}

MENU Tab_m_settings2
{
	LABEL	"Settings 2" "|de|Einstelldaten zweites Gert";
	ITEMS
	{
		PHD2_Unit1	(READ_ONLY),
		PHD2_Unit2	(READ_ONLY),
		PHD2_Setting1	(READ_ONLY),
		PHD2_Setting3	(READ_ONLY),
		PHD2_Setting4	(READ_ONLY),
		PHD2_Setting5	(READ_ONLY),
		PHD2_Setting10	(READ_ONLY),
		PHD2_Setting11	(READ_ONLY),
		PHD2_Setting12	(READ_ONLY),
		PHD2_Setting13	(READ_ONLY),
		PHD2_Setting14	(READ_ONLY),
		PHD2_Setting16	(READ_ONLY),
		PHD2_Setting2	(READ_ONLY),
		PHD2_Setting6	(READ_ONLY),
		PHD2_Setting7	(READ_ONLY)

				
	}
}

MENU OnlineWindow_actual_mode
{
	LABEL	"Measured Values" "|de|Aktuell";
	ITEMS
	{
		IC1_Measurement1,
		IC1_Measurement3,
		IC1_Setting1,
		IC1_Unit1,
		IC1_Unit3,
		Status1		
	
	}
}

MENU OnlineWindow_display
{
	LABEL		[menu_dialog_display];
	ITEMS
	{
		Page_display_func1
	}
}

MENU Page_display_func1
{
	LABEL   "Measured Value" "|de|Messwertanzeigen" ;
	ITEMS
	{
		BarVal_out_display_func1,
		IC1_Setting1,
		IC1_Unit1,
		Status1				
		BarVal_out_display_func3,
		BarVal_out_display_func2,
		Status2				
		BarVal_out_display_func4		
	}
}


MENU BarVal_out_display_func1
{
	LABEL		"Sensor Measurement 1" "|de|Messwrt Sensor 1" ;
	HELP		[func_ai_out_value_help];
	ITEMS
	{
		IC1_Measurement1


	}
}

MENU BarVal_out_display_func2
{
	LABEL		"Sensor Measurement 2" "|de|Messwrt Sensor 2" ;
	HELP		[func_ai_out_value_help];
	ITEMS
	{
		PHD2_Measurement1


	}
}

MENU BarVal_out_display_func3
{
	LABEL		"Temperature 1" "|de|Temperatur 1" ;
	HELP		[func_ai_out_value_help];
	ITEMS
	{
		IC1_Measurement3

	}
}

MENU BarVal_out_display_func4
{
	LABEL		"Temperature 2" "|de|Temperatur 2" ;
	HELP		[func_ai_out_value_help];
	ITEMS
	{
		PHD2_Measurement2

	}
}
