/*------------------------------------------------------------------*/
/*	Copyright (C)	Hach-Lange (2010). All Rights Reserved.	   		*/
/*	Product:		SIMATIC PDM  			   						*/
/*	Device:			SC V1       		           					*/
/*	Description:		Device Description	          				*/
/*	Dictionary:		SIPADC01.dct			   						*/
/*  	$Revision:		1.6  $				   						*/
/*  	$Date:			Maerz 2010			   						*/
/*	File:			L1_LDO.inc			   							*/
/*	Author:			T.Thiel Hach-Lange                 				*/
/*				R.Mellows Hach-Lange               					*/
/*				R.Stollenwerk Hach-Lange           					*/
/*------------------------------------------------------------------*/


/************************************************************************/
/*		Variables														*/
/************************************************************************/



VARIABLE L1_Measurement1
{
	LABEL 	"Oxygen Value" 	"|de|Sauerstoffwert";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

}


VARIABLE L1_Measurement2
{
	LABEL 	"Percent Saturation" 	"|de|Prozentuale Sttigung";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"%";
}

VARIABLE L1_Measurement3
{
	LABEL 	"Temperature Value" 	"|de|Temperatur";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

}

VARIABLE L1_Diag1
{
	LABEL 	"Total Phase Shift" 	"|de|Phasenverschiebung gesamt";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"" ;
}

VARIABLE L1_Diag2
{
	LABEL 	"Blue Phase Shift" 	"|de|Phasenverschiebung blau";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"" ;
}

VARIABLE L1_Diag3
{
	LABEL 	"Red Phase Shift" 	"|de|Phasenverschiebung rot";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"" ;
}

VARIABLE L1_Diag4
{
	LABEL 	"Blue Amplitude" 	"|de|Amplitude blau";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"0..1";
}

VARIABLE L1_Diag5
{
	LABEL 	"Red Amplitude" 	"|de|Amplitude rot";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"0..1";
}


VARIABLE L1_Diag6
{
	LABEL 	"Software version" 	"|de|Softwareversion";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

}

VARIABLE L1_AltPress
{
	LABEL 	"Altitude/Pressure"	"|de|Hhe/Druck";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
		MIN_VALUE		0.0 ;
		MAX_VALUE		5000 ;

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE L1_Salinity
{
	LABEL 	"Salinity"		"|de|Salzgehalt";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
		MIN_VALUE		0.0 ;
		MAX_VALUE		250 ;

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Salinity per mille" "|de|Promille Salzgehalt";
}

VARIABLE L1_UnitConc
{
	LABEL 	"Oxygen Unit" 			"|de|Sauerstoffeinheit";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			DEFAULT_VALUE 0;
			{0,			"mg/l"	},
			{2,			"ppm"	},
			{10,			"%"     }
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}




VARIABLE L1_UnitTemp
{
	LABEL 	"Temperature Unit"			"|de|Temperatureinheit";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			DEFAULT_VALUE 25;
			{25,			"C"   	},
			{26,			"F"     }
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}


VARIABLE L1_UnitAltP
{
	LABEL 	"Alt. Pressure Unit" 	"|de|Einheit Hhe/Druck";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			{13,		"meter"		"|de|Meter" 	},
			{43,		"foot" 	        "|de|Fu"	},
			{45,		"mmHg" 		"|de|mmHg" 	},
			{47,		"torr" 		"|de|Torr"	}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE L1_CorrectionSlope
{
	LABEL 	"Correction Slope"	"|de|Steilheitkorrektur";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
		MIN_VALUE		0.5 ;
		MAX_VALUE		1.5 ;

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE L1_Correction
{
	LABEL 	"Calibration Value"		"|de|Kalibrierwert";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
		MIN_VALUE		 0.0 ;
		MAX_VALUE		 20.0 ;

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE L1_Offset
{
	LABEL 	"Offset "		"|de|Offset";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
		MIN_VALUE		-5.0 ;
		MAX_VALUE		 5.0 ;

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE L1_Integration
{
	LABEL 	"Integration"	"|de|Integration";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
        {

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"s" "|de|s";
}


VARIABLE L1_SampleLocation
{
	LABEL 	"Probe Location" "|de|Einbauort";
	CLASS	CONTAINED;
	TYPE	ASCII (12)
		{
			DEFAULT_VALUE "";
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}


UNIT Select_unit		// dynymic unit relation
{
	L1_UnitConc:
	L1_Measurement1, L1_Offset
}

UNIT Select_unit_press		// dynymic unit relation
{
	L1_UnitAltP:
	L1_AltPress
}

UNIT Select_unit_T		// dynymic unit relation
{
	L1_UnitTemp:
	L1_Measurement3

}


//---EDD2DTM Dummy Byte-----
 VARIABLE dummy_byte
{
	LABEL "dummy";
	TYPE ASCII(1);
	CLASS LOCAL;

}

/************************************************************************/
/*		COMMANDS														*/
/************************************************************************/

COMMAND read_L1_Float01
{
	SLOT L1_SLOTADR;
	INDEX 0;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          L1_Measurement1, // Oxygen Concentration:40001(000)Float L(02)
          L1_Measurement2, // Percent Saturation:40003(002)Float L(02)
          L1_Measurement3, // Temperature:40005(004)Float L(02)
          L1_Diag1, // Total Phase Shift:40007(006)Float L(02)
          L1_Diag2, // Blue LED Phase Shift:40009(008)Float L(02)
          L1_Diag3, // Red LED Phase Shift:40011(010)Float L(02)
          L1_Diag4, // Blue LED Amplitude:40013(012)Float L(02)
          L1_Diag5, // Red LED Amplitude:40015(014)Float L(02)
          L1_Diag6, // Software Version Number of Application Code:40017(016)Float L(02)
          dummy_byte, dummy_byte, // Curve Coerff 0:40019(018)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Curve Coeff 1:40021(020)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Curve Coeff2:40023(022)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Curve Coeff 3:40025(024)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Calc. Partial Pressure of Oxygen:40027(026)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Temperature, Celsius:40029(028)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Phase Offset Correction:40031(030)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Phase Slope Correction:40033(032)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Phase for 0 torr at current temperature:40035(034)Float L(02)
          dummy_byte, dummy_byte
        }
    }
}

COMMAND read_L1_Float02
{
	SLOT L1_SLOTADR;
	INDEX 36;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          L1_Correction, // Value of sample during calibration:40037(036)Float L(02)
          dummy_byte, dummy_byte, // Non-averged DO value:40039(038)Float L(02)
          dummy_byte, dummy_byte,
          L1_AltPress, // Altitude or Pressure of sensor:40041(040)Float L(02)
          L1_Salinity, // Salinity of Sample:40043(042)Float L(02)
          L1_Offset, // Offset correction to readings:40045(044)Float L(02)
          L1_CorrectionSlope, // Slope correction to readings:40047(046)Float L(02)
          dummy_byte, dummy_byte, // Phase at T=11.9,pO2=0:40049(048)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Phase at T=11.9,pO2=5:40051(050)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Phase at T=11.9,pO2=20:40053(052)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Phase at T=11.9,pO2=50:40055(054)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Phase at T=11.9,pO2=100:40057(056)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Phase at T=11.9,pO2=150:40059(058)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Phase at T=11.9,pO2=220:40061(060)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Phase at T=24.9,pO2=0:40063(062)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Phase at T=24.9,pO2=5:40065(064)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Phase at T=24.9,pO2=20:40067(066)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Phase at T=24.9,pO2=50:40069(068)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Phase at T=24.9,pO2=100:40071(070)Float L(02)
          dummy_byte, dummy_byte

        }
    }
}


COMMAND read_L1_Var01
{
	SLOT L1_SLOTADR;
	INDEX 84;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          dummy_byte, dummy_byte, // Phase at T=37.6,pO2=100:40085(084)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Phase at T=37.6,pO2=150:40087(086)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Phase at T=37.6,pO2=220:40089(088)Float L(02)
          dummy_byte, dummy_byte,
          L1_UnitConc, //  unit: 0=mg/l; 2=ppm; 10=%:40091(090)Integer L(01)
          L1_UnitAltP, // unit: 13=meters; 43=feet; 45=mmHg; 47=torr:40092(091)Integer L(01)
          L1_UnitTemp, // unit: 25=Celsius; 26=Fahrenheit:40093(092)Integer L(01)
          dummy_byte, dummy_byte, // Calibration Code of Sensor Cap:40094(093)String L(05)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          L1_SampleLocation, // Customer Name for Sensor:40099(098)String L(06)
          L1_Integration, // Number of seconds to average reading:40105(104)Integer L(01)
          dummy_byte, dummy_byte, // Data logging interval in seconds:40106(105)Integer L(01)
          dummy_byte, dummy_byte, // 0=NormalOp;1=Blue on;2=Red On:40107(106)Integer L(01)
          dummy_byte, dummy_byte, // :40108(107)Integer L(01)
          dummy_byte, dummy_byte, // :40109(108)Integer L(01)
          dummy_byte, dummy_byte, // :40110(109)Integer L(01)
          dummy_byte, dummy_byte, // :40111(110)Integer L(01)
          dummy_byte, dummy_byte, // :40112(111)Integer L(01)
          dummy_byte, dummy_byte, // :40113(112)Integer L(01)
          dummy_byte, dummy_byte, // :40114(113)Integer L(01)
          dummy_byte, dummy_byte // Manufacturer Serial Number:40115(114)String L(06)
        }
    }
}


 //-----------------------------------------------------------------


COMMAND write_L1_AltPress
{
	SLOT L1_SLOTADR;
	INDEX 40;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              L1_AltPress
        }
        REPLY
        {

        }
    }
}

COMMAND write_L1_Salinity
{
	SLOT L1_SLOTADR;
	INDEX 42;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              L1_Salinity
        }
        REPLY
        {

        }
    }
}

COMMAND write_L1_Correction
{
	SLOT L1_SLOTADR;
	INDEX 36;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              L1_Correction
        }
        REPLY
        {

        }
    }
}


COMMAND write_L1_CorrectionSlope
{
	SLOT L1_SLOTADR;
	INDEX 46;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              L1_CorrectionSlope
        }
        REPLY
        {

        }
    }
}


COMMAND write_L1_Offset
{
	SLOT L1_SLOTADR;
	INDEX 44;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              L1_Offset
        }
        REPLY
        {

        }
    }
}

COMMAND write_L1_UnitConc
{
	SLOT L1_SLOTADR;
	INDEX 90;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              L1_UnitConc
        }
        REPLY
        {

        }
    }
}

COMMAND write_L1_UnitAltP
{
	SLOT L1_SLOTADR;
	INDEX 91;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              L1_UnitAltP
        }
        REPLY
        {

        }
    }
}


COMMAND write_L1_UnitTemp
{
	SLOT L1_SLOTADR;
	INDEX 92;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              L1_UnitTemp
        }
        REPLY
        {

        }
    }
}


COMMAND write_L1_Integration
{
	SLOT L1_SLOTADR;
	INDEX 104;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              L1_Integration
        }
        REPLY
        {

        }
    }
}


COMMAND write_L1_SampleLocation
{
	SLOT L1_SLOTADR;
	INDEX 98;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              L1_SampleLocation
        }
        REPLY
        {

        }
    }
}

