/*-----------------------------------------------------------------*/
/*	Copyright (C)	Hach-Lange (2010). All Rights Reserved.	       */
/*	Product:		SIMATIC PDM  			   					   */
/*	Device:			SC200 DPV1       		                       */
/*	Description:		Device Description	                       */
/*	Dictionary:		SIPADC01.dct			                       */
/*  	$Revision:		1.0  $				                       */
/*  	$Date:			03 2010  			                       */
/*  File:		SC200_Phosphax.ddl      			               */
/*	Author:			T.Thiel Hach-Lange	                           */
/* Angepasset: R.Stollenwerk                                       */
/*-----------------------------------------------------------------*/

MANUFACTURER		 	213,
DEVICE_TYPE				1,
DEVICE_REVISION  		1,
DD_REVISION     		0


#define DEVICE_TITLE	"SC200 Phosphax"

#define OPERATING_HOURS 1

#include	"p1_phosp.inc"	// first device
/************************************************************************/
/*      Methoden                                                        */
/************************************************************************/
METHOD METHOD_WOX1
{
	LABEL "Without1 0x";
	DEFINITION
	{
	DD_STRING Serial_str1,Serial_str2,Serial_str3,pos_str;
	unsigned int zw;
	unsigned int s1,s2,s3,s4;

        zw=SeriaP1_1;
        s1=zw>>12;
        zw=zw-(s1<<12);
        s2=zw>>8;
        zw=zw-(s2<<8);
        s3=zw>>4;
        zw=zw-(s3<<4);
        s4=zw;
	Serial_str1=itoa(s1)+itoa(s2)+itoa(s3)+itoa(s4);

        zw=SeriaP1_2;
        s1=zw>>12;
        zw=zw-(s1<<12);
        s2=zw>>8;
        zw=zw-(s2<<8);
        s3=zw>>4;
        zw=zw-(s3<<4);
        s4=zw;
        Serial_str2=itoa(s1)+itoa(s2)+itoa(s3)+itoa(s4);

        zw=SeriaP1_3;
        s1=zw>>12;
        zw=zw-(s1<<12);
        s2=zw>>8;
        zw=zw-(s2<<8);
        s3=zw>>4;
        zw=zw-(s3<<4);
        s4=zw;
        Serial_str3=itoa(s1)+itoa(s2)+itoa(s3)+itoa(s4);

        Serial1_WOX= Serial_str1+Serial_str2+Serial_str3;

	}

}

METHOD METHODE_SWAP(unsigned long wert, unsigned int zuweisung)
{
	LABEL "METHODE_SEC_DATE";
	DEFINITION
	{
	  unsigned int wert_h,wert_l;
	  unsigned long wert_intern;
	  
		 wert_l=0x0000ffff & wert;
		 wert_h=(0xffff0000 & wert)>>16;
		 wert_intern= (wert_l<<16)+wert_h;
		 switch(zuweisung)
		  { case OPERATING_HOURS: swap_wert_operating_hours=wert_intern; break;
		  }
	}
}


/************************************************************************/
/*		Variablen						*/
/************************************************************************/
VARIABLE swap_wert_operating_hours
{
	LABEL "Operating hours" "|de|Betriebsstunden";\
	HELP "operating hours of analyzer" "|de|operating hours of analyzer";\
	CLASS	LOCAL;
	TYPE	UNSIGNED_INTEGER (4)
		{		
		}
}


//---Dummy Byte-----
 VARIABLE dummy_byte
{
	LABEL "dummy";
	TYPE ASCII(1);
	CLASS LOCAL;
}

//--Lokale Seriennummer ohne 0x--
VARIABLE Serial1_WOX
{
	LABEL 	"Serial No, Device 1" 	"|de|Seriennummer, Gert 1";
	TYPE	ASCII (16)
		{
		DEFAULT_VALUE "0000000000000000";
		}

	CLASS LOCAL;

}

VARIABLE VendorName
{
	LABEL 	"Vendor Name""|de|Geraetehersteller";
	CLASS	CONTAINED;
	TYPE	ASCII (16)
		{
			DEFAULT_VALUE "Hach-Lange";
		}
	HANDLING	READ;
}

VARIABLE ModelName
{
	LABEL 	"Fieldbus type" "|de|Profibustyp";
	CLASS	CONTAINED;
	TYPE	ASCII (32)
		{
			DEFAULT_VALUE "SC device";
		}
	HANDLING	READ;
}

VARIABLE ModelNummer
{
	LABEL 	"Model Number""|de|Profibusversion";
	CLASS	CONTAINED;
	TYPE	ASCII (32)
		{
			DEFAULT_VALUE "";
		}
	HANDLING	READ;
}

VARIABLE SeriaP1_1
{
	LABEL 	"Serial No 1" 	"|de|Seriennummer 1";
	CLASS	DYNAMIC;
	TYPE	INTEGER (2)
		{
			
		}
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
}

VARIABLE SeriaP1_2
{
	LABEL 	"Serial No 2" 	"|de|Seriennummer 2";
	CLASS	DYNAMIC;
	TYPE	INTEGER (2)
		{
			
		}
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
}

VARIABLE SeriaP1_3
{
	LABEL 	"Serial No 3" 	"|de|Seriennummer 3";
	CLASS	DYNAMIC;
	TYPE	INTEGER (2)
		{
			
		}
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
        POST_READ_ACTIONS
          {
            METHOD_WOX1

          }	
}

VARIABLE DeviceID1
{
	LABEL 	"Device ID" 	"|de|Gertekennung";
	CLASS	DYNAMIC;
	TYPE	INTEGER (2)
		{
		
			{10,			"3798 Cond"		},
			{12,			"LDO"			},
			{13,			"1720E"			},
			{17,			"pHD SC"		},
			{18,			"5740 DO"		},
			{19,			"34xx Cont. Cond."	},
			{20,			"37xx Ind. Cond."	},
			{21,			"pH SC"				},
			{26,   			"Surface Scatter 7" },
			{39,   			"SC200"   			},  
			{101,			"ULTRATURB SC"		},
			{102,			"Nitratax eco"  	},
			{103,			"Nitratax plus"		},
			{104,			"Solitax SC"    	},
			{105,			"Nitratax clear"	},
			{106,			"UVAS plus"     	},
			{107,			"S::CAN CARBO::LYZER"	},
			{108,			"S::CAN NITRO::LYZER"   },
			{109,			"PHOSPHAX SC"     	},
			{110,			"AMTAX SC"     	 	},
			{112,			"NH4D SC"     		},
			{113,			"SONATAX SC"     	},
			{114,			"PHOSPHAX SC"     	},
			{120,   		"NO3D SC"           }					
								
		}
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
}

VARIABLE ManufactID1
{
	LABEL 	"Manufacturer ID" 	"|de|Herstellerkennung";
	CLASS	DYNAMIC;
	TYPE	INTEGER (2)
		{
			
		}
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
}

VARIABLE Length1
{
	LABEL 	"Length Member table" 	"|de|Lnge Teilnehmertabelle";
	CLASS	DYNAMIC;
	TYPE	INTEGER (2)
		{
			
		}
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
}

VARIABLE Status1
{
	LABEL 	"Status ";
	CLASS	DYNAMIC;
	TYPE	BIT_ENUMERATED (2)
	{
		
		{0,   	"OK"						"|de|OK"	 		 },
		{1,   	"Calibration start / in progress"		"|de|Kalibrierung aktiv"	 },
		{2,   	"Cleaning start / in progress"			"|de|Reinigungszyklus aktiv"	 },
		{4,   	"Enter(d) Service/Maintenance menu"		"|de|Betriebsart Service"	 },
		{8,   	"Common Error"					"|de|Sammelstrung"		 },
		{16,   	"Measurement 0 Quality Bad"			"|de|Messung 0 Qualittsfehler"	 },
		{32,   	"Measurement 0 low limit"			"|de|Messung 0 unterer Grenzwert"},
		{64,    "Measurement 0 high limit"			"|de|Messung 0 oberer Grenzwert" },
		{128,   "Measurement 1 Quality Bad"			"|de|Messung 1 Qualittsfehler"	 },
		{256,   "Measurement 1 low limit"			"|de|Messung 1 unterer Grenzwert"},
		{512,   "Measurement 1 high limit"			"|de|Messung 1 oberer Grenzwert" },
		{1024,  "Measurement 2 Quality Bad"			"|de|Messung 2 Qualittsfehler"	 },
		{2048,  "Measurement 2 low limit"			"|de|Messung 2 unterer Grenzwert"},	
		{4096,  "Measurement 2 high limit"			"|de|Messung 2 oberer Grenzwert" },
		{8192,  "Measurement 3 Quality Bad"			"|de|Messung 3 Qualittsfehler"	 },
		{16384, "Measurement 3 low limit"			"|de|Messung 3 unterer Grenzwert"},
		{32768, "Measurement 3 high limit"			"|de|Messung 3 oberer Grenzwert" }
					
	}	
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
}


VARIABLE Error1
{
	LABEL	"Error Classes Member "		"|de|Fehlermeldung";
	CLASS	CONTAINED;
	TYPE	BIT_ENUMERATED (2)
	{
			{0,   	"No Error"				"|de|Kein Fehler"			},
			{1,   	"Measurement calibration Error"		"|de|Kalibrierfehler"			},
			{2,   	"Electronic adjustment Error"		"|de|Elektronik / Einstellfehler"	},
			{4,   	"Cleaning Error"			"|de|Reinigungsfehler"			},
			{8,   	"Measuring module Error"		"|de|Messmodulfehler"			},
			{16,   	"Settings Error"			"|de|Fehler Einstellungen"		},
			{32,   	"Hardware Error"			"|de|Hardwarefehler"			},
			{64,    "Internal communication Error"		"|de|Interner Kommunikationsfehler"	},
			{128,   "Humidity Error"			"|de|Feuchtigkeit erkannt"		},
			{256,   "Temperatur Error"			"|de|Temperaturfehler"			},
			{512,   ""										},
			{1024,  ""										},
			{2048,  ""										},	
			{4096,  "Questionable measurement Warning"	"|de|Warnung Messwert unsicher"		},
			{8192,  "Safety Warning"			"|de|Warnung Sicherheitseinrichtung"	},
			{16384, "Reagent Warning"			"|de|Warnung Reagenz"			},
			{32768, "Maintenance Warning"			"|de|Warnung Instandhaltung"		}
					
	}
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
}







VARIABLE Channel_1
{
	LABEL 	"Channel 1";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
}

VARIABLE Channel_2
{
	LABEL 	"Channel 2";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
}




UNIT Select_P1_Unit1
{
	P1_Unit1:
	P1_Measurement1

}

UNIT Select_P1_Unit2
{
	P1_Unit2:
	P1_Measurement2

}

/************************************************************************/
/*		COMMANDS														*/
/************************************************************************/




COMMAND read_VendorName
{
	SLOT 0;
	INDEX 100;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            VendorName
        }
    }
}

COMMAND read_ModelName
{
	SLOT 0;
	INDEX 101;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            ModelName
        }
    }
}

COMMAND read_ModelNummer
{
	SLOT 0;
	INDEX 102;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            ModelNummer
        }
    }
}


COMMAND read_MemberTable
{
	SLOT 10;
	INDEX 0;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            SeriaP1_1,
            SeriaP1_2,
            SeriaP1_3,
            DeviceID1,
            ManufactID1,
            Length1,
            Error1,
            Status1
        }
    }
}







 


/************************************************************************/
/*  Upload from device to PC              Daten lesen vom Gert zum PC	*/
/************************************************************************/

MENU download_variables
{
	LABEL	[menu_load_to_PC];
	ITEMS
	{ 
		VendorName,
		ModelName,
		ModelNummer,
		P1_Measurement1,
		P1_Measurement2,
		P1_Diag1,
		P1_Diag2,
		P1_Diag3,
		P1_Unit1,
		P1_Unit2,
		P1_Range,
		P1_CleaningInterv,
		P1_CalibStart,
		P1_MeasInterv,
		P1_CleaningStart,
		P1_Parameter1,
		P1_Parameter2,
		P1_Correction1,
		P1_Correction2,
		P1_Process,
		P1_HeaterON,
		P1_HeaterOFF,
		P1_SampleLocation1,
		P1_Cooling,
		P1_Heater,
		P1_HumidityD,
		P1_HumidityF,
		P1_Filter,
		P1_Option,
		P1_Chem1,
		P1_Chem2,
		P1_Attendet,
		SeriaP1_1,
		
		
	}
} 


/************************************************************************/
/*  Write from PC to device        Datenschreiben vom PC zum Gert	    */
/************************************************************************/

MENU upload_variables
{
	LABEL	[menu_load_to_device];
	ITEMS
	{
		P1_SampleLocation1,
		P1_CleaningInterv,
		P1_CalibStart,
		P1_MeasInterv,
		P1_CleaningStart,
		P1_Parameter1,
		IF(P1_Option==2) {P1_Parameter2,}
		P1_Correction1,
		IF(P1_Option==2) {P1_Correction2,} 
		P1_Option,
		P1_Unit1,
		IF(P1_Option==2) {P1_Unit2,}
		P1_HeaterON,
		P1_HeaterOFF		
				
	}
}

/************************************************************************/
/*	  Table: Specialist													*/
/************************************************************************/

MENU Table_Main_Specialist
{
	LABEL	DEVICE_TITLE ;

	ITEMS
	{
		Tab_s_preferences,
		Tab_s_preferencesM1,
		Tab_s_settings,
		Tab_s_diag,
		Tab_s_output
	}
}

/************************************************************************/
/*	  Main Menus														*/
/************************************************************************/

/************************************************************************/
/*	  Menu: Bar															*/
/************************************************************************/

MENU Menu_Main_Specialist
{
    LABEL		[main_menu];
    ITEMS
    {
        Menu_File,
        Menu_S_Device,
        Menu_S_View,
        Menu_S_Options,
        Menu_Help	
    }
}

/************************************************************************/
/*	  Menu: Device														*/
/************************************************************************/

MENU Menu_S_Device
{
    LABEL		[menu_Device];
    ITEMS
    {
        std_LoadinDevice,
        std_LoadinPC,
        SEPARATOR,
	OnlineWindow_range_preferences,
	OnlineWindow_clean_calib
    }
}

/************************************************************************/
/*	  Menu: View														*/
/************************************************************************/

MENU Menu_S_View
{
    LABEL		[menu_View];
    ITEMS
    {
        OnlineWindow_display,
//	OnlineWindow_actual_mode
    }
}

/************************************************************************/
/*	  Online-Windows													*/
/************************************************************************/

MENU OnlineWindow_range_preferences
{
    LABEL	"Settings" "|de|Einstelldaten";
    ITEMS
    {
		Page_range_preferences
    }
}

MENU Page_range_preferences
{
    LABEL	"Settings" "|de|Voreinstellungen" ;
    ITEMS
    	{
		P1_SampleLocation1,
		P1_MeasInterv,
		P1_CleaningInterv,
		P1_CleaningStart,
		P1_Parameter1,
		P1_Parameter2,
		P1_Correction1,
		P1_Correction2
		
	
	}
}

MENU OnlineWindow_clean_calib
{
    LABEL	"Clean "  	"|de|Reinigen";
    ITEMS
    {
		Page_clean_calib 
    }
}

MENU Page_clean_calib
{
    LABEL	"Service"	"|de|Bedienanforderungen";
    ITEMS
    	{
	P1_BusCleanEmidiate,
	P1_BusEnable
	}
}


MENU Tab_s_preferences
{
    LABEL	"SC200 Overview"  "|de|SC200 Allgemein";
    ITEMS
    {
		VendorName,
		ModelName,
		ModelNummer,
				

    }
}

MENU Tab_s_preferencesM1
{
    LABEL	"Overview 1st device "  "|de|SC200 erstes Gert";
    ITEMS
    {
		DeviceID1,
		Serial1_WOX (READ_ONLY),
		P1_SampleLocation1
			

    }
}

MENU Tab_s_output
{
	LABEL		[menu_output];
	ITEMS
	{
		P1_Measurement1,
		P1_Measurement2
		
	}
}

MENU Tab_s_diag
{
	LABEL	"Diagnostics" "|de|Diagnose erstes Gert";
	ITEMS
	{
		Status1,
		Error1,
		P1_Diag1,
		P1_Diag2,
		P1_Heater,
		P1_Cooling,
		P1_Filter,
		P1_HumidityD,
		P1_HumidityF,
		P1_Chem1,
		P1_Chem2,
		P1_Attendet (HIDDEN),
		swap_wert_operating_hours (READ_ONLY),
		P1_Process
		
	}
}

MENU Tab_s_settings
{
	LABEL	"Settings" "|de|Einstelldaten erstes Gert";
	ITEMS
	{
		P1_SampleLocation1,
		P1_Range,
		P1_Option,
		P1_CleaningInterv,
		P1_CleaningStart,
		P1_MeasInterv,
		P1_Unit1,
		P1_Unit2,
		P1_Parameter1,
		P1_Parameter2,
		P1_Correction1,
		P1_Correction2,
		P1_HeaterON,
		P1_HeaterOFF
				
	}
}


/************************************************************************/
/*	  Table: Maintenance												*/
/************************************************************************/

MENU Table_Main_Maintenance
{
	LABEL	DEVICE_TITLE ;

	ITEMS
	{
		Tab_m_preferences,
		Tab_m_output,
		Tab_m_settings,
		Tab_m_diag
	}
}

/************************************************************************/
/*	  Main Menus														*/
/************************************************************************/

/************************************************************************/
/*	  Menu: Bar															*/
/************************************************************************/

MENU Menu_Main_Maintenance
{
    LABEL		[main_menu];
    ITEMS
    {
        Menu_File,
        Menu_M_Device,
        Menu_M_View,
        //Menu_M_Options,
        Menu_Help
    }
}

/************************************************************************/
/*	  Menu: Device														*/
/************************************************************************/

MENU Menu_M_Device
{
    LABEL		[menu_Device];
    ITEMS
    {
        std_LoadinDevice,
        std_LoadinPC
    }
}

/************************************************************************/
/*	  Menu: View														*/
/************************************************************************/

MENU Menu_M_View
{
    LABEL		[menu_View];
    ITEMS
    {
        OnlineWindow_display,
//	OnlineWindow_actual_mode
    }
}

/************************************************************************/
/*	  Online-Windows													*/
/************************************************************************/

MENU Tab_m_preferences
{
    LABEL	"Overview" "|de|Allgemein";
    ITEMS
    {
		VendorName,
		ModelName,
		ModelNummer,
		P1_SampleLocation1
		

    }
}

MENU Tab_m_output
{
	LABEL		[menu_output];
	ITEMS
	{
		P1_Measurement1,
		P1_Measurement2
			
	}
}

MENU Tab_m_diag
{
	LABEL	"Diagnostics" "|de|Diagnose erstes Gert";
	ITEMS
	{
		Status1,
		Error1,
		P1_Diag1,
		P1_Diag2,
		P1_Heater,
		P1_Cooling,
		P1_Filter,
		P1_HumidityD,
		P1_HumidityF,
		P1_Chem1,
		P1_Chem2,
		P1_Attendet,
		P1_Process
			
	}
}

//(READ_ONLY)
MENU Tab_m_settings
{
	LABEL	"Settings" "|de|Einstelldaten erstes Gert";
	ITEMS
	{
		P1_SampleLocation1	(READ_ONLY),
		P1_Range		(READ_ONLY),
		P1_Option		(READ_ONLY),
		P1_CleaningInterv	(READ_ONLY),
		P1_CleaningStart	(READ_ONLY),
		P1_MeasInterv		(READ_ONLY),
		P1_Unit1		(READ_ONLY),
		P1_Unit2		(READ_ONLY),
		P1_Parameter1		(READ_ONLY),
		P1_Parameter2		(READ_ONLY),
		P1_Correction1		(READ_ONLY),
		P1_Correction2		(READ_ONLY),
		P1_HeaterON		(READ_ONLY),
		P1_HeaterOFF		(READ_ONLY)
				
	}
}

MENU OnlineWindow_actual_mode
{
	LABEL	"Current mode" "|de|Aktuell";
	ITEMS
	{
		P1_Measurement1,
		P1_Measurement2

	

	}
}

MENU OnlineWindow_display
{
	LABEL		[menu_dialog_display];
	ITEMS
	{
		Page_display_func1
	}
}

MENU Page_display_func1
{
	LABEL   "Measured Value" "|de|Messwertanzeigen" ;
	ITEMS
	{
		BarVal_out_display_func1,
//		BarVal_out_display_func2,
		BarVal_out_display_func3,
		BarVal_out_display_func4
	}
}


MENU BarVal_out_display_func1
{
	LABEL 	"1st chan: value" 	"|de|Kanal 1";
	HELP		[func_ai_out_value_help];
	ITEMS
	{
		P1_Measurement1

	}
}

MENU BarVal_out_display_func2
{
	LABEL 	"1st chan: value" 	"|de|Kanal 1";
	HELP		[func_ai_out_value_help];
	ITEMS
	{
		P1_Measurement2

	}
}

MENU BarVal_out_display_func3
{
	LABEL 	"Process Phase"		"|de|Prozess Schritt";
	HELP		[func_ai_out_value_help];
	ITEMS
	{
		P1_Process
		
	}
}

MENU BarVal_out_display_func4
{
	LABEL   "Remaining time"		"|de|Restzeit";
	HELP		[func_ai_out_value_help];
	ITEMS
	{
		P1_Remain

	}
}