/*---------------------------------------------------------------------------*/
/*Copyright (C)	Hach-Lange (2009). All Rights Reserved.                      */
/*Product:	SIMATIC PDM  	                                             	 */
/*Device:	SC 200        	                                             	 */
/*Description:	Device Description	                                     	 */
/*Dictionary:	SIPADC01.dct	                                             */
/*$Revision:	1.0  $  	                                             	 */
/* SONDE: Phosphax SC                                                           */
/*$Date:	Okt 2009	                                             		 */
/*Author:	R.Stollenwerk Hach-Lange                                     	 */
/*---------------------------------------------------------------------------*/
//----DEF Menu----

//----DEF Variablen---------------------------------------------------------------------------
//-------MEASUREMENT TAGS----------
VARIABLE Phosphax1_MEAS_UNITS_1
{
         LABEL "Measurment units 1" "|de|Messwert Einheit 1";
         HELP "Measurement units for channel one 0=mg/l,  2=ppm" "|de|Measurement units for channel one 0=mg/l,  2=ppm";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
                 {0, "mg/l"   "|de|mg/l"},
                 {2, "ppm"   "|de|ppm"},
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_MEASURE_VALUE_1
{
         LABEL "Measure value 1" 	"|de|Messwert 1";
         HELP "actual measurement value from channel one" "|de|actual measurement value from channel one";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
		 {
		 }
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
UNIT Phosphax1_MEASURE_VALUE_1_UNIT
{
	Phosphax1_MEAS_UNITS_1:
	Phosphax1_MEASURE_VALUE_1,
	Phosphax1_PHOSPHATE_P_1,
	Phosphax1_PHOS_PENTOXIDE1,
	Phosphax1_PHOSPHATE_1,
}

VARIABLE Phosphax1_CHANNEL1
{
         LABEL "Channel 1" "|de|Kanal 1";
         HELP "Name of LOCATION 1 (see menu system)" "|de|Name of LOCATION 1 (see menu system)";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ASCII (16)
{
}
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_CUVETTE_TEMP
{
         LABEL "Cuvette temperature" "|de|Kvetten Temperatur";
         HELP "actual cuvette temperature" "|de|actual cuvette temperature";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
		DISPLAY_FORMAT 	".2f";
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "C";
}



VARIABLE Phosphax1_ENCLOSURE_TEMP
{
         LABEL "Enclosure temperature" "|de|Gehuse Temperatur";
         HELP "the temperature inside the analyzer" "|de|the temperature inside the analyzer";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
		DISPLAY_FORMAT 	".2f";
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "C";
}

VARIABLE Phosphax1_PROBE_P_MIN
{
         LABEL "Probe p. min"  "|de|Druck Sonde min";
         HELP "integrated value of pressure at filtration probe, if not yet calculated: nan" "|de|integrated value of pressure at filtration probe, if not yet calculated: nan";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "BAR";
		VALIDITY  IF(Phosphax1_OPTION==0) {TRUE;} ELSE {FALSE;}
}

VARIABLE Phosphax1_PROBE_PRESSURE
{
         LABEL "Probe pressure" "|de|Druck Sonde";
         HELP "actual value of pressure at filtration probe, if not yet calculated: nan" "|de|actual value of pressure at filtration probe, if not yet calculated: nan";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
		CONSTANT_UNIT 	"BAR";
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		VALIDITY  IF(Phosphax1_OPTION==0) {TRUE;} ELSE {FALSE;}		
}

VARIABLE Phosphax1_GAIN_CORR_1
{
         LABEL "Gain corr 1" "|de|Korrektur Faktor";
         HELP "Gain correction for channel one" "|de|Gain correction for channel one";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}


VARIABLE Phosphax1_BUSACTION_ACTIVE
{
         LABEL "Busaction active" "|de|Busaktion aktiv";
         HELP "write a one to this register to start a bus action (see Field bus control)" "|de|write a one to this register to start a bus action (see Field bus control)";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
			    {0, "Off"  "|de|Aus"},
                {1, "Action"  "|de|Aktion"},
				{65535, "Deaktiv"  "|de|Deaktiviert"}
              }\ 
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_BUS_ANALY_START
{
         LABEL "Analyse start" "|de|Analyse start";
         HELP "you can start the analyzer about the bus" "|de|you can start the analyzer about the bus";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
			    {0, "Off"  "|de|Aus"},
                {1, "Action"  "|de|Aktion"},
				{65535, "Deaktiv"  "|de|Deaktiviert"}
              }
  	    HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
VALIDITY  FALSE;	
}

VARIABLE Phosphax1_BUS_SERVICE
{
         LABEL "Service" "|de|Service";
         HELP "you can start the service mode  about the bus" "|de|you can start the service mode  about the bus";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
  			    {0, "Off"  "|de|Aus"},
                {1, "Action"  "|de|Aktion"},
				{65535, "Deaktiv"  "|de|Deaktiviert"}
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
VALIDITY  FALSE;	
}


VARIABLE Phosphax1_BUS_CLEANING
{
         LABEL "Cleaning" "|de|Reinigen";
         HELP "you can start the cleaning mode  about the bus" "|de|you can start the cleaning mode  about the bus";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
  			    {0, "Off"  "|de|Aus"},
                {1, "Action"  "|de|Aktion"},
				{65535, "Deaktiv"  "|de|Deaktiviert"}			  
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}


VARIABLE Phosphax1_BUS_PREPUMP_REA
{
         LABEL "Prepump reagent" "|de|Vorpumpen Reagenz";
         HELP "you can prepump reagent  about the bus" "|de|you can prepump reagent  about the bus";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
			    {0, "Off"  "|de|Aus"},
                {1, "Action"  "|de|Aktion"},
				{65535, "Deaktiv"  "|de|Deaktiviert"}			  
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
VALIDITY  FALSE;
}

VARIABLE Phosphax1_BUS_PREPUMP_CLEA
{
         LABEL "Prepump clean" "|de|Vorpumpen Reinigen";
         HELP "you can prepump cleaning solution  about the bus" "|de|you can prepump cleaning solution  about the bus";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
			    {0, "Off"  "|de|Aus"},
                {1, "Action"  "|de|Aktion"},
				{65535, "Deaktiv"  "|de|Deaktiviert"}
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
VALIDITY  FALSE;
}

VARIABLE Phosphax1_BUS_PREPUMP_PRO
{
         LABEL "Prepump probe" "|de|Vorpumpen Sonde";
         HELP "you can prepump the probe  about the bus" "|de|you can prepump the probe  about the bus";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
			    {0, "Off"  "|de|Aus"},
                {1, "Action"  "|de|Aktion"},
				{65535, "Deaktiv"  "|de|Deaktiviert"}
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
VALIDITY  FALSE;
}

VARIABLE Phosphax1_BUS_PREPUMP_ALL
{
         LABEL "Prepump all" "|de|Vorpumpen Alles";
         HELP "you can prepump all  about the bus" "|de|you can prepump all  about the bus";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
			    {0, "Off"  "|de|Aus"},
                {1, "Action"  "|de|Aktion"},
				{65535, "Deaktiv"  "|de|Deaktiviert"}
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
VALIDITY  FALSE;
}

VARIABLE Phosphax1_REMAINING_TIME
{
         LABEL "Remaining time" "|de|Restzeit";
         HELP "remaining time of the current process " "|de|remaining time of the current process ";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "s";
}

VARIABLE Phosphax1_APPL
{
         LABEL "Application" "|de|Applikation";
         HELP "the entry is for the application file" "|de|the entry is for the application file";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_HEATING_ON
{
         LABEL "Heating on" "|de|Heizung an";
         HELP "sets the month when the sample line heating is switched ON" "|de|sets the month when the sample line heating is switched ON";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
                 {0, "NEVER"   "|de|NIE"},
                 {1, "JAN"   "|de|JAN"},
                 {2, "FEB"   "|de|FEB"},
                 {3, "MAR"   "|de|MAR"},
                 {4, "APR"   "|de|APR"},
                 {5, "MAY"   "|de|MAI"},
                 {6, "JUN"   "|de|JUNI"},
                 {7, "JUL"   "|de|JULI"},
                 {8, "AUG"   "|de|AUG"},
                 {9, "SEP"   "|de|SEP"},
                 {10, "OCT"   "|de|OKT"},
                 {11, "NOV"   "|de|NOV"},
                 {12, "DEC"   "|de|DEZ"},
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_HEATING_OFF
{
         LABEL "Heating off"  "|de|Heizung aus";
         HELP "sets the month when the sample line heating is switched OFF" "|de|sets the month when the sample line heating is switched OFF";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
                 {1, "JAN"   "|de|JAN"},
                 {2, "FEB"   "|de|FEB"},
                 {3, "MAR"   "|de|MAR"},
                 {4, "APR"   "|de|APR"},
                 {5, "MAY"   "|de|MAI"},
                 {6, "JUN"   "|de|JUNI"},
                 {7, "JUL"   "|de|JULI"},
                 {8, "AUG"   "|de|AUG"},
                 {9, "SEP"   "|de|SEP"},
                 {10, "OCT"   "|de|OKT"},
                 {11, "NOV"   "|de|NOV"},
                 {12, "DEC"   "|de|DEZ"},
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_CLEANING_MODULES
{
         LABEL "Cleaning modules" "|de|Module reinigen";
         HELP "" "|de|";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (4)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		VALIDITY  IF(Phosphax1_OPTION==0) {TRUE;} ELSE {FALSE;}

}

VARIABLE Phosphax1_SET_PARAMETER_1
{
         LABEL "Set parameter 1" "|de|Parameter 1";
         HELP "Parameter for channel 1" "|de|Parameter for channel 1";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
                 {15, "PO4-P"   "|de|PO4-P"},
                 {14, "PO4"   "|de|PO4"},
                 {16, "P2O5"   "|de|P2O5"},
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_AIR_FILTER_DISPL
{
         LABEL "Air filter display" "|de|Luftfilter Anzeige";
         HELP "days until next cleaning/exchange of air filter pads. Negative values show a cleaning which is overdue" "|de|days until next cleaning/exchange of air filter pads. Negative values show a cleaning which is overdue";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE INTEGER (2)
{
}
        HANDLING READ;
		CONSTANT_UNIT 	"Day";
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_COOLING
{
         LABEL "Cooling" "|de|Khlung";
         HELP "percentage of cooling fan power" "|de|percentage of cooling fan power";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "%";
}

VARIABLE Phosphax1_ANALYZER_HEATING
{
         LABEL "Analyzer heating" "|de|Heizung Gehuse";
         HELP "the heating of the analyzer" "|de|the heating of the analyzer";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "%";
}
VARIABLE Phosphax1_INTERVAL
{
         LABEL "Interval" "|de|Intervall";
         HELP "0=5 minutes, 1 =10minutes, 2=15 minutes to 23=120 minutes" "|de|0=5 minutes, 1 =10minutes, 2=15 minutes to 23=120 minutes";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
{
          {0, "5 min"  "|de|5 min"},
          {1, "10 min"  "|de|10 min"},
          {2, "15 min"  "|de|15 min"},
          {3, "20 min"  "|de|20 min"},
          {4, "25 min"  "|de|25 min"},
          {5, "30 min"  "|de|30 min"},
          {6, "35 min"  "|de|35 min"},
          {7, "40 min"  "|de|40 min"},
          {8, "45 min"  "|de|45 min"},
          {9, "50 min"  "|de|50 min"},
          {10, "55 min"  "|de|55 min"},
          {11, "60 min"  "|de|60 min"},
          {12, "65 min"  "|de|65 min"},
          {13, "70 min"  "|de|70 min"},
          {14, "75 min"  "|de|75 min"},
          {15, "80 min"  "|de|80 min"},
          {16, "85 min"  "|de|85 min"},
          {17, "90 min"  "|de|90 min"},
          {18, "95 min"  "|de|95 min"},
          {19, "100 min"  "|de|100 min"},
          {20, "105 min"  "|de|105 min"},
          {21, "110 min"  "|de|110 min"},
          {22, "115 min"  "|de|115 min"},
          {23, "120 min"  "|de|120 min"},
}
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_CLEANING_START
{
         LABEL "Cleaning start" "|de|Reinigung start";
		 HELP "it describes when the analyzer starts the cleaning (24 hour format) 0=0 o`clock to23=23oclock" "|de|it describes when the analyzer starts the cleaning (24 hour format) 0=0 o`clock to23=23oclock";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE     ENUMERATED (2)
          {
          {0, "0 a.m."  "|de|0 UHR"},
          {1, "1 a.m."  "|de|1 UHR"},
          {2, "2 a.m."  "|de|2 UHR"},
          {3, "3 a.m."  "|de|3 UHR"},
          {4, "4 a.m."  "|de|4 UHR"},
          {5, "5 a.m."  "|de|5 UHR"},
          {6, "6 a.m."  "|de|6 UHR"},
          {7, "7 a.m."  "|de|7 UHR"},
          {8, "8 a.m."  "|de|8 UHR"},
          {9, "9 a.m."  "|de|9 UHR"},
          {10, "10 a.m."  "|de|10 UHR"},
          {11, "11 a.m."  "|de|11 UHR"},
          {12, "12 p.m."  "|de|12 UHR"},
          {13, "1 p.m."  "|de|13 UHR"},
          {14, "2 p.m."  "|de|14 UHR"},
          {15, "3 p.m."  "|de|15 UHR"},
          {16, "4 p.m."  "|de|16 UHR"},
          {17, "5 p.m."  "|de|17 UHR"},
          {18, "6 p.m."  "|de|18 UHR"},
          {19, "7 p.m."  "|de|19 UHR"},
          {20, "8 p.m."  "|de|20 UHR"},
          {21, "9 p.m."  "|de|21 UHR"},
          {22, "10 p.m."  "|de|22 UHR"},
          {23, "11 p.m."  "|de|23 UHR"},
          }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_STATUS_MODULES_FL
{
         LABEL "Status modules" "|de|Zustand Module";
         HELP "the state of the modules as float in percent" "|de|the state of the modules as float in percent";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "%";
		VALIDITY  IF(Phosphax1_OPTION==0) {TRUE;} ELSE {FALSE;}
}

VARIABLE Phosphax1_STATUS_MODULES_UI
{
         LABEL "Status modules UI???" "|de|Zustand Module UI????";
         HELP "the state of the modules as float in percent" "|de|the state of the modules as float in percent";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "%";
		VALIDITY  IF(Phosphax1_OPTION==0) {TRUE;} ELSE {FALSE;}
}

VARIABLE Phosphax1_NEW_MODULES
{
         LABEL "New modules" "|de|Neue Module";
         HELP "date of the last filter module exchange" "|de|date of the last filter module exchange";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (4)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		VALIDITY  IF(Phosphax1_OPTION==0) {TRUE;} ELSE {FALSE;}

}


VARIABLE Phosphax1_DISCHARGE_CLEAN
{
         LABEL "Discharge cleaning" "|de|Verwrfe Reinigung";
         HELP "discharged values after a cleaning" "|de|discharged values after a cleaning";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_SET_OUTMODE_CLE
{
         LABEL "Set outmode cleaning" "|de|Ausgangsmodus Reinigung";
         HELP "Set output mode for cleaning" "|de|Set output mode for cleaning";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE     ENUMERATED (2)
          {
          {0, "HOLD"  "|de|HALTEN"},
          {1, "SET TRANSFER"  "|de|ERSATZWERT"},
          {2, "CHOICE"  "|de|AUSWAHL"}
          }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_SET_OUTMODE_SER
{
         LABEL "Set outmode service" "|de|Ausgangsmodus Service";
         HELP "Set output mode for service mode" "|de|Set output mode for service mode";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
                 {0, "HOLD"   "|de|HALTEN"},
                 {1, "SET TRANSFER"   "|de|ERSATZWERT"},
                 {2, "CHOICE"   "|de|AUSWAHL"},
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_CHANNEL2
{
         LABEL "Channel 2" "|de|Kanal 2";
         HELP "location for the measuring channel two where the sample is coming from" "|de|location for the measuring channel two where the sample is coming from";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ASCII (16)
{
}
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		VALIDITY  IF(Phosphax1_OPTION==2) {TRUE;} ELSE {FALSE;}
}


VARIABLE Phosphax1_SET_PARAMETER_2
{
         LABEL "Set parameter 2" "|de|Parameter 2";
         HELP "Parameter for channel 2" "|de|Parameter for channel 2";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
                 {15, "PO4-P"   "|de|PO4-P"},
                 {14, "PO4"   "|de|PO4"},
                 {16, "P2O5"   "|de|P2O5"},
              }
        HANDLING READ & WRITE;
		VALIDITY  IF(Phosphax1_OPTION==2) {TRUE;} ELSE {FALSE;}
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_GAIN_CORR_2
{
         LABEL "Gain corr 2" "|de|Korrekturfaktor 2";
         HELP "Gain correction for channel two" "|de|Gain correction for channel two";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ & WRITE;
		VALIDITY  IF(Phosphax1_OPTION==2) {TRUE;} ELSE {FALSE;}
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_MEAS_UNITS_2
{
         LABEL "Measurment units 2" "|de|Messwert Einheit 2";
         HELP "Measurement units for channel two, 0=mg/l,  2=ppm" "|de|Measurement units for channel two, 0=mg/l,  2=ppm";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE     ENUMERATED (2)
          {
          {0, "mg/l"  "|de|mg/l"},
          {2, "ppm"  "|de|ppm"},
          }
        HANDLING READ & WRITE;
		VALIDITY  IF(Phosphax1_OPTION==2) {TRUE;} ELSE {FALSE;}
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_HUMIDITY_ANALY
{
         LABEL "Humidity analy" "|de|Feuchte Gert";
         HELP "humitity analyzer in percent" "|de|humitity analyzer in percent";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ;
		CONSTANT_UNIT 	"%";
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_SOFTWARE_PROBE
{
         LABEL "Software probe" "|de|Softwareversion Sonde";
         HELP "the softwareversion of the filtration probe" "|de|the softwareversion of the filtration probe";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		VALIDITY  IF(Phosphax1_OPTION==0) {TRUE;} ELSE {FALSE;}
}

VARIABLE Phosphax1_HUMIDITY_PROBE
{
         LABEL "Humidity probe" "|de|Feuchte Sonde";
         HELP "humitity filtration probe in percent" "|de|humitity filtration probe in percent";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "%";
		VALIDITY  IF(Phosphax1_OPTION==0) {TRUE;} ELSE {FALSE;}
}
VARIABLE Phosphax1_PROCESS_STATE
{
         LABEL "Process state" "|de|Prozessausgabe";
         HELP "" "|de|";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE     ENUMERATED (2)
          {
                 {0, "SERVICE MODE"   "|de|SERVICEZUSTAND"},
                 {1, "MEASURING 1..."   "|de|MESSUNG 1 LUFT"},
                 {2, "INTERVAL"   "|de|MESSINTERVALL"},
                 {3, "INITIALISATION"   "|de|INITIALISIERUNG"},
                 {4, "SERV. IN PROC."   "|de|SERVICE LUFT"},
                 {5, "CLEANING"   "|de|REINIGUNG"},
                 {6, "WARM UP PHASE"   "|de|TEMPERIERPHASE"},
                 {7, "MEASURING 2..."   "|de|MESSUNG 2 LUFT"},
                 {8, "PREPUMP REAG."   "|de|VORP. REAGENZ"},
                 {9, "PREPUMP CLEAN."   "|de|VORP. REIN."},
                 {10, "PREPUMP PROBE"   "|de|VORPUMPEN SONDE"},
                 {11, "FLUSHING"   "|de|SPLEN"},
                 {12, "START BY BUS"   "|de|BUSAUSLSUNG"},
                 {13, "CALIBRATE"   "|de|KALIBRIEREN"},
                 {14, "TEST PROCEDURE"   "|de|TESTABLAUF"},
                 {15, "PREPUMP.SAMPLE"   "|de|VORPUMPEN PROBE"},
                 {16, "VALIDATION"   "|de|VALIDIERUNG"},
          }
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_START_BY_BUS
{
         LABEL "Start by bus" "|de|Busauslsung";
         HELP "sets the analyzer to START BY BUS mode ( see Start by bus)" "|de|sets the analyzer to START BY BUS mode ( see Start by bus)";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
  TYPE     ENUMERATED (2)
          {
          {0, "NO"  "|de|NEIN"},
          {1, "YES"  "|de|JA"},
          }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_FIELDBUS
{
         LABEL "Fieldbus" "|de|Feldbus";
         HELP "trigers a measurement serie in START BY BUS mode (see Start by bus)" "|de|trigers a measurement serie in START BY BUS mode (see Start by bus)";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
		 TYPE ENUMERATED (2)
              {
			    {0, "Off"  "|de|Aus"},
				{1, "Measure channel 1"  "|de|Messkanal 1"},
				{2, "Measure channel 2"  "|de|Messkanal 2"},
				{65535, "Deaktiv"  "|de|Deaktiviert"}
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_NUMBER_OF_MEAS
{
         LABEL "Number of measurment" "|de|Anzahl Messungen";
         HELP "Number of measurements in a START BY BUS measurement series (see Start by bus)" "|de|Number of measurements in a START BY BUS measurement series (see Start by bus)";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_DISCHARGE_BUS
{
         LABEL "Discharge bus" "|de|Verwrfe Bus";
         HELP "discharge values at the beginning of a START BY BUS series" "|de|discharge values at the beginning of a START BY BUS series";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_AVERAGE
{
         LABEL "Average" "|de|Mittelwert";
         HELP "The number of measurement values that result in an average value in a START BY BUS measurement series." "|de|The number of measurement values that result in an average value in a START BY BUS measurement series.";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_NO_OF_VALUES_CH1
{
         LABEL "No of values ch1" "|de|Anzahl der Werte Kanal 1";
         HELP "2 channel mode: how often is channel 1 measured before switching to channel 2" "|de|2 channel mode: how often is channel 1 measured before switching to channel 2";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_NO_OF_VALUES_CH2
{
         LABEL "No of values ch2" "|de|Anzahl der Werte Kanal 2";
         HELP "2 channel mode: how often is channel 2 measured before switching to channel 1" "|de|2 channel mode: how often is channel 2 measured before switching to channel 1";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		VALIDITY  IF(Phosphax1_OPTION==2) {TRUE;} ELSE {FALSE;}
}

VARIABLE Phosphax1_DISCHARGE_VAL1
{
         LABEL "Discharge value 1" "|de|Verwurfwerte 1";
         HELP "number of discharged values when switching from channel 1 to channel 2" "|de|number of discharged values when switching from channel 1 to channel 2";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_DISCHARGE_VAL2
{
         LABEL "Discharge value 2" "|de|Verwurfwerte 2";
         HELP "number of discharged values when switching from channel 2 to channel 1" "|de|number of discharged values when switching from channel 2 to channel 1";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		VALIDITY  IF(Phosphax1_OPTION==2) {TRUE;} ELSE {FALSE;}
}

VARIABLE Phosphax1_REAG_WARNING
{
         LABEL "Reagent warning" "|de|Reagenzwarnung";
         HELP "warning if the level of reagent is low" "|de|warning if the level of reagent is low";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
                 {0,     "OFF"    "|de|AUS"},
				{1,		"ON"     "|de|AN" }
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_TYPE
{
         LABEL "Type" "|de|Typ";
         HELP "name of the item/analyzer" "|de|name of the item/analyzer";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ASCII (12)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_SENSOR_NAME
{
         LABEL "Sensor name" "|de|Name Sensor";
         HELP "User-assigned name for a sensor" "|de|User-assigned name for a sensor";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ASCII (16)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_WARNING
{
         LABEL "Warning" "|de|Warnung";
         HELP "Reagent warning level in percent" "|de|Reagent warning level in percent";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
                 {20, "20%"   "|de|20%"},
                 {15, "15%"   "|de|15%"},
                 {10, "10%"   "|de|10%"},
                 {5, "5%"   "|de|5%"},
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_REAGENT_LEVEL
{
         LABEL "Reagent level" "|de|Reagenzstand";
         HELP "the level of reagent in percent" "|de|the level of reagent in percent";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "%";
}

VARIABLE Phosphax1_CLEAN_SOLU_LEVEL
{
         LABEL "Clean solution level" "|de|Reinigungsstand";
         HELP "cleaninig solution level in percent" "|de|cleaninig solution level in percent";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "%";
}


VARIABLE Phosphax1_PUMP_DISPLAY
{
         LABEL "Piston pumb"  "|de|Hubpumpe";
         HELP "days lest until exchanging piston of pump, negative values show that exchange is overdue" "|de|days lest until exchanging piston of pump, negative values show that exchange is overdue";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE INTEGER (2)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "Day";
}

VARIABLE Phosphax1_MEASURE_VALUE_2
{
         LABEL "Measure value 2" "|de|Messwert 2";
         HELP "actual measurement value from channel two" "|de|actual measurement value from channel two";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ ;
		VALIDITY  IF(Phosphax1_OPTION==2) {TRUE;} ELSE {FALSE;}
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
UNIT Phosphax1_MEASURE_VALUE_2_UNIT
{
	Phosphax1_MEAS_UNITS_2:
	Phosphax1_MEASURE_VALUE_2,
	Phosphax1_PHOSPHATE_P_2,
	Phosphax1_PHOS_PENTOXIDE2,
	Phosphax1_PHOSPHATE_2
}

VARIABLE Phosphax1_STRUCTURE
{
         LABEL "Structure" "|de|Struktur";
         HELP "the entry is for the device driver file" "|de|the entry is for the device driver file";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_FIRMWARE
{
         LABEL "Firmware" "|de|Firmware";
         HELP "the entry is for the device driver file" "|de|the entry is for the device driver file";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_CONTENT
{
         LABEL "Content" "|de|Inhalt";
         HELP "the entry is for the device driver file" "|de|the entry is for the device driver file";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_LOADER
{
         LABEL "Loader" "|de|Ladeprogramm";
         HELP "the entry is for the application file" "|de|the entry is for the application file";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_HEATING
{
         LABEL "Heating" "|de|Heizung";
         HELP "status off heating for sample tube" "|de|status off heating for sample tube";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
                 {0, "OFF"   "|de|AUS"},
                 {1, "ON"   "|de|EIN"},
              }
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
VARIABLE Phosphax1_OPERATING_HOURS
{
         LABEL "Operating hours" "|de|Betriebsstunden";
         HELP "operating hours of analyzer" "|de|operating hours of analyzer";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (4)
{
}
        HANDLING READ;
		CONSTANT_UNIT 	"h";
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;

}		

VARIABLE Phosphax1_PUMP_MEMBR_DISP
{
         LABEL "Pump membran display" "|de|Pumpmebrane Anzeige";
         HELP "remaining days for pump membrane in filter probe" "|de|remaining days for pump membrane in filter probe";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE INTEGER (2)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		VALIDITY  IF(Phosphax1_OPTION==0) {TRUE;} ELSE {FALSE;}
}

VARIABLE Phosphax1_LAST_CHA_FACTOR1
{
         LABEL "Last channel factor 1" "|de|Letzte nderung Faktor 1";
         HELP "the date of the last correction factor for channel one" "|de|the date of the last correction factor for channel one";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (4)
{
}
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;

}

VARIABLE Phosphax1_LAST_CHA_FACTOR2
{
         LABEL "Last channel factor 2" "|de|Letzte nderung Faktor 2";
		 HELP "the date of the last correction factor for channel  two" "|de|the date of the last correction factor for channel  two";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (4)
{
}
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		VALIDITY  IF(Phosphax1_OPTION==2) {TRUE;} ELSE {FALSE;}

}

VARIABLE Phosphax1_Fieldbus_Enable
{
         LABEL "Remote mode" "|de|Remotezugang";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
			    {0, "DISABLED" "|de|DEAKTIVIERT"},
			    {1, "ENABLED" "|de|AKTIVIERT"},
              }
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_SAMPLE_DETECTION
{
         LABEL "Sample detection" "|de|Probenerkennung";
         HELP "output if sample detection detects low sample amount" "|de|output if sample detection detects low sample amount";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE     ENUMERATED (2)
          {
          {0, "WARNING"  "|de|WARNMELDUNG"},
          {1, "ERROR"  "|de|FEHLER"},
          {2, "OFF"  "|de|AUS"},
          }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
VARIABLE Phosphax1_ACTUAL_MEAS_TIME
{
         LABEL "Actual measure time" "|de|Aktuelle Messzeit";
         HELP "time of actual measurement value" "|de|time of actual measurement value";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (4)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;

}

VARIABLE Phosphax1_LAST_TIME
{
         LABEL "Last time" "|de|1. Zeit vorher";
         HELP "time of last measurement value" "|de|time of last measurement value";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (4)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;

}


VARIABLE Phosphax1_ND2_LAST_TIME
{
         LABEL "2nd last time" "|de|2. Zeit vorher";
         HELP "2_ND LAST TIME" "|de|2_ND LAST TIME";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (4)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;

}

VARIABLE Phosphax1_RD3_LAST_TIME
{
         LABEL "3rd last time" "|de|3. Zeit vorher";
         HELP "3_RD LAST TIME" "|de|3_RD LAST TIME";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (4)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;

}
VARIABLE Phosphax1_TH4_LAST_TIME
{
         LABEL "4th last time" "|de|4. Zeit vorher";
         HELP "4.TH LAST TIME" "|de|4.TH LAST TIME";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (4)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}


VARIABLE Phosphax1_TH5_LAST_TIME
{
         LABEL "5th last time" "|de|5. Zeit vorher";
         HELP "5.TH LAST TIME" "|de|5.TH LAST TIME";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (4)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;

}

VARIABLE Phosphax1_TH6_LAST_TIME
{
         LABEL "6th last time" "|de|6. Zeit vorher";
         HELP "6.TH LAST TIME" "|de|6.TH LAST TIME";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (4)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;

}

VARIABLE Phosphax1_TH7_LAST_TIME
{
         LABEL "7th last time" "|de|7. Zeit vorher";
         HELP "7.TH LAST TIME" "|de|7.TH LAST TIME";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (4)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;

}

VARIABLE Phosphax1_TH8_LAST_TIME
{
         LABEL "8th last time" "|de|8. Zeit vorher";
         HELP "8.TH LAST TIME" "|de|8.TH LAST TIME";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (4)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;

}

VARIABLE Phosphax1_TH9_LAST_TIME
{
         LABEL "9th last time" "|de|9. Zeit vorher";
         HELP "9.TH LAST TIME" "|de|9.TH LAST TIME";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (4)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;

}

VARIABLE Phosphax1_ACTUAL_VALUE
{
         LABEL "Actual value" "|de|Aktueller Wert";
         HELP "actual measurement value from channel one" "|de|actual measurement value from channel one";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "mg/l";
}

VARIABLE Phosphax1_LAST_VALUE
{
         LABEL "Last value" "|de|1. Wert vorher";
         HELP "LIST OF VALUES" "|de|LIST OF VALUES";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "mg/l";
}

VARIABLE Phosphax1_ND2_LAST_VALUE
{
         LABEL "2nd last value" "|de|2. Wert vorher";
         HELP "LIST OF VALUES" "|de|LIST OF VALUES";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "mg/l";
}
VARIABLE Phosphax1_RD3_LAST_VALUE
{
         LABEL "3rd last value" "|de|3. Wert vorher";
         HELP "LIST OF VALUES" "|de|LIST OF VALUES";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "mg/l";
}


VARIABLE Phosphax1_TH4_LAST_VALUE
{
         LABEL "4th last value" "|de|4. Wert vorher";
         HELP "LIST OF VALUES" "|de|LIST OF VALUES";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "mg/l";
}

VARIABLE Phosphax1_TH5_LAST_VALUE
{
         LABEL "5th last value" "|de|5. Wert vorher";
         HELP "LIST OF VALUES" "|de|LIST OF VALUES";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "mg/l";
}

VARIABLE Phosphax1_TH6_LAST_VALUE
{
         LABEL "6th last value" "|de|6. Wert vorher";
         HELP "LIST OF VALUES" "|de|LIST OF VALUES";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "mg/l";
}

VARIABLE Phosphax1_TH7_LAST_VALUE
{
         LABEL "7th last value" "|de|7. Wert vorher";
         HELP "LIST OF VALUES" "|de|LIST OF VALUES";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "mg/l";
}

VARIABLE Phosphax1_TH8_LAST_VALUE
{
         LABEL "8th last value" "|de|8. Wert vorher";
         HELP "LIST OF VALUES" "|de|LIST OF VALUES";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "mg/l";
}

VARIABLE Phosphax1_TH9_LAST_VALUE
{
         LABEL "9th last value" "|de|9. Wert vorher";
         HELP "LIST OF VALUES" "|de|LIST OF VALUES";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "mg/l";
}

VARIABLE Phosphax1_STAT_MODUL_WAR
{
         LABEL "Status modul warning" "|de|Modulzustand Warnung";
         HELP "configure the level of warning for the state of the modules" "|de|configure the level of warning for the state of the modules";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
                 {40, "40%"   "|de|40%"},
                 {30, "30%"   "|de|30%"},
                 {15, "15%"   "|de|15%"},
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		VALIDITY  IF(Phosphax1_OPTION==0) {TRUE;} ELSE {FALSE;}
}


VARIABLE Phosphax1_STATUS_MODUL_ERR
{
         LABEL "Status modul error" "|de|Modulzustand Fehler";
         HELP "configure the level of error for the state of the modules" "|de|configure the level of error for the state of the modules";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
                 {14, "14%"   "|de|14%"},
                 {10, "10%"   "|de|10%"},
                 {8, "8%"   "|de|8%"},
                 {0, "OFF"   "|de|AUS"},
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		VALIDITY  IF(Phosphax1_OPTION==0) {TRUE;} ELSE {FALSE;}
}
VARIABLE Phosphax1_ENCLOSU_TEMP_MAX
{
         LABEL "Enclosure temperature max." "|de|Temperatur Gehuse max.";
         HELP "the maximum temperature inside the analyzer during the last 24 hours" "|de|the maximum temperature inside the analyzer during the last 24 hours";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
		DISPLAY_FORMAT 	".2f";
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "C";
}

VARIABLE Phosphax1_ENCLOSU_TEMP_MIN
{
         LABEL "Enclosure temperature min."  "|de|Temperatur Gehuse Min.";
         HELP "the minimum temperature inside the analyzer during the last 24 hours" "|de|the minimum temperature inside the analyzer during the last 24 hours";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
		DISPLAY_FORMAT 	".2f";
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
		CONSTANT_UNIT "C";
}

VARIABLE Phosphax1_EXHAUST_CONTROL
{
         LABEL "Exhaust control" "|de|Auslaufberwachung";
         HELP "the analyzer is checking the exhaust whether it is blocked" "|de|the analyzer is checking the exhaust whether it is blocked";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
                 {0,     "OFF"    "|de|AUS"},
				 {1,		"ON"     "|de|AN" }
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_ERROR_LIST
{
         LABEL "Error list" "|de|Fehler";
         HELP "Errors coded bit wise, bit0=TEMP. < 0 C/ 32F?, bit1=ANALYZ. TO COLD,  COOLING FAILED, HUMIDITY ANALY, HUMIDITY PROBE, PROBE MISSING,  NO HEAT UP, CUVSENSOR DEFECT,TEMPSENS DEFECT, CUVHEAT DEFECT,  CUV TOO HOT,  PHOTO LEVEL LOW, PHOTO LEVEL HIGH, MODULES CONTAM.,  PHOTO LEVEL2 LOW,  PHOTO LEVEL2 HIGH, DRAIN BLOCKED, SAMPLE1, bit18=SAMPLE2" "|de|Errors coded bit wise, bit0=TEMP. < 0 C/ 32F?, bit1=ANALYZ. TO COLD,  COOLING FAILED, HUMIDITY ANALY, HUMIDITY PROBE, PROBE MISSING,  NO HEAT UP, CUVSENSOR DEFECT,TEMPSENS DEFECT, CUVHEAT DEFECT,  CUV TOO HOT,  PHOTO LEVEL LOW, PHOTO LEVEL HIGH, MODULES CONTAM.,  PHOTO LEVEL2 LOW,  PHOTO LEVEL2 HIGH, DRAIN BLOCKED, SAMPLE1, bit18=SAMPLE2";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (4)
              {
              }
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;

}

VARIABLE Phosphax1_WARNING_LIST
{
         LABEL "Warning list" "|de|Warnung";
		 HELP  "Warnings, coded bit wise, bit0=WARMUP PHASE, bit1=COOLING DOWN, SERVICE MODE, REAGENT LEVEL," "|de|Warnings, coded bit wise, bit0=WARMUP PHASE, bit1=COOLING DOWN, SERVICE MODE, REAGENT LEVEL,";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (4)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_EDIT_NAME
{
         LABEL "Edit name" "|de|Name Messort";
		 HELP  "Name of LOCATION  (see menu system)" "|de|Name of LOCATION  (see menu system)";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ASCII (16)
{
}
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}


VARIABLE Phosphax1_OPTION
{
         LABEL "Measurement device" "|de|Messgert";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE     ENUMERATED (2)
          {
          {0, "FILTRATION PRO"  "|de|FILTERSONDE"},
          {1, "1-CHANNEL"  "|de|1-KANAL"},
          {2, "2-CHANNEL"  "|de|2-KANAL"}
          }
  HANDLING READ;
  READ_TIMEOUT READ_TIMEOUT_VAL;
  WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}


VARIABLE Phosphax1_MEAS
{
         LABEL "Meas."  "|de|Mess";
         HELP "measuring value " "|de|measuring value ";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
VARIABLE Phosphax1_MEAS_ZERO
{
         LABEL "Meas. zero"  "|de|Mess Null";
         HELP "measuring zero" "|de|measuring zero";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
VARIABLE Phosphax1_OFFSET_MEAS
{
         LABEL "Offset meas."  "|de|Offset Mess";
         HELP "offset measuring" "|de|offset measuring";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
VARIABLE Phosphax1_REF
{
         LABEL "Ref"  "|de|Ref";
         HELP "reference value" "|de|reference value";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
VARIABLE Phosphax1_REF_ZERO
{
         LABEL "Ref zero"  "|de|Ref Null";
         HELP "reference zero" "|de|reference zero";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
VARIABLE Phosphax1_OFFSET_REF
{
         LABEL "Offset ref"  "|de|Offset Ref";
         HELP "offset reference" "|de|offset reference";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
VARIABLE Phosphax1_AMPLIFY_MEAS
{
         LABEL "AMplify meas."  "|de|Verstrkung Mess";
         HELP "amplification of measurement channel" "|de|amplification of measurement channel";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
VARIABLE Phosphax1_AMPLIFY_REF
{
         LABEL "Amplify ref"  "|de|Verstrkung ref";
         HELP "amplification of reference channel" "|de|amplification of reference channel";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE UNSIGNED_INTEGER (2)
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_PHOSPHATE_P_1
{
         LABEL "Phosphate-P 1"  "|de|Phosphat-P 1";
         HELP "measurement value for channel one as PO4-P" "|de|measurement value for channel one as PO4-P";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
UNIT Phosphax_Unit_Messeinheit
{
	Phosphax1_MEAS_UNITS_1:
	Phosphax1_PHOSPHATE_P_1, Phosphax1_PHOSPHATE_1, Phosphax1_PHOS_PENTOXIDE1,Phosphax1_MEASURE_VALUE_1
	Phosphax1_PHOSPHATE_P_2, Phosphax1_PHOSPHATE_2, Phosphax1_PHOS_PENTOXIDE2, Phosphax1_MEASURE_VALUE_2
}

VARIABLE Phosphax1_PHOSPHATE_P_2
{
         LABEL "Phosphate-P 2"  "|de|Phosphat-P 2";
         HELP "measurement value for channel two as PO4-P" "|de|measurement value for channel two as PO4-P";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
		VALIDITY  IF(Phosphax1_OPTION==2) {TRUE;} ELSE {FALSE;}
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}


VARIABLE Phosphax1_PHOSPHATE_1
{
         LABEL "Phosphate 1"  "|de|Phosphat 1";
         HELP "measurement value for channel one as PO4" "|de|measurement value for channel one as PO4";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
VARIABLE Phosphax1_PHOSPHATE_2
{
         LABEL "Phosphate 2"  "|de|Phosphat 2";
         HELP "measurement value for channel two as PO4" "|de|measurement value for channel two as PO4";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
		VALIDITY  IF(Phosphax1_OPTION==2) {TRUE;} ELSE {FALSE;}
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
VARIABLE Phosphax1_PHOS_PENTOXIDE1
{
         LABEL "Phos.pentoxide1"  "|de|Phos.Pentoxide1";
         HELP "measurement value for channel one as P2O5" "|de|measurement value for channel one as P2O5";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
VARIABLE Phosphax1_PHOS_PENTOXIDE2
{
         LABEL "Phos.pentoxide2"  "|de|Phos.PEntoxide2";
         HELP "measurement value for channel two as P2O5" "|de|measurement value for channel two as P2O5";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
		VALIDITY  IF(Phosphax1_OPTION==2) {TRUE;} ELSE {FALSE;}
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
VARIABLE Phosphax1_DEXT_LAST_VALUE
{
         LABEL "Dext last value"  "|de|Dext letzte Mess";
         HELP "last extinction value" "|de|last extinction value";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}



VARIABLE Phosphax1_EXT_MESS_1
{
         LABEL "Ext mess 1"  "|de|Ext Mess 1";
         HELP "the current measuring extinction from  channel one" "|de|the current measuring extinction from  channel one";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
VARIABLE Phosphax1_EXT_MESS_2
{
         LABEL "Ext mess 2"  "|de|Ext Mess 2";
         HELP "the current measuring extinction from  channel two" "|de|the current measuring extinction from  channel two";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
		VALIDITY  IF(Phosphax1_OPTION==2) {TRUE;} ELSE {FALSE;}
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
VARIABLE Phosphax1_EXT_REF
{
         LABEL "Ext ref"  "|de|Ext Ref";
         HELP "the current reference extinction" "|de|the current reference extinction";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_START
{
         LABEL "Start"  "|de|Start";
         HELP "it describes when the analyzer starts the cleaning (24 hour format) 0=0 o`clock to23=23oclock" "|de|it describes when the analyzer starts the cleaning (24 hour format) 0=0 o`clock to23=23oclock";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
                 {0, "0 a.m."   "|de|0 UHR"},
                 {1, "1 a.m."   "|de|1 UHR"},
                 {2, "2 a.m."   "|de|2 UHR"},
                 {3, "3 a.m."   "|de|3 UHR"},
                 {4, "4 a.m."   "|de|4 UHR"},
                 {5, "5 a.m."   "|de|5 UHR"},
                 {6, "6 a.m."   "|de|6 UHR"},
                 {7, "7 a.m."   "|de|7 UHR"},
                 {8, "8 a.m."   "|de|8 UHR"},
                 {9, "9 a.m."   "|de|9 UHR"},
                 {10, "10 a.m."   "|de|10 UHR"},
                 {11, "11 a.m."   "|de|11 UHR"},
                 {12, "12 a.m."   "|de|12 UHR"},
                 {13, "13 a.m."   "|de|13 UHR"},
                 {14, "14 a.m."   "|de|14 UHR"},
                 {15, "15 a.m."   "|de|15 UHR"},
                 {16, "16 a.m."   "|de|16 UHR"},
                 {17, "17 a.m."   "|de|17 UHR"},
                 {18, "18 a.m."   "|de|18 UHR"},
                 {19, "19 a.m."   "|de|19 UHR"},
                 {20, "20 a.m."   "|de|20 UHR"},
                 {21, "21 a.m."   "|de|21 UHR"},
                 {22, "22 a.m."   "|de|22 UHR"},
                 {23, "23 a.m."   "|de|23 UHR"},
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
VARIABLE Phosphax1_SET_INTERVAL
{
         LABEL "Set interval"  "|de|Intervall";
         HELP "cleaning intervall " "|de|cleaning intervall ";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
                 {0, "OFF"   "|de|AUS"},
                 {1, "1 h"   "|de|1 h"},
                 {3, "3 h"   "|de|3 h"},
                 {6, "6 h"   "|de|6 h"},
                 {8, "8 h"   "|de|8 h"},
                 {12, "12 h"   "|de|12 h"},
                 {24, "24 h"   "|de|24 h"},
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE Phosphax1_EXTINCTION_2
{
         LABEL "Extinction 2"  "|de|Extinktion 2";
         HELP "" "|de|";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE FLOAT
{
}
        HANDLING READ;
		VALIDITY  IF(Phosphax1_OPTION==2) {TRUE;} ELSE {FALSE;}
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}


VARIABLE Phosphax1_REF_
{
         LABEL "Ref"  "|de|Ref";
         HELP "to switch the ref measuring on or off" "|de|to switch the ref measuring on or off";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
                 {0, "DISABLED"   "|de|DEAKTIVIERT"},
                 {1, "ENABLED"   "|de|AKTIVIERT"},
              }
	    HANDLING READ ;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
VARIABLE Phosphax1_BUBBLE_REJECT
{
         LABEL "Bubble reject"  "|de|Luftbl Unterdr";
         HELP "it's possible to set the function bubble reject" "|de|it's possible to set the function bubble reject";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
                 {0, "DISABLED"   "|de|DEAKTIVIERT"},
                 {1, "ENABLED"   "|de|AKTIVIERT"},
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}
VARIABLE Phosphax1_SEL_ADJ_METHOD
{
         LABEL "Sel adj method"  "|de|Whle Methode";
         HELP "it's possible to set the measuring interval as dry or wet" "|de|it's possible to set the measuring interval as dry or wet";
         CLASS IF (dyn_aus==1)  {CONTAINED;} ELSE {DYNAMIC;}
         TYPE ENUMERATED (2)
              {
                 {0, "DRY"   "|de|TROCKEN"},
                 {1, "WET"   "|de|NASS"},
              }
        HANDLING READ & WRITE;
        READ_TIMEOUT READ_TIMEOUT_VAL;
        WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

//----DEF Variablen--ENDE---------------------------------------------------------------------
//----DEF COMMAND read---
COMMAND read_Phosphax1_Data1
{
 SLOT Phosphax1_SLOTADR;
 INDEX 0;
     OPERATION READ;
     TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          Phosphax1_MEASURE_VALUE_1,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
		  Phosphax1_CHANNEL1,
          Phosphax1_MEAS,
          Phosphax1_MEAS_ZERO,
          Phosphax1_OFFSET_MEAS,
          Phosphax1_REF,
          Phosphax1_REF_ZERO,
          Phosphax1_OFFSET_REF,
          Phosphax1_AMPLIFY_MEAS,
          Phosphax1_AMPLIFY_REF,
          Phosphax1_COOLING,
          Phosphax1_HEATING,
          Phosphax1_HUMIDITY_PROBE,
          Phosphax1_ENCLOSURE_TEMP,
          Phosphax1_ACTUAL_VALUE,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte
}
    }
}

COMMAND read_Phosphax1_Data2
{
 SLOT Phosphax1_SLOTADR;
 INDEX 33;
     OPERATION READ;
     TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
		  Phosphax1_CHANNEL2,
          Phosphax1_CONTENT,
		  Phosphax1_REMAINING_TIME,
          Phosphax1_CUVETTE_TEMP,
          Phosphax1_PHOSPHATE_P_1,
          Phosphax1_PHOSPHATE_P_2,
          Phosphax1_PHOSPHATE_1,
          Phosphax1_PHOSPHATE_2,
          Phosphax1_PHOS_PENTOXIDE1,
          Phosphax1_PHOS_PENTOXIDE2,
          Phosphax1_DEXT_LAST_VALUE,
          Phosphax1_HEATING_ON,
          Phosphax1_HEATING_OFF,
          Phosphax1_MEASURE_VALUE_2,
          Phosphax1_EXT_MESS_1,
          Phosphax1_EXT_MESS_2,
          Phosphax1_EXT_REF
}
    }
}

COMMAND read_Phosphax1_Data3
{
 SLOT Phosphax1_SLOTADR;
 INDEX 69;
     OPERATION READ;
     TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          Phosphax1_ANALYZER_HEATING,
          Phosphax1_BUSACTION_ACTIVE,
          Phosphax1_BUS_ANALY_START,
          Phosphax1_BUS_SERVICE,
          Phosphax1_BUS_CLEANING,
          Phosphax1_BUS_PREPUMP_REA,
          Phosphax1_BUS_PREPUMP_CLEA,
          Phosphax1_BUS_PREPUMP_PRO,
          Phosphax1_BUS_PREPUMP_ALL,
          Phosphax1_PROBE_P_MIN,
          Phosphax1_PROBE_PRESSURE,
          Phosphax1_GAIN_CORR_1,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          Phosphax1_DISCHARGE_CLEAN,
          Phosphax1_SET_OUTMODE_CLE,
          Phosphax1_SET_OUTMODE_SER,
          Phosphax1_SOFTWARE_PROBE,
          Phosphax1_STATUS_MODULES_FL,
          Phosphax1_MEAS_UNITS_1,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte
}
    }
}

COMMAND read_Phosphax1_Data4
{
 SLOT Phosphax1_SLOTADR;
 INDEX 103;
     OPERATION READ;
     TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          Phosphax1_APPL,
          Phosphax1_TYPE,
          Phosphax1_STATUS_MODULES_UI,
          Phosphax1_CLEANING_MODULES,
          Phosphax1_INTERVAL,
          dummy_byte, dummy_byte,
          Phosphax1_START,
          Phosphax1_SET_INTERVAL,
          Phosphax1_NEW_MODULES,
          Phosphax1_SET_PARAMETER_1,
          Phosphax1_GAIN_CORR_2,
          Phosphax1_OPTION,
          Phosphax1_SET_PARAMETER_2,
          Phosphax1_MEAS_UNITS_2,
          Phosphax1_HUMIDITY_ANALY,
          Phosphax1_FIELDBUS,
          Phosphax1_START_BY_BUS,
          Phosphax1_EXTINCTION_2,
          dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte
}
    }
}

COMMAND read_Phosphax1_Data5
{
 SLOT Phosphax1_SLOTADR;
 INDEX 131;
     OPERATION READ;
     TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          Phosphax1_PROCESS_STATE,
          Phosphax1_NUMBER_OF_MEAS,
          Phosphax1_AVERAGE,
          Phosphax1_NO_OF_VALUES_CH1,
          Phosphax1_NO_OF_VALUES_CH2,
          Phosphax1_DISCHARGE_VAL1,
          Phosphax1_DISCHARGE_VAL2,
          dummy_byte, dummy_byte,
          Phosphax1_DISCHARGE_BUS,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          Phosphax1_SENSOR_NAME,
          Phosphax1_REAG_WARNING,
          Phosphax1_WARNING,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          Phosphax1_REAGENT_LEVEL,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          Phosphax1_CLEAN_SOLU_LEVEL,
          dummy_byte, dummy_byte,
          Phosphax1_AIR_FILTER_DISPL,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          Phosphax1_PUMP_DISPLAY,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
}
    }
}

COMMAND read_Phosphax1_Data6
{
 SLOT Phosphax1_SLOTADR;
 INDEX 167;
     OPERATION READ;
     TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          Phosphax1_STRUCTURE,
          Phosphax1_FIRMWARE,
          Phosphax1_LOADER,
          Phosphax1_OPERATING_HOURS,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
		  Phosphax1_PUMP_MEMBR_DISP,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          Phosphax1_LAST_CHA_FACTOR1,
		  dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte
		  dummy_byte, dummy_byte,
		}
    }
}

COMMAND read_Phosphax1_Data7
{
 SLOT Phosphax1_SLOTADR;
 INDEX 199;
     OPERATION READ;
     TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          Phosphax1_LAST_CHA_FACTOR2,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          Phosphax1_Fieldbus_Enable,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          Phosphax1_SAMPLE_DETECTION,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          Phosphax1_ACTUAL_MEAS_TIME,
          Phosphax1_LAST_TIME,
          Phosphax1_ND2_LAST_TIME,
          Phosphax1_RD3_LAST_TIME,
          Phosphax1_TH4_LAST_TIME,
          Phosphax1_TH5_LAST_TIME,
          Phosphax1_TH6_LAST_TIME,
          Phosphax1_TH7_LAST_TIME,
          Phosphax1_TH8_LAST_TIME,
          dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
}
    }
}

COMMAND read_Phosphax1_Data8
{
 SLOT Phosphax1_SLOTADR;
 INDEX 233;
     OPERATION READ;
     TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          Phosphax1_TH9_LAST_TIME,
          Phosphax1_LAST_VALUE,
          Phosphax1_ND2_LAST_VALUE,
          Phosphax1_RD3_LAST_VALUE,
          Phosphax1_TH4_LAST_VALUE,
          Phosphax1_TH5_LAST_VALUE,
          Phosphax1_TH6_LAST_VALUE,
          Phosphax1_TH7_LAST_VALUE,
          Phosphax1_TH8_LAST_VALUE,
          Phosphax1_TH9_LAST_VALUE,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          Phosphax1_STATUS_MODUL_ERR,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
}
    }
}

//Tagregisterstart: 40257= 40001+ 256(Slot x+32) + 0(=index)
COMMAND read_Phosphax1_Data9
{
 SLOT Phosphax1_SLOTADR+32;
 INDEX 0;
     OPERATION READ;
     TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          Phosphax1_STAT_MODUL_WAR,
          Phosphax1_EXHAUST_CONTROL,
          dummy_byte, dummy_byte,
          Phosphax1_REF_,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          Phosphax1_BUBBLE_REJECT,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
}
    }
}

//Tagregisterstart: 40270= 40001+ 256(Slot x+32) + 13(=index)
COMMAND read_Phosphax1_Data10
{
 SLOT Phosphax1_SLOTADR+32;
 INDEX 13;
     OPERATION READ;
     TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          dummy_byte, dummy_byte,
          Phosphax1_SEL_ADJ_METHOD,
          dummy_byte, dummy_byte,
		  Phosphax1_ENCLOSU_TEMP_MIN,
          Phosphax1_ENCLOSU_TEMP_MAX,
		  Phosphax1_ERROR_LIST,
		  Phosphax1_WARNING_LIST,
		  Phosphax1_EDIT_NAME,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		  dummy_byte, dummy_byte,
		}
    }
}



//----DEF Command write----
COMMAND write_Phosphax1_CHANNEL1
{
 SLOT Phosphax1_SLOTADR;
 INDEX 4;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_CHANNEL1        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_CHANNEL2
{
 SLOT Phosphax1_SLOTADR;
 INDEX 33;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_CHANNEL2        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_HEATING_ON
{
 SLOT Phosphax1_SLOTADR;
 INDEX 59;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_HEATING_ON        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_HEATING_OFF
{
 SLOT Phosphax1_SLOTADR;
 INDEX 60;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_HEATING_OFF        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_BUSACTION_ACTIVE
{
 SLOT Phosphax1_SLOTADR;
 INDEX 70;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_BUSACTION_ACTIVE        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_BUS_ANALY_START
{
 SLOT Phosphax1_SLOTADR;
 INDEX 71;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_BUS_ANALY_START        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_BUS_SERVICE
{
 SLOT Phosphax1_SLOTADR;
 INDEX 72;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_BUS_SERVICE        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_BUS_CLEANING
{
 SLOT Phosphax1_SLOTADR;
 INDEX 73;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_BUS_CLEANING        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_BUS_PREPUMP_REA
{
 SLOT Phosphax1_SLOTADR;
 INDEX 74;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_BUS_PREPUMP_REA        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_BUS_PREPUMP_CLEA
{
 SLOT Phosphax1_SLOTADR;
 INDEX 75;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_BUS_PREPUMP_CLEA        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_BUS_PREPUMP_PRO
{
 SLOT Phosphax1_SLOTADR;
 INDEX 76;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_BUS_PREPUMP_PRO        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_BUS_PREPUMP_ALL
{
 SLOT Phosphax1_SLOTADR;
 INDEX 77;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_BUS_PREPUMP_ALL        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_GAIN_CORR_1
{
 SLOT Phosphax1_SLOTADR;
 INDEX 82;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_GAIN_CORR_1        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_DISCHARGE_CLEAN
{
 SLOT Phosphax1_SLOTADR;
 INDEX 95;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_DISCHARGE_CLEAN        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_SET_OUTMODE_CLE
{
 SLOT Phosphax1_SLOTADR;
 INDEX 96;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_SET_OUTMODE_CLE        }
        REPLY
        {
        }
    }
}



COMMAND write_Phosphax1_SET_OUTMODE_SER
{
 SLOT Phosphax1_SLOTADR;
 INDEX 97;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_SET_OUTMODE_SER        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_MEAS_UNITS_1
{
 SLOT Phosphax1_SLOTADR;
 INDEX 102;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_MEAS_UNITS_1        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_CLEANING_MODULES
{
 SLOT Phosphax1_SLOTADR;
 INDEX 112;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_CLEANING_MODULES        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_INTERVAL
{
 SLOT Phosphax1_SLOTADR;
 INDEX 114;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_INTERVAL        }
        REPLY
        {
        }
    }
}



COMMAND write_Phosphax1_START
{
 SLOT Phosphax1_SLOTADR;
 INDEX 116;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_START        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_SET_INTERVAL
{
 SLOT Phosphax1_SLOTADR;
 INDEX 117;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_SET_INTERVAL        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_NEW_MODULES
{
 SLOT Phosphax1_SLOTADR;
 INDEX 118;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_NEW_MODULES        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_SET_PARAMETER_1
{
 SLOT Phosphax1_SLOTADR;
 INDEX 120;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_SET_PARAMETER_1        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_GAIN_CORR_2
{
 SLOT Phosphax1_SLOTADR;
 INDEX 121;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_GAIN_CORR_2        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_SET_PARAMETER_2
{
 SLOT Phosphax1_SLOTADR;
 INDEX 124;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_SET_PARAMETER_2        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_MEAS_UNITS_2
{
 SLOT Phosphax1_SLOTADR;
 INDEX 125;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_MEAS_UNITS_2        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_FIELDBUS
{
 SLOT Phosphax1_SLOTADR;
 INDEX 127;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_FIELDBUS        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_START_BY_BUS
{
 SLOT Phosphax1_SLOTADR;
 INDEX 128;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_START_BY_BUS        }
        REPLY
        {
        }
    }
}


COMMAND write_Phosphax1_NUMBER_OF_MEAS
{
 SLOT Phosphax1_SLOTADR;
 INDEX 132;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_NUMBER_OF_MEAS        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_AVERAGE
{
 SLOT Phosphax1_SLOTADR;
 INDEX 133;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_AVERAGE        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_NO_OF_VALUES_CH1
{
 SLOT Phosphax1_SLOTADR;
 INDEX 134;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_NO_OF_VALUES_CH1        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_NO_OF_VALUES_CH2
{
 SLOT Phosphax1_SLOTADR;
 INDEX 135;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_NO_OF_VALUES_CH2        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_DISCHARGE_VAL1
{
 SLOT Phosphax1_SLOTADR;
 INDEX 136;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_DISCHARGE_VAL1        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_DISCHARGE_VAL2
{
 SLOT Phosphax1_SLOTADR;
 INDEX 137;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_DISCHARGE_VAL2        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_DISCHARGE_BUS
{
 SLOT Phosphax1_SLOTADR;
 INDEX 139;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_DISCHARGE_BUS        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_REAG_WARNING
{
 SLOT Phosphax1_SLOTADR;
 INDEX 150;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_REAG_WARNING        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_WARNING
{
 SLOT Phosphax1_SLOTADR;
 INDEX 151;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_WARNING        }
        REPLY
        {
        }
    }
}


COMMAND write_Phosphax1_OPERATING_HOURS
{
 SLOT Phosphax1_SLOTADR;
 INDEX 174;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_OPERATING_HOURS        }
        REPLY
        {
        }
    }
}


COMMAND write_Phosphax1_LAST_CHA_FACTOR1
{
 SLOT Phosphax1_SLOTADR;
 INDEX 197;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_LAST_CHA_FACTOR1        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_LAST_CHA_FACTOR2
{
 SLOT Phosphax1_SLOTADR;
 INDEX 199;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_LAST_CHA_FACTOR2        }
        REPLY
        {
        }
    }
}

COMMAND write_Phosphax1_SAMPLE_DETECTION
{
 SLOT Phosphax1_SLOTADR;
 INDEX 210;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_SAMPLE_DETECTION        }
        REPLY
        {
        }
    }
}


COMMAND write_Phosphax1_STATUS_MODUL_ERR
{
 SLOT Phosphax1_SLOTADR;
 INDEX 255;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_STATUS_MODUL_ERR        }
        REPLY
        {
        }
    }
}

//Tagregisterstart: 40257= 40001+ 256(Slot x+32) + 0(=index)
COMMAND write_Phosphax1_STAT_MODUL_WAR
{
 SLOT Phosphax1_SLOTADR+32;
 INDEX 0;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_STAT_MODUL_WAR        }
        REPLY
        {
        }
    }
}

//Tagregisterstart: 40258= 40001+ 256(Slot x+32) + 1(=index)
COMMAND write_Phosphax1_EXHAUST_CONTROL
{
 SLOT Phosphax1_SLOTADR+32;
 INDEX 1;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_EXHAUST_CONTROL        }
        REPLY
        {
        }
    }
}



//Tagregisterstart: 40264= 40001+ 256(Slot x+32) + 7(=index)
COMMAND write_Phosphax1_BUBBLE_REJECT
{
 SLOT Phosphax1_SLOTADR+32;
 INDEX 7;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_BUBBLE_REJECT        }
        REPLY
        {
        }
    }
}

//Tagregisterstart: 40270= 40001+ 256(Slot x+32) + 13(=index)
COMMAND write_Phosphax1_SEL_ADJ_METHOD
{
 SLOT Phosphax1_SLOTADR+32;
 INDEX 13;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_SEL_ADJ_METHOD        }
        REPLY
        {
        }
    }
}

//Tagregisterstart: 40281= 40001+ 256(Slot x+32) + 24(=index)
COMMAND write_Phosphax1_EDIT_NAME
{
 SLOT Phosphax1_SLOTADR+32;
 INDEX 24;
     OPERATION WRITE;
     TRANSACTION
    {
        REQUEST
        {
         Phosphax1_EDIT_NAME 	 }
        REPLY
        {
        }
    }
}



/*-----------------------COMMANDS---------------------------------------*/




