/*--------------------------------------------------------------*/
/*Copyright (C)	Hach-Lange (2010). All Rights Reserved.    		*/	
/*Product:	SIMATIC PDM  	           							*/
/*Device:	SC SS7        	           		        			*/
/*Description:	Device Description	           					*/
/*Dictionary:	SIPADC01.dct	           						*/
/*$Revision:	1.6  $  	           							*/
/*$Date:	Maerz 2010	           								*/
/*File:	SC_SS7.ddl   	           								*/
/*	Author:			T.Thiel Hach-Lange              			*/
/*				R.Mellows Hach-Lange            				*/
/*				R.Stollenwerk Hach-Lange        				*/
/*--------------------------------------------------------------*/


/************************************************************************/
/*---------------------Variablen----------------------------------------*/
/************************************************************************/


VARIABLE SS71_Measurement1

{
 LABEL 	"Turbidity value" 	"|de|Trbungswert";
 HELP	"Measured turbidity value";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
        DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

}


VARIABLE SS71_Measurement2  //TEMP	40005 Temperature measurement in Celsius

{
 LABEL 	"Temperature" 	"|de|Temperatur";
 HELP	"Temperature measurement in Celsius" ;
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
        DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"C";
}

VARIABLE SS71_Measurement3  //LAMP V	40018   Lamp voltage

{
 LABEL 	"Lamp voltage" 	"|de|Lampenspannung";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
        DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"V";
}

VARIABLE SS71_Measurement4  //LAMP CURR	40020 Lamp Current (amps)

{
 LABEL 	"Lamp Current" 	"|de|Lampenstrom";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
        DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"A";
}

VARIABLE SS71_Measurement5  //INPUT V	40024 Input voltage (~12V)

{
 LABEL 	"Input voltage" 	"|de|Eingangsspannung";
 HELP	"Input voltage (12V)";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
        DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"V";
}

VARIABLE SS71_Measurement6  //TEMP MAX	40068 Maximum Temperature

{
 LABEL 	"Maximum Temperature" 	"|de|Maximale Temperatur";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
        DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"C";
}

VARIABLE SS71_Measurement7  // TEMP MIN	40070 Minimum Temperature

{
 LABEL 	"Minimum Temperature" 	"|de|Minimale Temperatur";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
        DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"C";
}

VARIABLE SS71_Measurement8

{
 LABEL 	"+5V" 	"|de|+5V";
 HELP	"Plus five volt measurement" ;
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
        DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"V";
}


VARIABLE SS71_Measurement9

{
 LABEL 	"Voltage Ref." 	"|de|Spannungsreferenz";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {
        DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;

	CONSTANT_UNIT 	"V";
}

UNIT Select_unit_1		// dynymic unit relation
{
	SS71_Unit1:
	SS71_Measurement1


}

//-----------------Messwerte------Ende------------------------------


//-----------------Settings------Anfang------------------------------

VARIABLE SS71_Unit1  //Turbidity Unit	40004 Turb units (0=mg/L:7=NTU;42=FTU)
{
	LABEL 	"Turbidity Unit" "|de|Trbungseinheit";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{
          MIN_VALUE 0 ;
	  MAX_VALUE 114 ;
	  {0,	"mg/l"   },
	  {7,	"NTU"    },
	  {42,	"FTU"    },
	  {114,	"No Sensor"   "|de|Kein Sensor" }
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE SS71_Setting1  //Bubble Reject	40017   Bubble reject status (0=OFF; 1=ON)
{
	LABEL 	"Bubble Reject" "|de|Luftblasenunterdrckung";
	HELP	"Bubble reject status";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{
         MIN_VALUE 0 ;
	 MAX_VALUE 1 ;


         { 0, "Off" "|de|Aus"},
	 { 1, "On"  "|de|An"}
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}


VARIABLE SS71_Setting2  //Datalog Interval	40026  Datalog interval (0=5sec;
                          //1=30sec;2=1min;3=2min;4=5min;6=10min;7=15min;8=30min;9=60min, 10=4hr)
{
	LABEL 	"Datalog Interval" "|de|Datenloggerintervall";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
         MIN_VALUE 0 ;
	 MAX_VALUE 10 ;

	{0,	"5sec"   "|de|5s"},
	{1,	"30sec"  "|de|30s"},
	{2,	"1min"   "|de|1min"},
	{3,	"2min"   "|de|2min"},
	{4,	"5min"   "|de|5min"},
	{5,	"10min"  "|de|10min"},
	{6,	"15min"  "|de|15min"},
	{7,	"30min"  "|de|30min"},
	{8,	"60min"  "|de|60min"},
	{9,	"4hr"    "|de|4h"}

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE SS71_Setting3  //Sensor Name	40027 Sensor name or location (8)
{
	LABEL 	"Probe Location" "|de|Einbauort";
	CLASS	CONTAINED;
	TYPE	ASCII (12)
		{

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE SS71_Setting4  //SIGNAL AVG	40035 Signal Average (0=1sec; 1=6sec;
                        //2=30sec;3=60sec;4=90sec)
{
	LABEL 	"Signal avg" "|de|Mittelwertbildung";
	HELP	"Signal Average";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
         MIN_VALUE 0 ;
	 MAX_VALUE 4 ;

	{0,	"No Averaging"  "|de|Kein Mittelwert" },
	{1,	"6sec"          "|de|6s" },
	{2,	"30sec"         "|de|30s"},
	{3,	"60sec"         "|de|60s"},
	{4,	"90sec"         "|de|90s"}

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE SS71_Setting5

{
	LABEL 	"Resolution" "|de|Auflsung";
	HELP	"Maximum number of decimal places";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{

		{0,	"xxxxx"   },
		{1,	"xxxx.x"    },
		{2,	"xxx.xx"    }

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}


VARIABLE SS71_Setting8

{
	LABEL 	"Service Mode" "|de|Service Betrieb";
	HELP	"Used to detemine if the instrument is in the service mode (0 = disabled; 1= enabled)";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
                 { 0, "Off" "|de|Aus"},
	 	 { 1, "On"  "|de|An"}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}


//---EDD2DTM Dummy Byte-----
 VARIABLE dummy_byte
{
	LABEL "dummy";
	TYPE ASCII(1);
	CLASS LOCAL;

}

/************************************************************************/
/*-----------------------COMMANDS---------------------------------------*/
/************************************************************************/

COMMAND read_SS71_Float01
{
	SLOT 21;
	INDEX 0;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          SS71_Measurement1, // Measured turbidity value:40001(000)Float L(02)
          dummy_byte, dummy_byte, // Integer turbidity value:40003(002)Unsigned Integer L(01)
          dummy_byte, dummy_byte, // Integer turbidity * 100:40004(003)Unsigned Integer L(01)
          dummy_byte, dummy_byte, // Sensor name or location:40005(004)String L(06)
          dummy_byte, dummy_byte, // Sensor name or location:40005(005)String L(06)
          dummy_byte, dummy_byte, // Sensor name or location:40005(006)String L(06)
          dummy_byte, dummy_byte, // Sensor name or location:40005(007)String L(06)
          dummy_byte, dummy_byte, // Sensor name or location:40005(008)String L(06)
          dummy_byte, dummy_byte, // Sensor name or location:40005(009)String L(06)
          dummy_byte, dummy_byte, // Bubble reject status (0=OFF; 1=ON):40011(010)Unsigned Integer L(01)
          dummy_byte, dummy_byte, // Signal Average (0=1; 1=6sec; 2=30sec;3=60sec;4=90sec):40012(011)Unsigned Integer L(01)
          dummy_byte, dummy_byte, // Datalog interval (0=5sec;1=30sec;2=1min;3=2min;4=5min;6=10min;7=15min;8=30min;9=60min, 10=4hr):40013(012)Unsigned Integer L(01)
          dummy_byte, dummy_byte, // Maximum number of decimal places (0=xxxxx, 1=xxxx.x, 2=xxx.xx):40014(013)Unsigned Integer L(01)
          dummy_byte, dummy_byte, // Pass / Fail criteria for verification.  (1 to 10 percent):40015(014)Unsigned Integer L(01)
          dummy_byte, dummy_byte, // Turb units (0=mg/L:7=NTU;42=FTU):40016(015)Unsigned Integer L(01)
          dummy_byte, dummy_byte, // :40017(016) L(01)
          dummy_byte, dummy_byte, // Used to detemine if the instrument is in the service mode (0 = disabled; 1= enabled):40018(017)Unsigned Integer L(01)
          dummy_byte, dummy_byte, // :40019(018) L(01)
          dummy_byte, dummy_byte, // :40020(019) L(01)
          dummy_byte, dummy_byte, // Instrument serial number:40021(020)String L(06)
          dummy_byte, dummy_byte, // Instrument serial number:40021(021)String L(06)
          dummy_byte, dummy_byte, // Instrument serial number:40021(022)String L(06)
          dummy_byte, dummy_byte, // Instrument serial number:40021(023)String L(06)
          dummy_byte, dummy_byte, // Instrument serial number:40021(024)String L(06)
          dummy_byte, dummy_byte, // Instrument serial number:40021(025)String L(06)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // sensor Name(026)Float L(16)
          dummy_byte, dummy_byte, // Device driver firmware version:40029(028)Unsigned Integer L(01)
          dummy_byte, dummy_byte, // Device driver content version:40030(029)Unsigned Integer L(01)
          dummy_byte, dummy_byte, // Hardware version of pc board:40031(030)Unsigned Integer L(01)
          dummy_byte, dummy_byte, // Temperature measurement in Celsius:40032(031)Float L(02)
          dummy_byte, dummy_byte, // Temperature measurement in Celsius:40032(032)Float L(02)
          dummy_byte, dummy_byte, // 33
          dummy_byte, dummy_byte, // 34
          dummy_byte, dummy_byte // Dark turbidity A/D counts.:40034(035)Unsigned Integer L(02)


        }
    }
}


COMMAND read_SS71_Float03
{
	SLOT 21;
	INDEX 31;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          SS71_Measurement2, // Temperature measurement in Celsius:40032(031)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Dark turbidity A/D counts.:40034(033)Unsigned Integer L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // Turbidity value with dark offset and gain applied.:40036(035)Float L(02)
          dummy_byte, dummy_byte,
          dummy_byte, dummy_byte, // turbidity A/D counts:40038(037)Unsigned Integer L(02)
          SS71_Measurement6, // Maximum Temperature:40040(039)Float L(02)
          SS71_Measurement7, // Minimum Temperature:40042(041)Float L(02)
          SS71_Measurement3, // Lamp voltage:40044(043)Float L(02)
          SS71_Measurement4, // Lamp Current (amps):40046(045)Float L(02)
          SS71_Measurement8, // Plus five volt measurement:40048(047)Float L(02)
          SS71_Measurement5, // Input voltage (~12V):40050(049)Float L(02)
          SS71_Measurement9, // Voltage reference measurement (2.5V):40052(051)Float L(02)
          dummy_byte, dummy_byte, // :40054(053) L(01)
          dummy_byte, dummy_byte, // :40055(054) L(01)
          dummy_byte, dummy_byte, // :40056(055) L(01)
          dummy_byte, dummy_byte, // :40057(056) L(01)
          dummy_byte, dummy_byte, // :40058(057) L(01)
          dummy_byte, dummy_byte, // :40059(058) L(01)
          dummy_byte, dummy_byte, // :40060(059) L(01)
          dummy_byte, dummy_byte, // :40061(060) L(01)
          dummy_byte, dummy_byte, // :40062(061) L(01)
          dummy_byte, dummy_byte, // :40063(062) L(01)
          dummy_byte, dummy_byte, // :40064(063) L(01)
          dummy_byte, dummy_byte, // :40065(064) L(01)
          dummy_byte, dummy_byte, // :40066(065) L(01)
          dummy_byte, dummy_byte
        }
    }
}


COMMAND read_SS71_VAR01
{
	SLOT 21;
	INDEX 2;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {

        dummy_byte, dummy_byte,// Integer turbidity value:40003(002)Unsigned Integer L(01)
        dummy_byte, dummy_byte,// Integer turbidity * 100:40004(003)Unsigned Integer L(01)
        SS71_Setting3,// Sensor name or location:40005(004)String L(06)
        SS71_Setting1,// Bubble reject status (0=OFF; 1=ON):40011(010)Unsigned Integer L(01)
        SS71_Setting4,// Signal Average (0=1; 1=6sec; 2=30sec;3=60sec;4=90sec):40012(011)Unsigned Integer L(01)
        SS71_Setting2,// Datalog interval (0=5sec;1=30sec;2=1min;3=2min;4=5min;6=10min;7=15min;8=30min;9=60min, 10=4hr):40013(012)Unsigned Integer L(01)
        SS71_Setting5,// Maximum number of decimal places (0=xxxxx, 1=xxxx.x, 2=xxx.xx):40014(013)Unsigned Integer L(01)
        dummy_byte, dummy_byte,// Pass / Fail criteria for verification.  (1 to 10 percent):40015(014)Unsigned Integer L(01)
        SS71_Unit1,// Turb units (0=mg/L:7=NTU;42=FTU):40016(015)Unsigned Integer L(01)
        dummy_byte, dummy_byte,// :40017(016) L(01)
        SS71_Setting8,// Used to detemine if the instrument is in the service mode (0 = disabled; 1= enabled):40018(017)Unsigned Integer L(01)
        dummy_byte, dummy_byte,// :40019(018) L(01)
        dummy_byte, dummy_byte,// :40020(019) L(01)
        }
    }
}


//------------------------------------------------------------------------



COMMAND write_SS71_Unit1
{
	SLOT SS71_SLOTADR;
	INDEX 15;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
          SS71_Unit1
        }
        REPLY
        {

        }
    }
}





COMMAND write_SS71_Setting1  //Bubble Reject	40017   Bubble reject status (0=OFF; 1=ON)
{
	SLOT SS71_SLOTADR;
	INDEX 10;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
          SS71_Setting1

        }
        REPLY
        {

        }
    }
}

COMMAND write_SS71_Setting2  //Datalog Interval	40026  Datalog interval (0=5sec;
{
	SLOT SS71_SLOTADR;
	INDEX 12;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
          SS71_Setting2
        }
        REPLY
        {

        }
    }
}



COMMAND write_SS71_Setting3  //Sensor Name	40005 Sensor name or location (8)
{
	SLOT SS71_SLOTADR;
	INDEX 4;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
          SS71_Setting3
        }
        REPLY
        {

        }
    }
}



COMMAND write_SS71_Setting4  //SIGNAL AVG	40035 Signal Average (0=1sec; 1=6sec;
{
	SLOT SS71_SLOTADR;
	INDEX 11;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
          SS71_Setting4
        }
        REPLY
        {

        }
    }
}

COMMAND write_SS71_Setting5
{
	SLOT SS71_SLOTADR;
	INDEX 13;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
          SS71_Setting5
        }
        REPLY
        {

        }
    }
}


COMMAND write_SS71_Setting8
{
	SLOT SS71_SLOTADR;
	INDEX 17;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
          SS71_Setting8
        }
        REPLY
        {

        }
    }
}


