/*-----------------------------------------------------------------*/
/*	Copyright (C)	Hach-Lange (2011). All Rights Reserved.	   */
/*	Product:		SIMATIC PDM  			   */
/*	Device:			Sonatax Ultrasonic Sludge Monitor  */
/*	Description:		Device Description	           */
/*	Dictionary:		SIPADC01.dct			   */
/*  	$Revision:		0.1  $				   */
/*  	$Date:			June 2011			   */
/*	File:			SC200_SO1.inc		   	   */
/*	Author:			T.Thiel Hach-Lange	           */
/*-----------------------------------------------------------------*/

/************************************************************************/
/*		Variablen						*/
/************************************************************************/



METHOD METHOD_WAIT
{
	LABEL "Update Settings";
	DEFINITION
	{
	DELAY (3, "Reload");
	}

}

VARIABLE SO1_Measurement1
{
	LABEL 	"Sludge Level" 	"|de|Schlammspiegel";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"m";
}

VARIABLE SO1_Measurement2
{
	LABEL 	"Sludge Level" 	"|de|Schlammspiegel";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"ft";

}


VARIABLE SO1_Measurement3
{
	LABEL 	"Sludge Heigh" 	"|de|Schlammhoehe";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"m";
}

VARIABLE SO1_Measurement4
{
	LABEL 	"Sludge Heigh" 	"|de|Schlammhoehe";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"ft";
}

VARIABLE SO1_Calib1
{
	LABEL 	"Plunger Depth" 	"|de|Tauchtiefe";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	
	MIN_VALUE		0.1 ;
	MAX_VALUE		3  ;
	
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"m";
}

VARIABLE SO1_Calib2
{
	LABEL 	"Plunger Depth" 	"|de|Tauchtiefe";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	
	MIN_VALUE		0.328 ;
	MAX_VALUE		9.8424  ;
	
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"ft";
}

VARIABLE SO1_Calib3
{
	LABEL 	"Bottom Depth" 	"|de|Bodentiefe";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	
	MIN_VALUE		1 ;
	MAX_VALUE		12  ;
	
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"m";
}

VARIABLE SO1_Calib4
{
	LABEL 	"Bottom Depth" 	"|de|Bodentiefe";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	
	MIN_VALUE		3.2808 ;
	MAX_VALUE		39.3696  ;
	
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"ft";
}



VARIABLE SO1_Unit
{
	LABEL 	"Unit" 			"|de|Einheit ";
	CLASS	DYNAMIC;
	TYPE	ENUMERATED (2)
		{
			{13,		"Meter"	},
			{43,		"Feed"	}
	
						
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}



VARIABLE SO1_Parameter
{
	LABEL 	"Parameter" 	"|de|Parameter";
	CLASS	DYNAMIC;
	TYPE	ENUMERATED (2)
		{
			{23,			"Sludge Level" 	"|de|Schlammspiegel" 	},
			{24,			"Sludge High" 	"|de|Schlammhoehe"	}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}



VARIABLE SO1_Correction
{
	LABEL 	"Factor "               "|de|Korrekturfaktor ";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
		DEFAULT_VALUE  1.0;
		MIN_VALUE		0.3 ;
		MAX_VALUE		3  ;
			
			
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE SO1_Wipe
{
	LABEL 	"Wiper" 	"|de|Wischerstatus";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{
			{0,			"Home Position" 	"|de|Stop" 	},
			{1,			"Run Wiper Cycle" 	"|de|Start"	},

			MIN_VALUE		0 ;
			MAX_VALUE		1 ;
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	POST_WRITE_ACTIONS
					
		{
			METHOD_WAIT
					
          	}
}

VARIABLE SO1_CleanInterval
{
	LABEL 	"Cleaning Interval" "|de|Reinigungsintervall";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{


		{1,	"1 Min"					},
		{5,	"5 Min"					},
		{10,	"10 Min"			    	},
		{15,	"15 Min"				},
		{60,	"1 Hour"				},
		{240,	"4 Hours"				},
		{720,	"12 Hours"				},
		{1440,	"1 day"					}		
		

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE SO1_Offset
{
	LABEL 	"Offset Value"            "|de|Offsetwert";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  0.0;
			
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"";
}

VARIABLE SO1_Integration
{
	LABEL 	"Response Time"	"|de|Ansprechzeit";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
        {

		MIN_VALUE		10 ;
		MAX_VALUE		600  ;
	
		
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Seconds" "|de|Sekunden";
}

VARIABLE SO1_FadeOut
{
	LABEL 	"Fade-Out"      "|de|Ausblendung";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{


		{0,	"OFF"	"|de|AUS"		},
		{1,	"ON"	"|de|EIN"		}
		
		

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}


VARIABLE SO1_Begin_m
{
	LABEL 	"Fade-Out Begin" 	"|de|Fade-Out Start";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {

		MIN_VALUE		0  ;
		MAX_VALUE		12 ;
			
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"m";
}

VARIABLE SO1_Begin_ft
{
	LABEL 	"Fade-Out Begin" 	"|de|Fade-Out Start";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	
		MIN_VALUE		0 ;
		MAX_VALUE		39.3696  ;	
	
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"ft";

}


VARIABLE SO1_End_m
{
	LABEL 	"Fade-Out End" 	"|de|Fade-Out Ende";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {

		MIN_VALUE		0 ;
		MAX_VALUE		12  ;
			
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"m";
}

VARIABLE SO1_End_ft
{
	LABEL 	"Fade-Out End" 	"|de|Fade-Out Ende";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {

		MIN_VALUE		0 ;
		MAX_VALUE		39.3696  ;
			
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"ft";
}


VARIABLE SO1_LogInterval
{
	LABEL 	"Data Log Interval" "|de|Datenloggerinteval";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{

		{60,	"1 Min"				},
		{120,	"2 Min"				},
		{180,	"3 Min"				},
		{240,	"4 Min"			    	},
		{300,	"5 Min"				},
		{360,	"6 Min"				},
		{600,	"10 Min"			},
		{900,	"15 Min"			},
		{1800,	"30 Min"			}
		

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Minutes"  "|de|Minuten";
}

VARIABLE SO1_Threshold_Auto
{
	LABEL 	"Threshold Automatic"      "|de|Schwellwertautomatik";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{


		{0,	"OFF"			},
		{1,	"1%"			},
		{5,	"5%"			},
		{10,	"10%"			},
		{15,	"15%"			},
		{20,	"20%"			},
		{25,	"25%"			},
		{30,	"30%"			},
		{35,	"35%"			},
		{40,	"40%"			},
		{45,	"45%"			},
		{50,	"50%"			},
		{55,	"55%"			},
		{60,	"60%"			},
		{65,	"65%"			},
		{70,	"70%"			},
		{75,	"75%"			},
		{80,	"80%"			},		
		{85,	"85%"			},
		{90,	"90%"			},
		{95,	"95%"			}		
		

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"%"  "|de|%";
}

VARIABLE SO1_Threshold_M
{
	LABEL 	"Manual Threshold Value" 	"|de|Schwellwert manuell";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {

		MIN_VALUE		0.1 ;
		MAX_VALUE		50  ;
			
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"";
}

VARIABLE SO1_Window
{
	LABEL 	"Measurement Window"      "|de|Messwertfenster";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{


		{0,	"OFF"			},
		{1,	"1"			},
		{2,	"2"			},
		{5,	"5"			},
		{10,	"10"			},
		{20,	"20"			},
		{30,	"30"			},
		{40,	"40"			},
		{50,	"50"			},
		{75,	"75"			},

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"%"  "|de|%";
	POST_WRITE_ACTIONS
				
		{
			METHOD_WAIT
				
          	}	
}



VARIABLE SO1_Profile_Count
{
	LABEL 	"Wiper Counter"	"|de|Zaehler Wischprofile";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
        {
		MIN_VALUE		0.0 ;
		MAX_VALUE		40000  ;
	
		
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"" "|de|";
}

VARIABLE SO1_Moist
{
	LABEL 	"Humidity Detection" "|de|Feuchtesensor";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
        {
		MIN_VALUE		0.0 ;
		MAX_VALUE		100 ;	
	
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"%" "|de|%";
}

VARIABLE SO1_Temp
{
	LABEL 	"Internal Temperature" "|de|Innentemperatur";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
        {
		MIN_VALUE		0.0 ;
		MAX_VALUE		100 ;	
	
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"C" "|de|C";
}

VARIABLE SO1_Sensor_Angle
{
	LABEL 	"Sensor Angle" "|de|Winkelerkennung";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
        {
		MIN_VALUE		0.0 ;
		MAX_VALUE		100 ;	
	
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"deg" "|de|deg";
}

VARIABLE SO1_Freq
{
	LABEL 	"Meas. Frequency" "|de|Resonanzfrequenz";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
        {
	
	
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"kHz" "|de|kHz";
}

VARIABLE SO1_Amp_Diag
{
	LABEL 	"Amplitude Voltage" "|de|Resonanzspannung";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
        {
		
		MIN_VALUE		5.0 ;
		MAX_VALUE		125 ;
	
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Volt" "|de|Volt";
}


VARIABLE SO1_SampleLocation
{
	LABEL 	"Probe Location" "|de|Einbauort";
	CLASS	CONTAINED;
	TYPE	ASCII (16)
		{
			DEFAULT_VALUE "";
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	POST_WRITE_ACTIONS
				
		{

//			METHOD_WAIT
				
          	}

}

VARIABLE SO1_SettingBlock_1
{
	LABEL 	"Setting data block I"	;
	CLASS	INPUT & OUTPUT;
	TYPE	INTEGER (26)
        {
	
        }
	HANDLING	READ & WRITE;

}

VARIABLE SO1_SettingBlock2
{
	LABEL 	"Setting data block II"	;
	CLASS	INPUT & OUTPUT;
	TYPE	INTEGER (32)
        {
	
        }
	HANDLING	READ & WRITE;

}

VARIABLE SO1_SettingBlock_3
{
	LABEL 	"Setting data block III"	;
	CLASS	INPUT & OUTPUT;
	TYPE	INTEGER (10)
        {
	
        }
	HANDLING	READ & WRITE;
	
}



/************************************************************************/
/*		COMMANDS														*/
/************************************************************************/

COMMAND read_SO1_SettingBlock_1
{
	SLOT 21;
	INDEX 8;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
	
        }
        REPLY
        {
            SO1_Calib1,
            SO1_Calib2,
            SO1_Calib3,
            SO1_Calib4,
            SO1_Parameter,
            SO1_Unit,
            SO1_Correction,
            SO1_Wipe

        }
    }
}



COMMAND write_SO1_Calib1
{
	SLOT 21;
	INDEX 8;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              SO1_Calib1
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_SO1_Calib2
{
	SLOT 21;
	INDEX 10;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              SO1_Calib2
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_SO1_Calib3
{
	SLOT 21;
	INDEX 12;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              SO1_Calib3
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_SO1_Calib4
{
	SLOT 21;
	INDEX 14;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              SO1_Calib4
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_SO1_Parameter
{
	SLOT 21;
	INDEX 16;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              SO1_Parameter
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_SO1_Unit
{
	SLOT 21;
	INDEX 17;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              SO1_Unit
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_SO1_Correction
{
	SLOT 21;
	INDEX 18;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              SO1_Correction
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_SO1_Wipe
{
	SLOT 21;
	INDEX 20;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              SO1_Wipe
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_SO1_SettingBlock_2
{
	SLOT 21;
	INDEX 20;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
	
        }
        REPLY
        {
    
            SO1_CleanInterval,
            SO1_Integration
            SO1_FadeOut,
            SO1_Begin_m,
            SO1_Begin_ft,
            SO1_End_m,
            SO1_End_ft,
            SO1_LogInterval,
            SO1_Threshold_Auto,
            SO1_Threshold_M,
            SO1_Window,
            SO1_Profile_Count

        }
    }
}



COMMAND write_SO1_CleanInterval
{
	SLOT 21;
	INDEX 29;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              SO1_CleanInterval
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_SO1_Integration
{
	SLOT 21;
	INDEX 30;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              SO1_Integration
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_SO1_FadeOut
{
	SLOT 21;
	INDEX 31;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              SO1_FadeOut
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_SO1_Begin_m
{
	SLOT 21;
	INDEX 32;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              SO1_Begin_m
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_SO1_Begin_ft
{
	SLOT 21;
	INDEX 34;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              SO1_Begin_ft
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_SO1_End_m
{
	SLOT 21;
	INDEX 36;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              SO1_End_m
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_SO1_End_ft
{
	SLOT 21;
	INDEX 38;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              SO1_End_ft
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_SO1_LogInterval
{
	SLOT 21;
	INDEX 40;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              SO1_LogInterval
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_SO1_Threshold_Auto
{
	SLOT 21;
	INDEX 41;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              SO1_Threshold_Auto
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_SO1_Threshold_M
{
	SLOT 21;
	INDEX 42;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              SO1_Threshold_M
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_SO1_Window
{
	SLOT 21;
	INDEX 44;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              SO1_Window
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_SO1_SettingBlock_3
{
	SLOT 21;
	INDEX 77;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {

        }
        REPLY
        {
            SO1_Moist,
            SO1_Temp,
            SO1_Sensor_Angle,
            SO1_Freq,
            SO1_Amp_Diag

        }
    }
}



COMMAND read_SO1_Measurement1
{
	SLOT 21;
	INDEX 0;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            SO1_Measurement1
        }
    }
}

COMMAND read_SO1_Measurement2
{
	SLOT 21;
	INDEX 2;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            SO1_Measurement2
        }
    }
}

COMMAND read_SO1_Measurement3
{
	SLOT 21;
	INDEX 4;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            SO1_Measurement3
        }
    }
}

COMMAND read_SO1_Measurement4
{
	SLOT 21;
	INDEX 6;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            SO1_Measurement4
        }
    }
}


COMMAND read_SO1_SampleLocation
{
	SLOT 21;
	INDEX 21;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            
            SO1_SampleLocation
        }
    }
}

COMMAND write_SO1_SampleLocation
{
	SLOT 21;
	INDEX 21;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              SO1_SampleLocation
        }
        REPLY
        {
            
        }
    }
}

