/*--------------------------------------------------------------*/
/*Copyright (C)	Hach-Lange (2010). All Rights Reserved.    	    */
/*Product:	SIMATIC PDM  	           			                */
/*Device:	SC200 1720e Turbidity sensor           	            */
/*Description:	Device Description	           		            */
/*Dictionary:	SIPADC01.dct	           			            */
/*$Revision:	1.5  $  	           			                */
/*$Date:	Maerz 2010	           			                    */
/*File:		SC200_UltraTurb.ddl    				                */
/*Author:	R.Stollenwerk / R.Mellows Hach-Lange	       	    */
/*                                                    	        */
/*--------------------------------------------------------------*/

MANUFACTURER	213,
DEVICE_TYPE	    1,
DEVICE_REVISION 1,
DD_REVISION     5

#define DEVICE_TITLE	"SC200 Ultraturb"

#define UTB1_SLOTADR 21

#define READ_TIMEOUT_VAL 0
#define WRITE_TIMEOUT_VAL 0




#include	"1_UTRB.inc"	// first device
/************************************************************************/
/*      Methoden                                                        */
/************************************************************************/
METHOD METHOD_WOX1
{
	LABEL "Without1 0x";
	DEFINITION
	{
	DD_STRING Serial_str1,Serial_str2,Serial_str3;
	unsigned int zw;
	unsigned int s1,s2,s3,s4;

        zw=UTB1_Seria1;
        s1=zw>>12;
        zw=zw-(s1<<12);
        s2=zw>>8;
        zw=zw-(s2<<8);
        s3=zw>>4;
        zw=zw-(s3<<4);
        s4=zw;
	Serial_str1=itoa(s1)+itoa(s2)+itoa(s3)+itoa(s4);

        zw=UTB1_Seria2;
        s1=zw>>12;
        zw=zw-(s1<<12);
        s2=zw>>8;
        zw=zw-(s2<<8);
        s3=zw>>4;
        zw=zw-(s3<<4);
        s4=zw;
        Serial_str2=itoa(s1)+itoa(s2)+itoa(s3)+itoa(s4);

        zw=UTB1_Seria3;
        s1=zw>>12;
        zw=zw-(s1<<12);
        s2=zw>>8;
        zw=zw-(s2<<8);
        s3=zw>>4;
        zw=zw-(s3<<4);
        s4=zw;
        Serial_str3=itoa(s1)+itoa(s2)+itoa(s3)+itoa(s4);

        Serial1_WOX= Serial_str1+Serial_str2+Serial_str3;

	}

}
/************************************************************************/
/*---------------------Variablen----------------------------------------*/
/************************************************************************/
//--Lokale Seriennummer ohne 0x--
VARIABLE Serial1_WOX
{
	LABEL 	"Serial Number" 	"|de|Seriennummer";
	TYPE	ASCII (16)
		{
		DEFAULT_VALUE "0000000000000000";
		}

	CLASS LOCAL;

}
VARIABLE VendorName
{
	LABEL 	"Vendor Name""|de|Geraetehersteller";
	CLASS	CONTAINED;
	TYPE	ASCII (12)
		{
			DEFAULT_VALUE "Hach-Lange";
		}
	HANDLING	READ;
}

VARIABLE ModelName
{
	LABEL 	"Fieldbus type" "|de|Feldbustyp";
	CLASS	CONTAINED;
	TYPE	ASCII (14)
		{
			DEFAULT_VALUE "DP/V1";
		}
	HANDLING	READ;
}

VARIABLE ModelNummer
{
	LABEL 	"Model Number""|de|Model Nummer";
	CLASS	CONTAINED;
	TYPE	ASCII (15)
		{
			DEFAULT_VALUE "";
		}
	HANDLING	READ;
}
VARIABLE UTB1_Seria1
{
	LABEL 	"Serial No 1" 	"|de|Seriennummer 1";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{

		}
	HANDLING	READ;

}

VARIABLE UTB1_Seria2
{
	LABEL 	"Serial No 2" 	"|de|Seriennummer 2";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{

		}
	HANDLING	READ;

}

VARIABLE UTB1_Seria3
{
	LABEL 	"Serial No 3" 	"|de|Seriennummer 3";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{

		}
	HANDLING	READ;
        POST_READ_ACTIONS
          {
            METHOD_WOX1

          }
  }

VARIABLE UTB1_ManufactID1
{
	LABEL 	"Manufacturer ID" 	"|de|Herstellerkennung";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{

		}
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE UTB1_DeviceID1
{
	LABEL 	"Device ID" 	"|de|Geraetekennung";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{

			{10,			"3798 Cond"		},
			{12,			"LDO"			},
			{13,			"1720E"			},
			{17,			"pHD SC"		},
			{18,			"5740 DO"		},
			{19,			"34xx Cont. Cond."	},
			{20,			"37xx Ind. Cond."	},
			{21,			"pH SC"				},
			{26,   			"Surface Scatter 7" },
			{39,   			"SC200"   			},  
			{101,			"ULTRATURB SC"		},
			{102,			"Nitratax eco"  	},
			{103,			"Nitratax plus"		},
			{104,			"Solitax SC"    	},
			{105,			"Nitratax clear"	},
			{106,			"UVAS plus"     	},
			{107,			"S::CAN CARBO::LYZER"	},
			{108,			"S::CAN NITRO::LYZER"   },
			{109,			"PHOSPHAX SC"     	},
			{110,			"AMTAX SC"     	 	},
			{112,			"NH4D SC"     		},
			{113,			"SONATAX SC"     	},
			{114,			"PHOSPHAX SC"     	},
			{120,   		"NO3D SC"           }


		}
	HANDLING	READ;
}

VARIABLE UTB1_Length1
{
	LABEL 	"Length Member table" 	"|de|Lnge Teilnehmertabelle";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{

		}
	HANDLING	READ;
}

VARIABLE UTB1_Status1
{
	LABEL 	"Status";
	STYLE "MULTILINE 22 17";
	CLASS	DYNAMIC;
	TYPE	BIT_ENUMERATED (2)
	{

		{0,   	"OK"						"|de|OK"	 		 },
		{1,   	"Calibration start / in progress"		"|de|Kalibrierung aktiv"	 },
		{2,   	"Cleaning start / in progress"			"|de|Reinigungszyklus aktiv"	 },
		{4,   	"Enter(d) Service/Maintenance menu"		"|de|Betriebsart Service"	 },
		{8,   	"Common Error"					"|de|Sammelstrung"		 },
		{16,   	"Measurement 0 Quality Bad"			"|de|Messung 0 Qualittsfehler"	 },
		{32,   	"Measurement 0 low limit"			"|de|Messung 0 unterer Grenzwert"},
		{64,    "Measurement 0 high limit"			"|de|Messung 0 oberer Grenzwert" },
		{128,   "Measurement 1 Quality Bad"			"|de|Messung 1 Qualittsfehler"	 },
		{256,   "Measurement 1 low limit"			"|de|Messung 1 unterer Grenzwert"},
		{512,   "Measurement 1 high limit"			"|de|Messung 1 oberer Grenzwert" },
		{1024,  "Measurement 2 Quality Bad"			"|de|Messung 2 Qualittsfehler"	 },
		{2048,  "Measurement 2 low limit"			"|de|Messung 2 unterer Grenzwert"},
		{4096,  "Measurement 2 high limit"			"|de|Messung 2 oberer Grenzwert" },
		{8192,  "Measurement 3 Quality Bad"			"|de|Messung 3 Qualittsfehler"	 },
		{16384, "Measurement 3 low limit"			"|de|Messung 3 unterer Grenzwert"},
		{32768, "Measurement 3 high limit"			"|de|Messung 3 oberer Grenzwert" }

	}
	HANDLING	READ;
}

VARIABLE UTB1_Error1
{
	LABEL	"Error Detection"		"|de|Fehlermeldung";
	CLASS	DYNAMIC;
	STYLE "MULTILINE 22 17";
	TYPE	BIT_ENUMERATED (2)
	{
			{0,   	"No Error"				"|de|Kein Fehler"			},
			{1,   	"Measurement calibration Error"		"|de|Kalibrierfehler"			},
			{2,   	"Electronic adjustment Error"		"|de|Elektronik / Einstellfehler"	},
			{4,   	"Cleaning Error"			"|de|Reinigungsfehler"			},
			{8,   	"Measuring module Error"		"|de|Messmodulfehler"			},
			{16,   	"Settings Error"			"|de|Fehler Einstellungen"		},
			{32,   	"Hardware Error"			"|de|Hardwarefehler"			},
			{64,    "Internal communication Error"		"|de|Interner Kommunikationsfehler"	},
			{128,   "Humidity Error"			"|de|Feuchtigkeit erkannt"		},
			{256,   "Temperatur Error"			"|de|Temperaturfehler"			},
			{512,   ""										},
			{1024,  ""										},
			{2048,  ""										},
			{4096,  "Questionable measurement Warning"	"|de|Warnung Messwert unsicher"		},
			{8192,  "Safety Warning"			"|de|Warnung Sicherheitseinrichtung"	},
			{16384, "Reagent Warning"			"|de|Warnung Reagenz"			},
			{32768, "Maintenance Warning"			"|de|Warnung Instandhaltung"		}

	}
	HANDLING	READ;
}


/************************************************************************/
/*-----------------------COMMANDS---------------------------------------*/
/************************************************************************/
 //----------------------------------------------
//------IDENTIFICATIONS-------------------------
//----------------------------------------------
COMMAND read_VendorName
{
	SLOT 0;
	INDEX 100;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            VendorName
        }
    }
}

COMMAND read_ModelName
{
	SLOT 0;
	INDEX 101;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            ModelName
        }
    }
}

COMMAND read_ModelNummer
{
	SLOT 0;
	INDEX 102;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            ModelNummer
        }
    }
}

COMMAND read_MemberTable
{
	SLOT 10;
	INDEX 0;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            UTB1_Seria1,
            UTB1_Seria2,
            UTB1_Seria3,
            UTB1_DeviceID1,
            UTB1_ManufactID1,
            UTB1_Length1,
            UTB1_Error1,
            UTB1_Status1
        }
    }
}

/************************************************************************/
/*  Upload from device to PC              Daten lesen vom Gert zum PC  */
/************************************************************************/

MENU download_variables
{
	LABEL	[menu_load_to_PC];
	ITEMS
	{
	    VendorName,
	    ModelName,
	    ModelNummer,
// Floats:
            UTB1_Measurement1,
            UTB1_Setting3,
            UTB1_Measurement3,
// Keine Floats:
            UTB1_Setting1,
            UTB1_Diag5,
            UTB1_Setting16,
            UTB1_Seria1
	}
}


/************************************************************************/
/*  Write from PC to device        Datenschreiben vom PC zum Gert	*/
/************************************************************************/

MENU upload_variables
{
	LABEL	[menu_load_to_device];
	ITEMS
	{
          UTB1_Setting2,                                               // 40004
          UTB1_Setting3,                                              // 40006
          UTB1_Setting4,                                               // 40008
          UTB1_Setting5,                                               // 40011
          UTB1_Setting6,                                              // 40013
          UTB1_Setting7,                                               // 40014
          UTB1_Setting8,                                               // 40018
          UTB1_Setting9,                                               // 40038
          UTB1_Setting12,                                             // 40066
          UTB1_Setting13,                                             // 40068
          UTB1_Setting14,                                             // 40070
          UTB1_Setting15,                                               // 40072
          UTB1_Setting16,                                             // 40082
          UTB1_Setting17,                                             // 40083
          UTB1_Setting18,                                              // 40084
          UTB1_Setting19,                                             // 40087
          UTB1_Setting1                                               // 40003
	}
}
/************************************************************************/
/*	  Table: Specialist						*/
/************************************************************************/

MENU Table_Main_Specialist
{
	LABEL	DEVICE_TITLE ;

	ITEMS
	{
	Tab_s_preferences,
	Tab_s_preferencesM1,
	Tab_s_settings,
	Tab_s_diag,
	Tab_s_output_Offline
	}
}
/************************************************************************/
/*	  Main Menus							*/
/************************************************************************/
MENU Menu_Main_Specialist
{
    LABEL		[main_menu];
    ITEMS
    {
        Menu_File,
        Menu_S_Device,
        Menu_S_View,
        Menu_S_Options,
        Menu_Help
    }
}

/************************************************************************/
/*	  Menu: Device							*/
/************************************************************************/
MENU Menu_S_Device   //Menu: Device
{
    LABEL		"Online Menu" "|de|Online Men";
    ITEMS
    {
	Tab_s_preferences,
	Tab_s_preferencesM1,
	Tab_s_settings,
	Tab_s_diag,
	Tab_s_output_Online
    }
}


/************************************************************************/
/*	  Menu: View							*/
/************************************************************************/

MENU Menu_S_View
{
    LABEL		"Monitor" "|de|Beobachten";
    ITEMS
    {
      UTB1_Measurement1,
      UTB1_Measurement2,
      UTB1_Measurement3,
      UTB1_Measurement4,
      UTB1_Measurement5,
      UTB1_Measurement6,
      UTB1_Measurement7,
      UTB1_Status1,
      UTB1_Error1
    }
}


/************************************************************************/
/*------------------------Online-Windows--------------------------------*/
/************************************************************************/

MENU Tab_s_preferences
{
    LABEL	"Profibus Interface"  "|de|Profibus Schnittstelle";
    ITEMS
    {
		VendorName,
		ModelName,
		ModelNummer


    }
}

MENU Tab_s_preferencesM1
{
    LABEL	"SC device"  "|de|SC Gert";
    ITEMS
    {
		UTB1_DeviceID1,
		Serial1_WOX  (READ_ONLY),
		UTB1_Setting8

    }
}

MENU Tab_s_output_Offline
{
	LABEL	"Output" "|de|Ausgang";
	ITEMS
	{
		UTB1_Measurement1,
		UTB1_Measurement4,
		UTB1_Measurement5

	}
}

MENU Tab_s_output_Online
{
	LABEL	"Output" "|de|Ausgang";
	ITEMS
	{
          UTB1_Measurement1,
          UTB1_Measurement2,
          UTB1_Measurement3,
          UTB1_Measurement4,
          UTB1_Measurement5,
          UTB1_Measurement6,
          UTB1_Measurement7,
          UTB1_Diag1,
          UTB1_Diag2,
          UTB1_Diag3,
          UTB1_Diag4,
          UTB1_Diag7,
          UTB1_Diag8,
          UTB1_Diag9,
          UTB1_Diag10,
          UTB1_Diag11,
          UTB1_Diag12
	}
}

MENU Tab_s_diag
{
	LABEL	"Diagnostics" "|de|Diagnose";
	ITEMS
	{
		UTB1_Measurement2,
		UTB1_Measurement7,
      	     	UTB1_Diag1,
		UTB1_Diag2,
		UTB1_Diag3,
                UTB1_Diag4
		UTB1_Status1,
		UTB1_Error1

	}
}

MENU Tab_s_settings
{
	LABEL	"Settings" "|de|Einstellungen";
	ITEMS
	{
	     UTB1_Setting1,
	     UTB1_Setting3,
	     UTB1_Setting4,
	     UTB1_Setting6,
	     UTB1_Setting7,
	     UTB1_Setting5,
             UTB1_Setting12,
             UTB1_Setting13,
             UTB1_Setting14,
             UTB1_Setting15
	}
}

