/*--------------------------------------------------------------*/
/*Copyright (C)	Hach-Lange (2010). All Rights Reserved.    		*/	
/*Product:	SIMATIC PDM  	           							*/
/*Device:	SC Ultraturb        	           					*/
/*Description:	Device Description	           					*/
/*Dictionary:	SIPADC01.dct	           						*/
/*$Revision:	1.0  $         									*/
/*$Date:		Maerz 2010     									*/
/*File:		SC_UTRB.ddl   	           							*/
/*Author:	R.Stollenwerk / R.Mellows Hach-Lange	       		*/
/*                                                    	        */
/*--------------------------------------------------------------*/


/************************************************************************/
/*---------------------Variablen----------------------------------------*/
/************************************************************************/

//-----------------Messwerte------Anfang------------------------------

VARIABLE UTB1_Measurement1

{
 LABEL 	"Measurement value" 	"|de|Messwert";
 HELP	"diplayed measurement value";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {

        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
}


VARIABLE UTB1_Measurement2

{
 LABEL 	"LED current" 	"|de|LED Strom";
 CLASS	DYNAMIC;
 TYPE	UNSIGNED_INTEGER (2)
        {

        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"mA";
}

VARIABLE UTB1_Measurement3

{
 LABEL 	"Measurement single value" 	"|de|Einzelmesswert";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {

        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
}

VARIABLE UTB1_Measurement4

{
 LABEL 	"Meas. Channel" 	"|de|Mess.Kanal";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {

        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
}

VARIABLE UTB1_Measurement5

{
 LABEL 	"Ref. Channel" 	"|de|Ref.Kanal";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {

        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
}

VARIABLE UTB1_Measurement6

{
 LABEL 	"Quotient" 	"|de|Quotient";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {

        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".4f";

}

VARIABLE UTB1_Measurement7

{
 LABEL 	"Humidity main value" 	"|de|Feuchtigkeit Hauptwert";
 CLASS	DYNAMIC;
 TYPE	FLOAT
        {

        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"%";
}



UNIT Select_unit_1		// dynymic unit relation
{
	UTB1_Setting1:
	UTB1_Measurement1,
	UTB1_Measurement3
}

//-----------------Messwerte------Ende------------------------------


//-----------------Settings------Anfang------------------------------
VARIABLE UTB1_Setting1
{
	LABEL 	"Measurement unit" "|de|Einheit Messwert";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
                      	MIN_VALUE 0 ;
	 		MAX_VALUE 9 ;

			{0,	"mg/l"   },
			{6,	"FNU"    },
			{7,	"NTU"    },
			{8,	"TE/F"   },
			{9,	"EBC"    }

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}


VARIABLE UTB1_Setting2

{
	LABEL 	"Parameter" "|de|Parameter";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE UTB1_Setting3
{
	LABEL 	"Correction" "|de|Korrektur";
	CLASS	CONTAINED;
	TYPE	FLOAT
		{

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE UTB1_Setting4
{
	LABEL 	"Offset" "|de|Offset";
	CLASS	CONTAINED;
	TYPE	FLOAT
		{

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE UTB1_Setting5
{
	LABEL 	"Clean interval" "|de|Reinigungsintervall";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
                                 MIN_VALUE 10 ;
	 MAX_VALUE 4096 ;


		{10,	"10 min"    },
		{20,	"20 min"    },
		{30,	"30 min"    },
		{120,	"2 h"       },
		{360,	"6 h"       },
		{720,	"12 h"      },
		{4096,	"10:00"     }

		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}


VARIABLE UTB1_Setting6
{
	POST_READ_ACTIONS
		  {
			set_home_1
  		  }
	POST_WRITE_ACTIONS
		  {
			set_home_1
  		  }

	LABEL 	"Wiper state" "|de|Wischerstatus";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)


		{

			MIN_VALUE 0 ;
	 		MAX_VALUE 1 ;
	        	{0,	"wiper park position"	"|de|Wischer Stop"},
		        {1,	"run wiper cycle."	"|de|Wischer Start"}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

METHOD set_home_1
{
	LABEL "set_wiper to home" "|de|Wischer zurcksetzen";
	//ACCESS ONLINE;
	DEFINITION
	{
	UTB1_Setting6=0;
	}
}


VARIABLE UTB1_Setting7

{
	LABEL 	"Response time" "|de|Ansprechzeit";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{
			MIN_VALUE 1 ;
	 		MAX_VALUE 60 ;
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"s";
}


VARIABLE UTB1_Setting8

{
	LABEL 	"Probe Location" "|de|Einbauort";
	CLASS	CONTAINED;
	TYPE	ASCII (16)
		{
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}

VARIABLE UTB1_Setting9

{
	LABEL 	"Desired measurement value" "|de|Ergebnissmesswert";
	CLASS	CONTAINED;
	TYPE	FLOAT
		{
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}


VARIABLE UTB1_Setting12

{
	LABEL 	"Factor quotient q" "|de|Faktorquotient Q";
	CLASS	CONTAINED;
	TYPE	FLOAT
		{
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".4f";
}

VARIABLE UTB1_Setting13

{
	LABEL 	"Distortion light q" "|de|Verzerrungslicht Q";
	CLASS	CONTAINED;
	TYPE	FLOAT
		{
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".3f";
}

VARIABLE UTB1_Setting14

{
	LABEL 	"Factor quotient m" "|de|Faktorquotient M";
	CLASS	CONTAINED;
	TYPE	FLOAT
		{
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".4f";
}

VARIABLE UTB1_Setting15

{
	LABEL 	"Distortion light m" "|de|Verzerrungslicht M";
	CLASS	CONTAINED;
	TYPE	FLOAT
		{
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".3f";
}

VARIABLE UTB1_Setting16

{
	LABEL 	"User cal. interval" "|de|Benutzer Kalibrierinterval";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"day";

}

VARIABLE UTB1_Setting17

{
	LABEL 	"cal. Output mode " "|de|Kalibrier Ausgangs Modus";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;


}

VARIABLE UTB1_Setting18

{
	LABEL 	"Measure mode" "|de|Messmodus";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;


}

VARIABLE UTB1_Setting19

{
	LABEL 	"Measurement precision" "|de|Messgenauigkeit";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
		{
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;


}

VARIABLE UTB1_Setting20

{
	LABEL 	"Logger interval" "|de|Logger interval";
	CLASS	CONTAINED;
	TYPE	ENUMERATED  (2)
		{
                 MIN_VALUE 5 ;
        	 MAX_VALUE 1800 ;

	{5,	"5s"   },
	{30,	"30s"    },
	{60,	"1min"    },
	{120,	"2min"    },
	{300,	"5min"    },
	{600,	"10min"    },
	{900,	"15min"    },
	{1800,	"30min"    }


		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;


}
//-----------------Settings------Ende------------------------------

//-----------------Diag------Anfang------------------------------
VARIABLE UTB1_Diag1
{
	LABEL 	"Profile counter" "|de|Profilzhler";
	HELP	"1200 is the start value after profile exchange, Counts down, negative values indicate that the profile needs to be exchanged";
        CLASS	DYNAMIC;
	TYPE	UNSIGNED_INTEGER (4)
		{
		}
	HANDLING	READ ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Counts" "|de|Zhlungen";
}

VARIABLE UTB1_Diag2
{
	LABEL 	"Motor cycles" "|de|Motorzyklen";
        CLASS	DYNAMIC;
	TYPE	UNSIGNED_INTEGER (4)
		{

		}
	HANDLING	READ ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Counts" "|de|Zhlungen";
}

VARIABLE UTB1_Diag3
{
	LABEL 	"Operating hours" "|de|Betriebsstunden";
        CLASS	DYNAMIC;
	TYPE	UNSIGNED_INTEGER (4)
		{

		}
	HANDLING	READ ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"h" ;
}


VARIABLE UTB1_Diag4
{
	LABEL 	"Service counter" "|de|Servicezhler";
        CLASS	DYNAMIC;
	TYPE	UNSIGNED_INTEGER(4)
		{
		}
	HANDLING	READ ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"Counts" "|de|Zhlungen";
}


VARIABLE UTB1_Diag5
{
	LABEL 	"Calibration time and date" "|de|Kalibrierungs- Zeit u. Datum";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (4)
		{

		}
	HANDLING	READ ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}


VARIABLE UTB1_Diag6
{
	LABEL 	"User calibration time and date" "|de|Benutzer Kalibrierungs- Zeit u. Datum";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (4)
		{

		}
	HANDLING	READ ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
}



VARIABLE UTB1_Diag7
{
	LABEL 	"Factor meas. 0" "|de|Faktor Mess. 0";
        CLASS	DYNAMIC;
	TYPE	FLOAT
		{

		}
	HANDLING	READ ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
}

VARIABLE UTB1_Diag8
{
	LABEL 	"Factor meas. 1" "|de|Faktor Mess. 1";
        CLASS	DYNAMIC;
	TYPE	FLOAT
		{

		}
	HANDLING	READ ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
}

VARIABLE UTB1_Diag9
{
	LABEL 	"Factor meas. 2" "|de|Faktor Mess. 2";
        CLASS	DYNAMIC;
	TYPE	FLOAT
		{

		}
	HANDLING	READ ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
}

VARIABLE UTB1_Diag10
{
	LABEL 	"Factor meas. 3" "|de|Faktor Mess. 3";
        CLASS	DYNAMIC;
	TYPE	FLOAT
		{

		}
	HANDLING	READ ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
}

VARIABLE UTB1_Diag11
{
	LABEL 	"Factor ref 0" "|de|Faktor ref. 0";
        CLASS	DYNAMIC;
	TYPE	FLOAT
		{

		}
	HANDLING	READ ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
}

VARIABLE UTB1_Diag12
{
	LABEL 	"Factor ref 1" "|de|Faktor ref. 1";
        CLASS	DYNAMIC;
	TYPE	FLOAT
		{

		}
	HANDLING	READ ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
}

VARIABLE UTB1_Diag13
{
	LABEL 	"Measurement format" "|de|Messformat";
	CLASS	CONTAINED;
	TYPE	FLOAT
		{

		}
	HANDLING	READ ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	DISPLAY_FORMAT 	".2f";
}
//-----------------Diag------Ende--------------------------------

/************************************************************************/
/*-----------------------COMMANDS---------------------------------------*/
/************************************************************************/


//-----------------Messwerte------Anfang------------------------------

//---EDD2DTM Dummy Byte-----
 VARIABLE dummy_byte
{
	LABEL "dummy";
	TYPE ASCII(1);
	CLASS LOCAL;
}


COMMAND read_UTB1_Measurement1

{
        SLOT UTB1_SLOTADR;
        INDEX 0;
        OPERATION READ;
        TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          UTB1_Measurement1,                                          // 40001 - 4  Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40003 - 8  Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40005 - 12 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40007 - 16 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40009 - 20 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40011 - 24 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40013 - 28 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40015 - 32 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40017 - 36 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40019 - 40 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40021 - 44 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40023 - 48 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40025 - 52 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40027 - 56 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40029 - 60 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40031 - 64 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40033 - 68 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40035 - 72 Bytes
        }
    }
}

COMMAND read_UTB1_Setting3

{
        SLOT UTB1_SLOTADR;
        INDEX 5;
        OPERATION READ;
        TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          UTB1_Setting3,                                              // 40006 - 4  Bytes
          UTB1_Setting4,                                              // 40008 - 8  Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40010 - 12 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40012 - 16 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40014 - 20 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40016 - 24 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40018 - 28 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40020 - 32 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40022 - 36 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40024 - 40 Bytes
          UTB1_Diag1,                                                 // 40026 - 44 Bytes
          UTB1_Diag2,                                                 // 40028 - 48 Bytes
          UTB1_Diag3,                                                 // 40030 - 52 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40032 - 56 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40034 - 60 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40036 - 64 Bytes
          UTB1_Setting9,                                              // 40038 - 68 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte              // 40040 - 72 Bytes
        }
    }
}


COMMAND read_UTB1_Measurement3
{
        SLOT UTB1_SLOTADR;
        INDEX 39;
        OPERATION READ;
        TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          UTB1_Measurement3,                                          // 40040 - 4  Bytes
          UTB1_Measurement4,                                          // 40042 - 8  Bytes
          UTB1_Measurement5,                                          // 40044 - 12 Bytes
          UTB1_Measurement6,                                          // 40046 - 16 Bytes
          UTB1_Measurement7,                                          // 40048 - 20 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40050 - 24 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40052 - 28 Bytes
          UTB1_Diag7,                                                 // 40054 - 32 Bytes
          UTB1_Diag8,                                                 // 40056 - 36 Bytes
          UTB1_Diag9,                                                 // 40058 - 40 Bytes
          UTB1_Diag10,                                                // 40060 - 44 Bytes
          UTB1_Diag11,                                                // 40062 - 48 Bytes
          UTB1_Diag12,                                                // 40064 - 52 Bytes
          UTB1_Setting12,                                             // 40066 - 56 Bytes
          UTB1_Setting13,                                             // 40068 - 60 Bytes
          UTB1_Setting14,                                             // 40070 - 64 Bytes
          UTB1_Setting15,                                             // 40072 - 68 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte              // 40074 - 72 Bytes
        }
    }
}

COMMAND read_UTB1_Setting1

{
        SLOT UTB1_SLOTADR;
        INDEX 2;
        OPERATION READ;
        TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          UTB1_Setting1,                                              // 40003 - 2  Bytes
          UTB1_Setting2,                                              // 40004 - 4  Bytes
          dummy_byte, dummy_byte,                                     // 40005 - 6  Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40006 - 10 Bytes
          dummy_byte, dummy_byte, dummy_byte, dummy_byte,             // 40008 - 14 Bytes
          dummy_byte, dummy_byte,                                     // 40010 - 16 Bytes
          UTB1_Setting5,                                              // 40011 - 18 Bytes
          UTB1_Measurement2,                                          // 40012 - 20 Bytes
          UTB1_Setting6,                                              // 40013 - 22 Bytes
          UTB1_Setting7,                                              // 40014 - 24 Bytes
          dummy_byte, dummy_byte,                                     // 40015 - 26 Bytes
          dummy_byte, dummy_byte,                                     // 40016 - 28 Bytes
          dummy_byte, dummy_byte,                                     // 40017 - 30 Bytes
          UTB1_Setting8,                                              // 40018 - 46 Bytes
          dummy_byte, dummy_byte,                                     // 40026 - 50 Bytes
          dummy_byte, dummy_byte,                                     // 40028 - 54 Bytes
          dummy_byte, dummy_byte,                                     // 40030 - 58 Bytes
          UTB1_Diag4                                                  // 40032 - 62 Bytes
        }
    }
}

COMMAND read_UTB1_Diag5

{
        SLOT UTB1_SLOTADR;
        INDEX 49;
        OPERATION READ;
        TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          UTB1_Diag5,                                                 // 40050 - 4  Bytes
          UTB1_Diag6                                                  // 40052 - 8  Bytes
        }
    }
}

COMMAND read_UTB1_Setting16

{
        SLOT UTB1_SLOTADR;
        INDEX 53;
        OPERATION READ;
        TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
          dummy_byte, dummy_byte,dummy_byte, dummy_byte,              // 40054 - 4  Bytes
          dummy_byte, dummy_byte,dummy_byte, dummy_byte,              // 40056 - 8  Bytes
          dummy_byte, dummy_byte,dummy_byte, dummy_byte,              // 40058 - 12 Bytes
          dummy_byte, dummy_byte,dummy_byte, dummy_byte,              // 40060 - 16 Bytes
          dummy_byte, dummy_byte,dummy_byte, dummy_byte,              // 40062 - 20 Bytes
          dummy_byte, dummy_byte,dummy_byte, dummy_byte,              // 40064 - 24 Bytes
          dummy_byte, dummy_byte,dummy_byte, dummy_byte,              // 40066 - 28 Bytes
          dummy_byte, dummy_byte,dummy_byte, dummy_byte,              // 40068 - 32 Bytes
          dummy_byte, dummy_byte,dummy_byte, dummy_byte,              // 40070 - 36 Bytes
          dummy_byte, dummy_byte,dummy_byte, dummy_byte,              // 40072 - 40 Bytes
          dummy_byte, dummy_byte,dummy_byte, dummy_byte,              // 40074 - 44 Bytes
          dummy_byte, dummy_byte,dummy_byte, dummy_byte,              // 40076 - 48 Bytes
          dummy_byte, dummy_byte,dummy_byte, dummy_byte,              // 40078 - 52 Bytes
          dummy_byte, dummy_byte,dummy_byte, dummy_byte,              // 40080 - 56 Bytes
          UTB1_Setting16,                                             // 40082 - 58 Bytes
          UTB1_Setting17,                                             // 40083 - 60 Bytes
          UTB1_Setting18,                                             // 40084 - 62 Bytes
          UTB1_Diag13,                                                // 40085 - 66 Bytes
          UTB1_Setting19,                                             // 40087 - 68 Bytes
//          UTB1_Setting20                                            // 40088 - 70 Bytes         Kann nicht geliefert werden, da Netzwerkkarte
//          UTB1_Setting21                                            // 40089 / 72 Bytes         in die letzten 4 Bytes Unsinn schreibt
        }
    }
}
//--------------------
COMMAND write_UTB1_Setting1
{
        SLOT UTB1_SLOTADR;
        INDEX 2;
        OPERATION WRITE;
        TRANSACTION
    {
        REQUEST
        {
          UTB1_Setting1                                              // 40003
        }
        REPLY
        {
        }
    }
}
//--------------------
COMMAND write_UTB1_Setting2
{
        SLOT UTB1_SLOTADR;
        INDEX 3;
        OPERATION WRITE;
        TRANSACTION
    {
        REQUEST
        {
          UTB1_Setting2                                               // 40004
        }
        REPLY
        {
        }
    }
}
//--------------------
COMMAND write_UTB1_Setting3
{
        SLOT UTB1_SLOTADR;
        INDEX 5;
        OPERATION WRITE;
        TRANSACTION
    {
        REQUEST
        {
          UTB1_Setting3                                              // 40006
        }
        REPLY
        {
        }
    }
}
//--------------------
COMMAND write_UTB1_Setting4
{
        SLOT UTB1_SLOTADR;
        INDEX 7;
        OPERATION WRITE;
        TRANSACTION
    {
        REQUEST
        {
          UTB1_Setting4                                               // 40008
        }
        REPLY
        {
        }
    }
}

COMMAND write_UTB1_Setting5
{
        SLOT UTB1_SLOTADR;
        INDEX 10;
        OPERATION WRITE;
        TRANSACTION
    {
        REQUEST
        {
          UTB1_Setting5                                               // 40011
        }
        REPLY
        {
        }
    }
}


COMMAND write_UTB1_Setting6
{
        SLOT UTB1_SLOTADR;
        INDEX 12;
        OPERATION WRITE;
        TRANSACTION
    {
        REQUEST
        {
          UTB1_Setting6                                              // 40013
        }
        REPLY
        {
        }
    }
}
COMMAND write_UTB1_Setting7
{
        SLOT UTB1_SLOTADR;
        INDEX 13;
        OPERATION WRITE;
        TRANSACTION
    {
        REQUEST
        {
          UTB1_Setting7                                               // 40014
        }
        REPLY
        {
        }
    }
}
//--------------------

COMMAND write_UTB1_Setting8
{
        SLOT UTB1_SLOTADR;
        INDEX 17;
        OPERATION WRITE;
        TRANSACTION
    {
        REQUEST
        {
          UTB1_Setting8                                               // 40018
        }
        REPLY
        {
        }
    }
}
//--------------------
COMMAND write_UTB1_Setting9
{
        SLOT UTB1_SLOTADR;
        INDEX 37;
        OPERATION WRITE;
        TRANSACTION
    {
        REQUEST
        {
          UTB1_Setting9                                               // 40038
        }
        REPLY
        {
        }
    }
}
//--------------------
COMMAND write_UTB1_Setting12
{
        SLOT UTB1_SLOTADR;
        INDEX 65;
        OPERATION WRITE;
        TRANSACTION
    {
        REQUEST
        {
          UTB1_Setting12                                             // 40066
        }
        REPLY
        {
        }
    }
}
//--------------------
COMMAND write_UTB1_Setting13
{
        SLOT UTB1_SLOTADR;
        INDEX 67;
        OPERATION WRITE;
        TRANSACTION
    {
        REQUEST
        {
          UTB1_Setting13                                             // 40068
        }
        REPLY
        {
        }
    }
}
//--------------------
COMMAND write_UTB1_Setting14
{
        SLOT UTB1_SLOTADR;
        INDEX 69;
        OPERATION WRITE;
        TRANSACTION
    {
        REQUEST
        {
          UTB1_Setting14                                             // 40070
        }
        REPLY
        {
        }
    }
}
//--------------------
COMMAND write_UTB1_Setting15
{
        SLOT UTB1_SLOTADR;
        INDEX 71;
        OPERATION WRITE;
        TRANSACTION
    {
        REQUEST
        {
          UTB1_Setting15                                              // 40072
        }
        REPLY
        {
        }
    }
}
//--------------------
COMMAND write_UTB1_Setting16
{
        SLOT UTB1_SLOTADR;
        INDEX 81;
        OPERATION WRITE;
        TRANSACTION
    {
        REQUEST
        {
          UTB1_Setting16                                             // 40082
        }
        REPLY
        {
        }
    }
}
//--------------------
COMMAND write_UTB1_Setting17
{
        SLOT UTB1_SLOTADR;
        INDEX 82;
        OPERATION WRITE;
        TRANSACTION
    {
        REQUEST
        {
          UTB1_Setting17                                             // 40083
        }
        REPLY
        {
        }
    }
}
//--------------------
COMMAND write_UTB1_Setting18
{
        SLOT UTB1_SLOTADR;
        INDEX 83;
        OPERATION WRITE;
        TRANSACTION
    {
        REQUEST
        {
          UTB1_Setting18                                              // 40084
        }
        REPLY
        {
        }
    }
}
COMMAND write_UTB1_Setting19
{
        SLOT UTB1_SLOTADR;
        INDEX 86;
        OPERATION WRITE;
        TRANSACTION
    {
        REQUEST
        {
          UTB1_Setting19                                             // 40087
        }
        REPLY
        {
        }
    }
}
