/*------------------------------------------------------------------*/
/*	Copyright (C)	Hach-Lange (2010). All Rights Reserved.	   		*/
/*	Product:		SIMATIC PDM  			   						*/
/*	Device:			SC Solitax         		   						*/
/*	Description:		Device Description	           				*/
/*	Dictionary:		SIPADC01.dct			   						*/
/*  	$Revision:		1.9  $				   						*/
/*  	$Date:			Maerz. 2010			   						*/
/*	File:			S1_Solitax.inc			   						*/
/*	Author:			T.Thiel Hach-Lange                 				*/
/*				R.Mellows Hach-Lange               					*/
/*				R.Stollenwerk Hach-Lange           					*/
/*------------------------------------------------------------------*/


//--- METHOD---
METHOD METHOD_READ_WIPERSTATUS_S1
{
	LABEL "METHOD_READ_WIPERSTATUS_S1";
	DEFINITION
	{
        READ_COMMAND(read_S1_Var01);
        }
}        

/************************************************************************/
/*		Variablen						*/
/************************************************************************/

VARIABLE S1_Measurement1
{
	LABEL 	"TRB Value FNU" 	"|de|TRB Messwert FNU";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";			
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"FNU";
	VALIDITY IF (S1_Parameter == 0) { TRUE; } ELSE { FALSE; }

}

VARIABLE S1_Measurement2
{
	LABEL 	"TRB Value EBC" 	"|de|TRB Messwert EBC";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT ".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"EBC";
	VALIDITY IF (S1_Parameter == 0) { TRUE; } ELSE { FALSE; }
}

VARIABLE S1_Measurement3
{
	LABEL 	"TS Value mg/l" 	"|de|TS Messwert mg/l";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"mg/l";
	VALIDITY IF (S1_Parameter == 1) { TRUE; } ELSE { FALSE; }
}

VARIABLE S1_Measurement4
{
	LABEL 	"TS Value g/l" 	"|de|TS Messwert g/l";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"g/l";
	VALIDITY IF (S1_Parameter == 1) { TRUE; } ELSE { FALSE; }
}

VARIABLE S1_Measurement5
{
	LABEL 	"TS Value %" 	"|de|TS Messwert %";
	CLASS	DYNAMIC;
	TYPE	FLOAT
        {
	DISPLAY_FORMAT 	".2f";
        }
	HANDLING	READ;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	CONSTANT_UNIT 	"%";
	VALIDITY IF (S1_Parameter == 1) { TRUE; } ELSE { FALSE; }
}

VARIABLE S1_UnitTRB
{
	LABEL 	"Unit turbidity" 			"|de|Einheit Trbung";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			{6,			"FNU"	},
			{7,			"NTU"   },
			{9,			"EBC"   }


		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	VALIDITY IF (S1_Parameter == 0) { TRUE; } ELSE { FALSE; }
}


VARIABLE S1_UnitTS
{
	LABEL 	"Unit suspended solids"			"|de|Einheit Feststoff";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			DEFAULT_VALUE 0;
			{0,			"mg/l"	},
			{1,			"g/l"   }
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	READ_TIMEOUT_VAL;
	WRITE_TIMEOUT 	WRITE_TIMEOUT_VAL;
	VALIDITY IF (S1_Parameter == 1) { TRUE; } ELSE { FALSE; }
}

VARIABLE S1_Parameter
{
	LABEL 	"Measurement Mode" 	"|de|Betriebsart";
	CLASS	DYNAMIC;
	TYPE	ENUMERATED (2)
		{
			{0,			"Turbidity" 		"|de|Trbung" 	},
			{1,			"Suspended solids" 	"|de|Feststoff"	}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE S1_CorrectionTRB
{
	LABEL 	"Correction TRB""|de|Korrekturfaktor TRB";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  1.0;

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
	VALIDITY IF (S1_Parameter == 0) { TRUE; } ELSE { FALSE; }
}

VARIABLE S1_CorrectionTS
{
	LABEL 	"Correction TS""|de|Korrekturfaktor TS";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  1.0;

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
	VALIDITY IF (S1_Parameter == 1) { TRUE; } ELSE { FALSE; }
}

VARIABLE S1_OffsetTRB
{
	LABEL 	"Offset TRB""|de|Offset TRB";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  0.0;

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
	VALIDITY IF (S1_Parameter == 0) { TRUE; } ELSE { FALSE; }
}

VARIABLE S1_Integration
{
	LABEL 	"Integration"	"|de|Integration in Sekunden";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
        {

        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE S1_CleaningInterval
{
	LABEL 	"Cleaning interval" "|de|Reinigungsinterval";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{
		{0,	""					},
		{1,	"1 Min."				},
		{5,	"5 Min"					},
		{15,	"15 Min"				},
		{30,	"30 Min"				},
		{60,	"1 houre"	"|de|1 Stunde"		},
		{240,	"4 houres"	"|de|4 Stunden"		},
		{720,	"12 houres"	"|de|12 Stunden"	},
		{1440,	"24 houres"	"|de|24 Stunden"	},
		{4320,	"3  days"	"|de|3 Tage"		},
		{10080,	"7  days"	"|de|7 Tage"		}
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

VARIABLE S1_Wiperstatus
{
	LABEL 	"Wiper status" "|de|Wischerstatus";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{
		{0,	"wiper park position"	"|de|Wischer Stop"},
		{1,	"run wiper cycle."	"|de|Wischer Start"}
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
        POST_WRITE_ACTIONS
          {
            METHOD_READ_WIPERSTATUS_S1
          }

}

VARIABLE S1_Wiperprofile
{
	LABEL 	"Wiper replace counter" "|de|Wischblatt Zykluszhler";
	CLASS	DYNAMIC;
	TYPE	UNSIGNED_INTEGER (2)
        {

        }
	HANDLING	READ;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}



VARIABLE S1_SampleLocation
{
	LABEL 	"Probe Location" "|de|Einbauort";
	CLASS	CONTAINED;
	TYPE	ASCII (16)
		{
			DEFAULT_VALUE "";
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT READ_TIMEOUT_VAL;
	WRITE_TIMEOUT WRITE_TIMEOUT_VAL;
}

//---EDD2DTM Dummy Byte-----
 VARIABLE dummy_byte
{
	LABEL "dummy";
	TYPE ASCII(1);
	CLASS LOCAL;

}



/************************************************************************/
/*		COMMANDS														*/
/************************************************************************/
//----------EDD2DTM Variablen ANfang----------------
COMMAND read_S1_Float01
{
	SLOT S1_SLOTADR;
	INDEX 0;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
           S1_Measurement1, //Index 0,1,,
           S1_Measurement2, //Index 2,3,,
           S1_Measurement3, //Index 4,5,,
           S1_Measurement4, //Index 6,7,,
           S1_Measurement5, //Index 8,9,,
           dummy_byte, dummy_byte, dummy_byte, dummy_byte, //Index 10,11,,
           dummy_byte, dummy_byte, dummy_byte, dummy_byte, //Index 12,13,,
           S1_OffsetTRB, //Index 14,15,,
           S1_CorrectionTRB, //Index 16,17,,
           S1_CorrectionTS, //Index 18,19,,
           dummy_byte, dummy_byte, dummy_byte, dummy_byte, //Index 20,21,,
           dummy_byte, dummy_byte, dummy_byte, dummy_byte, //Index 22,23,,
           dummy_byte, dummy_byte, dummy_byte, dummy_byte, //Index 24,25,,
           dummy_byte, dummy_byte, dummy_byte, dummy_byte, //Index 26,27,,
           dummy_byte, dummy_byte, dummy_byte, dummy_byte, //Index 28,29,,
           dummy_byte, dummy_byte, dummy_byte, dummy_byte, //Index 30,31,,
           dummy_byte, dummy_byte, dummy_byte, dummy_byte, //Index 32,33,,
           dummy_byte, dummy_byte, dummy_byte, dummy_byte //Index 34,35,,

        }
    }
}

COMMAND read_S1_Var01
{
	SLOT S1_SLOTADR;
	INDEX 12;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
           S1_UnitTRB, //Index 12,,,
           S1_UnitTS, //Index 13,,,
           dummy_byte, dummy_byte, //Index 14,,,
           dummy_byte, dummy_byte, //Index 15,,,
           dummy_byte, dummy_byte, //Index 16,,,
           dummy_byte, dummy_byte, //Index 17,,,
           dummy_byte, dummy_byte, //Index 18,,,
           dummy_byte, dummy_byte, //Index 19,,,
           S1_Wiperstatus, //Index 20,,,
           S1_Integration, //Index 21,,,
           S1_CleaningInterval, //Index 22,,,
           dummy_byte, dummy_byte, //Index 23,,,
           dummy_byte, dummy_byte, //Index 24,,,
           dummy_byte, dummy_byte, //Index 25,,,
           S1_SampleLocation, //Index 26,,,
           S1_Wiperprofile //Index 34,,,

        }
    }
}

COMMAND read_S1_Var02
{
	SLOT S1_SLOTADR;
	INDEX 11;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
           S1_Parameter

        }
    }
}


COMMAND read_Var_MT
{
	SLOT 10;
	INDEX 0;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
           Serial1_1, //Index 0,,,
           Serial1_2, //Index 1,,,
           Serial1_3, //Index 2,,,
           DeviceID1, //Index 3,,,
           ManufactID1, //Index 4,,,
           Length1, //Index 5,,,
           Error1, //Index 6,,,
           dummy_byte, dummy_byte, //Index 7,,,
           dummy_byte, dummy_byte, //Index 8,,,
           dummy_byte, dummy_byte, //Index 9,,,
           dummy_byte, dummy_byte, //Index 10,,,
           dummy_byte, dummy_byte, //Index 11,,,
           dummy_byte, dummy_byte, //Index 12,,,
           dummy_byte, dummy_byte, //Index 13,,,
           dummy_byte, dummy_byte, //Index 14,,,
           dummy_byte, dummy_byte //Index 15,,,

        }
    }
}
//----------EDD2DTM Variablen Ende------------------
REFRESH Refresh1
{
S1_Parameter:
S1_Measurement1,S1_Measurement2,S1_Measurement3,S1_Measurement4,S1_Measurement5,S1_UnitTRB,S1_UnitTS


}
//------Write Befehle--------------------
COMMAND write_S1_UnitTRB
{
	SLOT S1_SLOTADR;
	INDEX 12;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              S1_UnitTRB
        }
        REPLY
        {

        }
    }
}
COMMAND write_S1_CorrectionTRB
{
	SLOT S1_SLOTADR;
	INDEX 16;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              S1_CorrectionTRB
        }
        REPLY
        {

        }
    }
}
COMMAND write_S1_UnitTS
{
	SLOT S1_SLOTADR;
	INDEX 13;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              S1_UnitTS
        }
        REPLY
        {

        }
    }
}
COMMAND write_S1_Integration
{
	SLOT S1_SLOTADR;
	INDEX 21;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              S1_Integration
        }
        REPLY
        {

        }
    }
}
COMMAND write_S1_CorrectionTS
{
	SLOT S1_SLOTADR;
	INDEX 18;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              S1_CorrectionTS
        }
        REPLY
        {

        }
    }
}
COMMAND write_S1_OffsetTRB
{
	SLOT S1_SLOTADR;
	INDEX 14;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              S1_OffsetTRB
        }
        REPLY
        {

        }
    }
}
COMMAND write_S1_CleaningInterval
{
	SLOT S1_SLOTADR;
	INDEX 22;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              S1_CleaningInterval
        }
        REPLY
        {

        }
    }
}
COMMAND write_S1_Wiperstatus
{
	SLOT S1_SLOTADR;
	INDEX 20;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              S1_Wiperstatus
        }
        REPLY
        {

        }
    }
}
COMMAND write_S1_Wiperprofile
{
	SLOT S1_SLOTADR;
	INDEX 34;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              S1_Wiperprofile
        }
        REPLY
        {
            
        }
    }
}

COMMAND write_S1_Parameter
{
	SLOT S1_SLOTADR;
	INDEX 11;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
        S1_Parameter
        }
        REPLY
        {

        }
    }
}
COMMAND write_S1_SampleLocation
{
	SLOT S1_SLOTADR;
	INDEX 26;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              S1_SampleLocation
        }
        REPLY
        {
            
        }
    }
}
//-------------------Write Befehle Ende------------------
